@@ -39,4 +39,4 @@ desc view v3;
 
 select ms from v3;
 
-select case when ms = 92 then 'XXX' else ms end from v3;
+select case when ms = 92 then 42 else ms end from v3;
