@@ -13,7 +13,7 @@ class CegoAdm
 public:
 
    CegoAdm();
-   ~CegoAdm();
+   virtual ~CegoAdm();
 
    void parse();
    ListT<Chain>& getTokenList() { return _tokenList; }
@@ -24,6 +24,7 @@ protected:
    virtual void backChar() = 0;
    virtual void statementAction() = 0;
    virtual void poolInfoAction() = 0;
+   virtual void parameterInfoAction() = 0;
    virtual void tableSetInfoAction() = 0;
    virtual void poolEntryListAction() = 0;
    virtual void rawModeOn() = 0;
@@ -42,7 +43,9 @@ protected:
    virtual void threadInfoAction() = 0;
    virtual void lockStatAction() = 0;
    virtual void dbThreadInfoAction() = 0;
-   virtual void dbThreadLastQueryAction() = 0;
+   virtual void dbThreadQueryHistAction() = 0;
+   virtual void dbQueryHistLastAction() = 0;
+   virtual void dbQueryHistCostAction() = 0;
    virtual void admThreadInfoAction() = 0;
    virtual void logThreadInfoAction() = 0;
    virtual void copyInfoAction() = 0;
@@ -88,11 +91,16 @@ protected:
    virtual void addArchLogAction() = 0;
    virtual void removeArchLogAction() = 0;
    virtual void beginBackupAction() = 0;
+   virtual void executeBackupAction() = 0;
    virtual void endBackupAction() = 0;
+   virtual void listBackupAction() = 0;
    virtual void syncTableSetAction() = 0;
+   virtual void restoreTableSetAction() = 0;
    virtual void recoverTableSetAction() = 0;
    virtual void setLogMngAction() = 0;
+   virtual void setBackupMngAction() = 0;
    virtual void showLogMngAction() = 0;
+   virtual void showBackupMngAction() = 0;
    virtual void setTSInitFileAction() = 0;
    virtual void setCheckpointAction() = 0;
    virtual void setTSSysSizeAction() = 0;
@@ -102,20 +110,33 @@ protected:
    virtual void setTSLogNumAction() = 0;
    virtual void setTSLogSizeAction() = 0;
    virtual void setTSSortAreaSizeAction() = 0;
+   virtual void setTSLogUserAction() = 0;
+   virtual void setNumQueryLastAction() = 0;
+   virtual void setNumQueryCostAction() = 0;
+   virtual void enableAppendModeAction() = 0;
+   virtual void disableAppendModeAction() = 0;
    virtual void enableAutoCorrectAction() = 0;
    virtual void disableAutoCorrectAction() = 0;
    virtual void enableTableCacheAction() = 0;
    virtual void disableTableCacheAction() = 0;
+   virtual void listTableCacheAction() = 0;
+   virtual void showTableCacheAction() = 0;
+   virtual void cleanTableCacheAction() = 0;
+   virtual void setTableCacheParamAction() = 0;
+   virtual void setTableCacheFilter() = 0;
+   virtual void setTableCacheMaxSize() = 0;
+   virtual void setTableCacheMaxEntry() = 0;
+   virtual void setTableCacheHashRange() = 0;
    virtual void enableQueryCacheAction() = 0;
    virtual void disableQueryCacheAction() = 0;
    virtual void listQueryCacheAction() = 0;
+   virtual void showQueryCacheAction() = 0;
    virtual void cleanQueryCacheAction() = 0;
-   virtual void setQueryCacheEntryAction() = 0;
-   virtual void setQueryCacheSizeAction() = 0;
-   virtual void listTableCacheAction() = 0;
-   virtual void cleanTableCacheAction() = 0;
-   virtual void setTableCacheEntryAction() = 0;
-   virtual void setTableCacheSizeAction() = 0;
+   virtual void setQueryCacheParamAction() = 0;
+   virtual void setQueryCacheMaxEntry() = 0;
+   virtual void setQueryCacheMaxSize() = 0;
+   virtual void setQueryCacheHashRange() = 0;
+   virtual void setQueryCacheThreshold() = 0;
    virtual void exportTableAction() = 0;
    virtual void exportTableSetAction() = 0;
    virtual void exportTableSetStructureAction() = 0;
@@ -125,10 +146,11 @@ protected:
    virtual void keepTicketAction() = 0;
    virtual void syncCmdAction() = 0;
    virtual void timeoutAction() = 0;
-   virtual void nologAction() = 0;
    virtual void msgAction() = 0;
    virtual void cleanupAction() = 0;
    virtual void forceloadAction() = 0;
+   virtual void cpDumpAction() = 0;
+   virtual void noInitAction() = 0;
    virtual void xmlModeAction() = 0;
    virtual void binModeAction() = 0;
    virtual void plainModeAction() = 0;
@@ -164,6 +186,7 @@ protected:
       TRACE,
       TO,
       TMPSIZE,
+      THRESHOLD,
       THREADINFO,
       THREAD,
       TIMEOUT,
@@ -186,12 +209,14 @@ protected:
       ROLE,
       RIGHT,
       RETRIEVE,
+      RESTORE,
       RESET,
       RECOVER,
       REMOVE,
       RELOCATE,
       RAWMODE,
       QUIT,
+      QUERYHIST,
       QUERYCACHE,
       PRIMARY,
       POOL,
@@ -199,15 +224,18 @@ protected:
       PERMISSION,
       PASSWD,
       PATH,
+      PARAMETER,
       ON,
       OFF,
       OBJECT,
-      NOLOGGING,
+      NOINIT,
       NODE,
       MESSAGE,
       MEDIATOR,
+      MAXSIZE,
       UINDEX,
       IDENTIFIED,
+      LOGUSER,
       LOGSIZE,
       LOGNUM,
       LOGMNG,
@@ -216,9 +244,11 @@ protected:
       LOCKSTAT,
       LOCK,
       LIST,
+      LAST,
       KEEP,
       INITFILE,
       IMPORT,
+      HASHRANGE,
       GETDBINFO,
       GETNODELIST,
       GETTSLIST,
@@ -229,7 +259,7 @@ protected:
       FILTER,
       FILE,
       EXPORT,
-      ENTRY,
+      MAXENTRY,
       END_TOKEN,
       ENABLE,
       DUMP,
@@ -239,6 +269,8 @@ protected:
       DB,
       DATAFILE,
       CREATE,
+      CPDUMP,
+      COST,
       CORRECT,
       COPY,
       CONNECT,
@@ -253,11 +285,13 @@ protected:
       BUFILE,
       BINARY,
       BEGIN_TOKEN,
+      BACKUPMNG,
       BACKUP,
       AUTOCORRECT,
       ASSIGN,
       ARCHLOG,
       APPSIZE,
+      APPENDMODE,
       ADM,
       ADD,
       ABORT,
@@ -275,10 +309,13 @@ private:
       Start,
       PermList,
       PermEntry,
+      TableCacheParamList,
+      TableCacheParam,
+      QueryCacheParamList,
+      QueryCacheParam,
       KeepTicketOpt,
       SyncCmdOption,
       TimeoutOpt,
-      LogOpt,
       MsgOption,
       StartOptList,
       StartOpt,
@@ -304,6 +341,9 @@ private:
    void loadParser12();
    void loadParser13();
    void loadParser14();
+   void loadParser15();
+   void loadParser16();
+   void loadParser17();
 
    class ScannerStateEntry {
 
@@ -400,8 +440,8 @@ class ScannerTransEntry {
       int _num;
    };
 
-   ActionEntry _actionMap[405][113];
-   int _jumpMap[405][16];
+   ActionEntry _actionMap[467][125];
+   int _jumpMap[467][19];
 
    class ProdEntry {
 
