@@ -6,13 +6,13 @@
 //
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
 // Class: CegoAdmAction
 // 
-// Description: 
+// Description: Semantic actions for cgadm
 //
 // Status: CLEAN
 //
@@ -26,6 +26,9 @@
 #include "CegoAdmAction.h"
 #include "CegoOutput.h"
 
+#include <stdlib.h>
+#include <string.h>
+
 #define DEFTMPSIZE 100
 #define DEFSYSSIZE 100
 #define DEFAPPSIZE 3000
@@ -36,12 +39,25 @@
 #define DEFPRIMARY Chain()
 #define DEFSECONDARY Chain()
 #define DEFTIMEOUT 10
-
+#define DEFMAXCACHEENTRY 200
+#define DEFMAXCACHESIZE 500000
+#define DEFCACHEHASHRANGE 30
 #define MAXHOSTLEN 25
 
-CegoAdmAction::CegoAdmAction(CegoAdminHandler *pAH, CegoModule *pModule, CegoAdmAction::ResultMode resultMode, bool rawMode) 
+extern char __quoteEscapeFlag;
+extern char __caseSensitiveFlag;
+
+CegoAdmAction::CegoAdmAction(CegoAdminHandler *pAH, CegoModule *pModule, CegoAdmAction::ResultMode resultMode, bool rawMode) :  CegoAdm(), SigHandler() 
 {
-    _i=0;
+    init();
+    
+    install(SIGINT);
+#ifndef HAVE_MINGW
+    install(SIGPIPE);
+#endif
+
+    _isAborted = false;
+	
     _pC = 0;
     _pModule = pModule;
     _pAH = pAH;
@@ -49,17 +65,35 @@ CegoAdmAction::CegoAdmAction(CegoAdminHandler *pAH, CegoModule *pModule, CegoAdm
     _rawMode = rawMode;
     _resultMode = resultMode;
     _keepTicket = false;
-    _doLogging = true;
     _doCleanup = false;
     _doForceload = false;
+    _doCPDump = false;
+    _doNoInit = false;
+    
     _xportMode = XML_XML_VALUE;
     _timeout = DEFTIMEOUT;
     setDefault();
 
+    // default query cache param values
+    _maxEntry = 0;
+    _maxSize = 0;
+    _threshold = -1;
+    _hashRange = 0;
+    _cacheFilter = Chain();
+
     _admSchema.Insert(CegoField(Chain("ADM"), Chain("ADM"), Chain("ROLE"), VARCHAR_TYPE, 10)); 
     _admSchema.Insert(CegoField(Chain("ADM"), Chain("ADM"), Chain("HOSTNAME"), VARCHAR_TYPE, MAXHOSTLEN)); 
     _admSchema.Insert(CegoField(Chain("ADM"), Chain("ADM"), Chain("MSG"), VARCHAR_TYPE, 50));
-        
+
+    _stringBuf = (char*)malloc(MAXSTRINGLEN);
+    _stringBufLen = MAXSTRINGLEN;
+    
+    if ( _stringBuf == 0 ) 
+    {
+	Chain msg("Malloc system error"); 
+	throw Exception(EXLOC, msg);
+    }
+
     _modId = _pModule->getModId("CegoAdmAction");
 }
 
@@ -88,59 +122,191 @@ bool CegoAdmAction::getRawMode()
 
 void CegoAdmAction::setCommandChain(char *pC)
 {
-    _i = 0;
     _pC = pC;
     
     // init some vars
     _buMsg = Chain("NONE");
-    _syncCmd = Chain("");
+    _syncCmd = Chain();
     _timeout = DEFTIMEOUT;
+
+    _maxEntry = 0;
+    _maxSize = 0;
+    _threshold = -1;
+    _hashRange = 0;
+    _cacheFilter = Chain();
 }
 
 char CegoAdmAction::nextChar() 
-{
+{   
+    if ( _pC == 0 )
+	return 0;
 
-    if (_pC[_i])
+    if ( (int)(*_pC) < 0 )
     {
-	if ( _pC[_i] == '\'')
-	{
-	    setReserved(STRINGVAL);
-	    
-	    _i++;
-	    int j=0;
-	    while ( _pC[_i] != '\'')
-	    {
-		// cout << "Storing: " << _pC[_i] << endl;
-		_stringBuf[j] = _pC[_i];
-		j++;
-		_i++;
-		if (_i == MAXSTRINGLEN)
-		{
-		    throw Exception(EXLOC, "Stringbuf exceeded");
-		}
-
-	    }
-	    _stringBufLen = j+1;
-	    _stringBuf[j] = 0;
-	    _i++;
-	    return 0;
-	    
-	}
-	_i++;
-	return _pC[_i-1];
-	// return (toupper(_pC[_i-1]));
+	Chain msg = Chain("Invalid character <") + Chain((int)(*_pC)) + Chain("> detected"); 
+	throw Exception(EXLOC, msg);
     }
-    return 0;
+
+    // cout << "Character read : " << *_pC << endl;
+
+    if ( *_pC == '\'' )
+    {
+	_pC++;
+	readChain();
+	return 0;
+    }
+ 
+    if ( *_pC == 0 )
+    {
+        return 0; 
+    }
+    
+    char c = *_pC; 
+    _pC++;
+
+    if ( __caseSensitiveFlag == 0 )
+	return c;
+    else
+	return (char)tolower((int)c);
+} 
+
+void CegoAdmAction::readChain()
+{
+    setReserved(STRINGVAL); 
+    
+    int i=0;    
+
+    if ( __quoteEscapeFlag )
+    {
+	bool moreChar = true; 
+	while ( moreChar )
+	{	    
+	    if ( *_pC == '\'' ) 
+	    {
+		_pC++;
+		if ( *_pC == '\'' )
+		{
+		    _stringBuf[i] = '\'';
+		    i++;
+		}
+		else
+		{
+		    moreChar = false;
+		}
+	    }
+	    else
+	    {
+		_stringBuf[i] = *_pC; 		
+		i++;
+	    }
+	  
+	    if ( i == _stringBufLen ) 
+	    { 
+		reallocateStringBuf();
+	    }
+	    
+	    if ( moreChar )
+	    {
+		_pC++;
+		
+		if ( *_pC == 0 )
+		{
+		    Chain msg("Unterminated string"); 
+		    throw Exception(EXLOC, msg);
+		}
+	    }
+	}
+    }
+    else
+    {
+	while ( *_pC != '\'' ) 
+	{ 
+	    // cout << "Storing: " << *_pC << endl; 
+	    
+	    if ( *_pC == '\\' ) 
+	    { 
+		_pC++; 
+		
+		if ( *_pC == 'n' ) 
+		{ 
+		    _stringBuf[i] = '\n'; 
+		} 
+		else if ( *_pC == 'r' ) 
+		{ 
+		    _stringBuf[i] = '\r'; 
+		} 
+		else if ( *_pC == 't' ) 
+		{ 
+		    _stringBuf[i] = '\t'; 
+		} 
+		else if ( *_pC == '\'' ) 
+		{ 
+		    _stringBuf[i] = '\''; 
+		}
+		else if ( *_pC == '\\' ) 
+		{ 
+		    _stringBuf[i] = '\\'; 
+		} 
+		else 
+		{ 
+		    Chain msg = Chain("Invalid escape character <") + Chain(*_pC) + Chain(">"); 
+		    throw Exception(EXLOC, msg);
+		} 
+	    } 
+	    else
+	    { 
+		_stringBuf[i] = *_pC; 
+	    } 
+	    
+	    _stringBuf[i] = *_pC; 
+	    i++; 
+	    
+	    if ( i == _stringBufLen ) 
+	    {
+		reallocateStringBuf();
+	    }
+	    
+	    _pC++;
+	    
+	    if ( *_pC == 0 )
+	    {
+		Chain msg("Unterminated string"); 
+		throw Exception(EXLOC, msg);
+	    }
+	}
+	_pC++; 
+    }
+
+    _stringBuf[i] = 0; 
+
+    return; 
 }
 
 void CegoAdmAction::backChar() 
 {
-    _i--;
+    if ( _pC != 0 )
+	_pC--;
 }
-    
-void CegoAdmAction::printTokenList() 
+
+void CegoAdmAction::reallocateStringBuf()
 {
-    
+    // reallocation required
+    _stringBufLen += MAXSTRINGLEN;
+    char *newBuf = (char*)malloc( _stringBufLen );
+    if ( newBuf == 0 ) 
+    {
+	Chain msg("Malloc system error"); 
+	throw Exception(EXLOC, msg);
+    }
+
+    // we just have to copy the previous len
+    memcpy(newBuf, _stringBuf, _stringBufLen - MAXSTRINGLEN);
+    free(_stringBuf);
+    _stringBuf=newBuf;
+}
+
+void CegoAdmAction::printTokenList() 
+{   
     cout << "TokenList is " << endl;
 	
     ListT<Chain> tlist =  getTokenList();
@@ -154,12 +320,46 @@ void CegoAdmAction::printTokenList()
 
 void CegoAdmAction::cleanUp() 
 {
+    _isAborted = false;
+    _tsPerm = Chain();
+    _filterPerm = Chain();
+    _rightPerm = Chain();
+}
+
+void CegoAdmAction::showQueryCacheAction()
+{
+    Chain tableSet;
+
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+
+    CegoAdminHandler::ResultType res;
+
+    res = _pAH->reqShowQueryCache(tableSet);
+    handleMedResult(res);
     
+    CegoTableObject oe;
+    ListT<ListT<CegoFieldValue> > info;
+    
+    Chain format;
+    if ( _pAH->getCacheInfo(oe, info, format) )
+    {
+	CegoOutput output(oe.getSchema(), format);
+	output.setRawMode(_rawMode);
+	output.tabOut(info);
+    }
+    Chain msg;
+    _pAH->getMsg(msg);
+    
+    if ( _rawMode == false )
+	cout << msg << endl;
 }
 
 void CegoAdmAction::listQueryCacheAction()
 {
-
     Chain tableSet;
 
     Chain* pS = getTokenList().First();
@@ -178,8 +378,7 @@ void CegoAdmAction::listQueryCacheAction()
     
     Chain format;
     if ( _pAH->getCacheList(oe, info, format) )
-    {
-	
+    {	
 	CegoOutput output(oe.getSchema(), format);
 	output.setRawMode(_rawMode);
 	output.tabOut(info);
@@ -192,8 +391,7 @@ void CegoAdmAction::listQueryCacheAction()
 }
 
 void CegoAdmAction::cleanQueryCacheAction()
-{
-    
+{    
     Chain tableSet;
 
     Chain* pS = getTokenList().First();
@@ -213,26 +411,20 @@ void CegoAdmAction::cleanQueryCacheAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::setQueryCacheEntryAction()
+void CegoAdmAction::setQueryCacheParamAction()
 {
     Chain tableSet;
-    int numQueryEntry;
+    int numQueryEntry = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
     {
 	tableSet = *pS;
     }
-    pS = getTokenList().Next();
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	numQueryEntry = pS->asInteger();
-    }
 
     CegoAdminHandler::ResultType res;
 
-    res = _pAH->reqSetQueryCacheEntry(tableSet, numQueryEntry);
+    res = _pAH->reqSetQueryCacheParam(tableSet, _maxEntry, _maxSize, _threshold, _hashRange);
     handleMedResult(res);
 
     Chain msg;
@@ -241,38 +433,76 @@ void CegoAdmAction::setQueryCacheEntryAction()
 	cout << msg << endl;    
 }
 
-void CegoAdmAction::setQueryCacheSizeAction()
+void CegoAdmAction::setQueryCacheMaxEntry()
 {
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_maxEntry = pS->asInteger();
+    }
+}
 
+void CegoAdmAction::setQueryCacheMaxSize()
+{
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_maxSize = pS->asInteger();
+    }
+}
+
+void CegoAdmAction::setQueryCacheHashRange()
+{
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_hashRange = pS->asInteger();
+    }
+}
+
+void CegoAdmAction::setQueryCacheThreshold()
+{
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_threshold = pS->asInteger();
+    }
+}
+
+void CegoAdmAction::showTableCacheAction()
+{
     Chain tableSet;
-    int queryCacheSize = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
     {
 	tableSet = *pS;
     }
-    pS = getTokenList().Next();
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	queryCacheSize = pS->asInteger();
-    }
 
     CegoAdminHandler::ResultType res;
 
-    res = _pAH->reqSetQueryCacheSize(tableSet, queryCacheSize);
+    res = _pAH->reqShowTableCache(tableSet);
     handleMedResult(res);
-
+    
+    CegoTableObject oe;
+    ListT<ListT<CegoFieldValue> > info;
+    
+    Chain format;
+    if ( _pAH->getCacheInfo(oe, info, format) )
+    {
+	CegoOutput output(oe.getSchema(), format);
+	output.setRawMode(_rawMode);
+	output.tabOut(info);
+    }
     Chain msg;
     _pAH->getMsg(msg);
+    
     if ( _rawMode == false )
 	cout << msg << endl;
 }
 
 void CegoAdmAction::listTableCacheAction()
 {
-
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -289,8 +519,7 @@ void CegoAdmAction::listTableCacheAction()
     
     Chain format;
     if ( _pAH->getCacheList(oe, info, format) )
-    {
-	
+    {	
 	CegoOutput output(oe.getSchema(), format);
 	output.setRawMode(_rawMode);
 	output.tabOut(info);
@@ -304,7 +533,6 @@ void CegoAdmAction::listTableCacheAction()
 
 void CegoAdmAction::cleanTableCacheAction()
 {
-
     Chain tableSet;
     
     Chain* pS = getTokenList().First();
@@ -324,60 +552,62 @@ void CegoAdmAction::cleanTableCacheAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::setTableCacheEntryAction()
+void CegoAdmAction::setTableCacheParamAction()
 {
     Chain tableSet;
-    int numEntry;
-    
+    int numQueryEntry = 0;
+
     Chain* pS = getTokenList().First();
     if ( pS )
     {
 	tableSet = *pS;
     }
-    pS = getTokenList().Next();
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	numEntry = pS->asInteger();
-    }
 
     CegoAdminHandler::ResultType res;
 
-    res = _pAH->reqSetTableCacheEntry(tableSet, numEntry);
+    res = _pAH->reqSetTableCacheParam(tableSet, _cacheFilter, _maxEntry, _maxSize, _hashRange);
     handleMedResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
-	cout << msg << endl;
+	cout << msg << endl;    
 }
 
-void CegoAdmAction::setTableCacheSizeAction()
+void CegoAdmAction::setTableCacheMaxEntry()
 {
-    Chain tableSet;
-    int cacheSize = 0;
-    
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	tableSet = *pS;
+	_maxEntry = pS->asInteger();
     }
-    pS = getTokenList().Next();
-    pS = getTokenList().Next();
+}
+
+void CegoAdmAction::setTableCacheMaxSize()
+{
+    Chain* pS = getTokenList().First();
     if ( pS )
     {
-	cacheSize = pS->asInteger();
+	_maxSize = pS->asInteger();
     }
+}
 
-    CegoAdminHandler::ResultType res;
+void CegoAdmAction::setTableCacheHashRange()
+{
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_hashRange = pS->asInteger();
+    }
+}
 
-    res = _pAH->reqSetTableCacheSize(tableSet, cacheSize);
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
+void CegoAdmAction::setTableCacheFilter()
+{
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_cacheFilter = Chain(_stringBuf);
+    }
 }
 
 void CegoAdmAction::setDefault()
@@ -403,7 +633,6 @@ void CegoAdmAction::lockInfoAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-
 	Chain lockCat;
 	if ( *pS  == Chain("rec") )
 	{
@@ -445,9 +674,17 @@ void CegoAdmAction::lockInfoAction()
 	{
 	    lockCat = Chain(XML_LOCK_BUFFERPOOL_VALUE);
 	}
-	else if ( *pS == Chain("ts") )
+	else if ( *pS == Chain("lm") )
 	{
-	    lockCat = Chain(XML_LOCK_TABLESET_VALUE);
+	    lockCat = Chain(XML_LOCK_LOGMNG_VALUE);
+	}
+	else if ( *pS == Chain("qc") )
+	{
+	    lockCat = Chain(XML_LOCK_QUERYCACHE_VALUE);
+	}
+	else if ( *pS == Chain("tc") )
+	{
+	    lockCat = Chain(XML_LOCK_TABLECACHE_VALUE);
 	}
 	else
 	{
@@ -478,7 +715,6 @@ void CegoAdmAction::lockInfoAction()
 
 void CegoAdmAction::lockStatAction() 
 {
-
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqLockStat();    
@@ -500,8 +736,7 @@ void CegoAdmAction::lockStatAction()
 }
 
 void CegoAdmAction::poolInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqPoolInfo();
@@ -511,26 +746,18 @@ void CegoAdmAction::poolInfoAction()
     _pAH->getMsg(msg);
     
     CegoTableObject oe;
-    ListT<ListT<CegoFieldValue> > info1;
-    ListT<ListT<CegoFieldValue> > info2;
+    ListT<ListT<CegoFieldValue> > info;
     
-    _pAH->getPoolInfo(oe, info1, info2);
+    _pAH->getPoolInfo(oe, info);
     
     CegoOutput output(oe.getSchema());
     output.setRawMode(_rawMode);
     output.headOut();
-    ListT<CegoFieldValue> *pFVL = info1.First();
+    ListT<CegoFieldValue> *pFVL = info.First();
     while ( pFVL )
     {
 	output.rowOut(*pFVL);	
-	pFVL = info1.Next();
-    }
-
-    pFVL = info2.First();
-    while ( pFVL )
-    {
-	output.rowOut(*pFVL);	
-	pFVL = info2.Next();
+	pFVL = info.Next();
     }
     output.tailOut();
 
@@ -538,16 +765,45 @@ void CegoAdmAction::poolInfoAction()
 	cout << msg << endl;
 }
 
+void CegoAdmAction::parameterInfoAction() 
+{       
+    CegoAdminHandler::ResultType res;
+    
+    res = _pAH->reqParameterInfo();
+    handleMedResult(res); 
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    
+    CegoTableObject oe;
+    ListT<ListT<CegoFieldValue> > info;
+    
+    _pAH->getParameterInfo(oe, info);
+    
+    CegoOutput output(oe.getSchema());
+    output.setRawMode(_rawMode);
+    output.headOut();
+    ListT<CegoFieldValue> *pFVL = info.First();
+    while ( pFVL )
+    {
+	output.rowOut(*pFVL);	
+	pFVL = info.Next();
+    }
+
+    output.tailOut();
+
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::poolEntryListAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqPoolEntryList();
 
     while ( res == CegoAdminHandler::ADM_INFO )
     {
-
 	Chain msg;
 	_pAH->getMsg(msg);
 	
@@ -560,8 +816,7 @@ void CegoAdmAction::poolEntryListAction()
 	output.setRawMode(_rawMode);
 	output.tabOut(info);
 		
-	res = _pAH->nextInfo();
-	
+	res = _pAH->nextInfo();	
     }
     
     if ( _rawMode == false )
@@ -573,8 +828,7 @@ void CegoAdmAction::poolEntryListAction()
 }
 
 void CegoAdmAction::dbSessionInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqDbSessionInfo();
@@ -597,11 +851,10 @@ void CegoAdmAction::dbSessionInfoAction()
 }
 
 void CegoAdmAction::listTableSetAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medGetTableSetList();
+    res = _pAH->medGetTableSetList(true);
     handleMedResult(res);
 
     Chain msg;
@@ -610,9 +863,9 @@ void CegoAdmAction::listTableSetAction()
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
     
-    _pAH->getTableSetList(oe, info);
+    _pAH->getTableSetList(oe, info, true);
     
-    CegoOutput output(oe.getSchema(), Chain("llllll"));
+    CegoOutput output(oe.getSchema(), Chain("llllrrr"));
     output.setRawMode(_rawMode);
     output.tabOut(info);
     if ( _rawMode == false )
@@ -620,8 +873,7 @@ void CegoAdmAction::listTableSetAction()
 }
 
 void CegoAdmAction::threadInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqThreadInfo();
@@ -644,8 +896,7 @@ void CegoAdmAction::threadInfoAction()
 }
 
 void CegoAdmAction::dbThreadInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqDbThreadInfo();	
@@ -667,10 +918,9 @@ void CegoAdmAction::dbThreadInfoAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::dbThreadLastQueryAction() 
+void CegoAdmAction::dbThreadQueryHistAction() 
 {
-
-    int threadId;
+    int threadId = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -680,7 +930,7 @@ void CegoAdmAction::dbThreadLastQueryAction()
         
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->reqDbThreadInfo();
+    res = _pAH->reqDbThreadHistory(threadId);
     handleMedResult(res);
 
     Chain msg;
@@ -690,7 +940,69 @@ void CegoAdmAction::dbThreadLastQueryAction()
     ListT<ListT<CegoFieldValue> > info;
     
     Chain format;
-    _pAH->getDbThreadLastQuery(threadId, oe, info, format);
+    _pAH->getDbThreadHistory(oe, info, format);
+    
+    CegoOutput output(oe.getSchema(), format);
+    output.setRawMode(_rawMode);
+    output.tabOut(info);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
+void CegoAdmAction::dbQueryHistLastAction()
+{
+    int numLast = 0;
+
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	numLast = pS->asInteger();
+    }
+    
+    CegoAdminHandler::ResultType res;
+    
+    res = _pAH->reqQueryHistoryLast(numLast);
+    handleMedResult(res);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    
+    CegoTableObject oe;
+    ListT<ListT<CegoFieldValue> > info;
+    
+    Chain format;
+    _pAH->getDbThreadHistory(oe, info, format);
+    
+    CegoOutput output(oe.getSchema(), format);
+    output.setRawMode(_rawMode);
+    output.tabOut(info);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
+void CegoAdmAction::dbQueryHistCostAction()
+{
+    int numLast = 0;
+
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	numLast = pS->asInteger();
+    }
+    
+    CegoAdminHandler::ResultType res;
+    
+    res = _pAH->reqQueryHistoryCost(numLast);
+    handleMedResult(res);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    
+    CegoTableObject oe;
+    ListT<ListT<CegoFieldValue> > info;
+    
+    Chain format;
+    _pAH->getDbThreadHistory(oe, info, format);
     
     CegoOutput output(oe.getSchema(), format);
     output.setRawMode(_rawMode);
@@ -700,8 +1012,7 @@ void CegoAdmAction::dbThreadLastQueryAction()
 }
 
 void CegoAdmAction::admThreadInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqAdmThreadInfo();
@@ -724,8 +1035,7 @@ void CegoAdmAction::admThreadInfoAction()
 }
 
 void CegoAdmAction::logThreadInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqLogThreadInfo();
@@ -748,8 +1058,7 @@ void CegoAdmAction::logThreadInfoAction()
 }
 
 void CegoAdmAction::copyInfoAction() 
-{
-        
+{       
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqCopyInfo();
@@ -773,7 +1082,6 @@ void CegoAdmAction::copyInfoAction()
 
 void CegoAdmAction::buFileInfoAction()
 {
-
     Chain tableSet;
 
     Chain* pS = getTokenList().First();
@@ -806,7 +1114,6 @@ void CegoAdmAction::buFileInfoAction()
 
 void CegoAdmAction::buStatInfoAction()
 {
-
     Chain tableSet;
 
     Chain* pS = getTokenList().First();
@@ -839,7 +1146,6 @@ void CegoAdmAction::buStatInfoAction()
 
 void CegoAdmAction::buStatResetAction()
 {
-
     Chain tableSet;
 
     Chain* pS = getTokenList().First();
@@ -862,7 +1168,7 @@ void CegoAdmAction::buStatResetAction()
 
 void CegoAdmAction::abortDbThreadAction() 
 {
-    int threadId;
+    int threadId = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -929,9 +1235,11 @@ void CegoAdmAction::startTableSetAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medStartTableSet(tableSet, _doCleanup, _doForceload);
+    res = _pAH->medStartTableSet(tableSet, _doCleanup, _doForceload, _doCPDump, _doNoInit);
     _doCleanup=false;
     _doForceload=false;
+    _doCPDump=false;
+    _doNoInit = false;
 
     handleMedResult(res);
 
@@ -939,7 +1247,6 @@ void CegoAdmAction::startTableSetAction()
     _pAH->getMsg(msg);
     if ( _rawMode == false )
 	cout << msg << endl;
-
 }
 
 void CegoAdmAction::stopTableSetAction() 
@@ -976,7 +1283,6 @@ void CegoAdmAction::copyTableSetAction()
     _pAH->getMsg(msg);
     if ( _rawMode == false )
 	cout << msg << endl;
-
 }
 
 void CegoAdmAction::switchTableSetAction() 
@@ -1107,6 +1413,24 @@ void CegoAdmAction::beginBackupAction()
 	cout << msg << endl;
 }
 
+void CegoAdmAction::executeBackupAction()
+{
+    Chain tableSet;
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+    CegoAdminHandler::ResultType res;
+    res = _pAH->medExecuteBackup(tableSet, _buMsg);
+    handleMedResult(res);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::endBackupAction()
 {
     Chain tableSet;
@@ -1126,6 +1450,37 @@ void CegoAdmAction::endBackupAction()
 	cout << msg << endl;
 }
 
+void CegoAdmAction::listBackupAction()
+{
+    Chain tableSet;
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+    CegoAdminHandler::ResultType res;
+    res = _pAH->medListBackup(tableSet, _pit);
+    handleMedResult(res);
+
+    // reset pit to 0
+    _pit = Chain();
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    
+    CegoTableObject oe;
+    ListT<ListT<CegoFieldValue> > info;
+    
+    _pAH->getBackupInfo(oe, info);
+    
+    CegoOutput output(oe.getSchema());
+    
+    output.setRawMode(_rawMode);
+    output.tabOut(info);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::keepTicketAction()
 {
     _keepTicket = true;
@@ -1145,11 +1500,6 @@ void CegoAdmAction::timeoutAction()
     }
 }
 
-void CegoAdmAction::nologAction()
-{
-    _doLogging = false;
-}
-
 void CegoAdmAction::msgAction()
 {
     _buMsg = Chain(_stringBuf);
@@ -1165,6 +1515,16 @@ void CegoAdmAction::forceloadAction()
     _doForceload = true;
 }
 
+void CegoAdmAction::cpDumpAction()
+{
+    _doCPDump = true;
+}
+
+void CegoAdmAction::noInitAction()
+{
+    _doNoInit = true;
+}
+
 void CegoAdmAction::xmlModeAction()
 {
     _xportMode = XML_XML_VALUE;
@@ -1180,6 +1540,29 @@ void CegoAdmAction::plainModeAction()
     _xportMode = XML_PLAIN_VALUE;
 }
 
+void CegoAdmAction::restoreTableSetAction()
+{
+    Chain tableSet;
+    Chain backupId(_stringBuf);
+
+    Chain* pS = getTokenList().First();
+    pS = getTokenList().Next();
+    pS = getTokenList().Next();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+    
+    CegoAdminHandler::ResultType res;
+    res = _pAH->medRestore(tableSet, backupId);
+    handleMedResult(res);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::recoverTableSetAction()
 {
     Chain tableSet;
@@ -1203,7 +1586,6 @@ void CegoAdmAction::recoverTableSetAction()
 
 void CegoAdmAction::setLogMngAction()
 {
-
     Chain progName(_stringBuf);
 
     CegoAdminHandler::ResultType res;
@@ -1217,10 +1599,21 @@ void CegoAdmAction::setLogMngAction()
     _timeout = DEFTIMEOUT;
 }
 
+void CegoAdmAction::setBackupMngAction()
+{
+    Chain progName(_stringBuf);
+
+    CegoAdminHandler::ResultType res;
+    res = _pAH->reqSetBackupMng(progName);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
 
 void CegoAdmAction::showLogMngAction()
 {
-
     CegoAdminHandler::ResultType res;
     res = _pAH->reqShowLogMng();
 
@@ -1251,6 +1644,38 @@ void CegoAdmAction::showLogMngAction()
     }
 }
 
+void CegoAdmAction::showBackupMngAction()
+{
+    CegoAdminHandler::ResultType res;
+    res = _pAH->reqShowBackupMng();
+
+    if ( res == CegoAdminHandler::ADM_OK )
+    {
+
+	CegoTableObject oe;
+	ListT<ListT<CegoFieldValue> > info;
+
+	_pAH->getBackupMngInfo(oe, info);
+
+	CegoOutput output(oe.getSchema());
+	output.setRawMode(_rawMode);
+	output.tabOut(info);
+
+	if ( _rawMode == false )
+	{
+	    Chain msg;
+	    _pAH->getMsg(msg);
+	    cout << msg << endl;
+	}
+    }
+    else if ( res == CegoAdminHandler::ADM_ERROR )
+    {
+	Chain msg;
+	_pAH->getMsg(msg);
+	throw Exception(EXLOC, msg);
+    }
+}
+
 void CegoAdmAction::setTSInitFileAction()
 {
     Chain initFileName(_stringBuf);
@@ -1293,7 +1718,7 @@ void CegoAdmAction::setTSRootPathAction()
 
 void CegoAdmAction::setTSLogNumAction()
 {
-    int logNum;
+    int logNum = 0;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -1319,7 +1744,7 @@ void CegoAdmAction::setTSLogNumAction()
 
 void CegoAdmAction::setTSLogSizeAction()
 {
-    int logSize;
+    int logSize = 0;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -1344,7 +1769,7 @@ void CegoAdmAction::setTSLogSizeAction()
 
 void CegoAdmAction::setTSSortAreaSizeAction()
 {
-    unsigned long long sortAreaSize;
+    unsigned long long sortAreaSize = 0;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -1367,10 +1792,35 @@ void CegoAdmAction::setTSSortAreaSizeAction()
 	cout << msg << endl;
 }
 
+void CegoAdmAction::setTSLogUserAction()
+{
+    Chain logUser;
+    Chain tableSet;
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+    pS = getTokenList().Next();
+    pS = getTokenList().Next();
+    if ( pS )
+    {
+	logUser = *pS;
+    }
+
+    CegoAdminHandler::ResultType res;
+    res = _pAH->reqSetTSLogUser(tableSet, logUser);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::setTSSysSizeAction()
 {
     Chain tableSet;
-    int sysSize;
+    int sysSize = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1395,7 +1845,7 @@ void CegoAdmAction::setTSSysSizeAction()
 void CegoAdmAction::setTSTmpSizeAction()
 {
     Chain tableSet;
-    int tmpSize;
+    int tmpSize = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1420,7 +1870,7 @@ void CegoAdmAction::setTSTmpSizeAction()
 void CegoAdmAction::setTSAppSizeAction()
 {
     Chain tableSet;
-    int appSize;
+    int appSize = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1445,7 +1895,7 @@ void CegoAdmAction::setTSAppSizeAction()
 void CegoAdmAction::setCheckpointAction()
 {
     Chain tableSet;
-    int interval;
+    int interval = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1467,6 +1917,42 @@ void CegoAdmAction::setCheckpointAction()
 	cout << msg << endl;
 }
 
+void CegoAdmAction::setNumQueryLastAction()
+{    
+    int numLast = 0;
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	numLast = pS->asInteger();
+    }
+
+    CegoAdminHandler::ResultType res;
+    res = _pAH->reqNumQueryLast(numLast);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
+void CegoAdmAction::setNumQueryCostAction()
+{   
+    int numCost = 0;
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	numCost = pS->asInteger();
+    }
+
+    CegoAdminHandler::ResultType res;
+    res = _pAH->reqNumQueryCost(numCost);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::switchSecondaryAction()
 {
     Chain tableSet;
@@ -1714,7 +2200,6 @@ void CegoAdmAction::listNodeAction()
 
     if ( res == CegoAdminHandler::ADM_OK )
     {
-
 	CegoTableObject oe;
 	ListT<ListT<CegoFieldValue> > info;
 
@@ -1828,7 +2313,7 @@ void CegoAdmAction::archLogInfoAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetDetailedTableSetInfo(tableSet);
+    res = _pAH->medGetArchLogInfo(tableSet);
     
     handleMedResult(res);
 
@@ -2003,7 +2488,6 @@ void CegoAdmAction::copyFileAction()
 
 void CegoAdmAction::exportTableAction()
 {
-
     Chain exportFile(_stringBuf);
 
     Chain tableSet;
@@ -2026,23 +2510,17 @@ void CegoAdmAction::exportTableAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqExportTable(tableSet, tableName, exportFile, _xportMode);
-    _xportMode = XML_XML_VALUE;
+    
+    handleMedResult(res);
 
-    if ( res == CegoAdminHandler::ADM_OK )
-    {
-	if ( _rawMode == false )
-	{
-	    Chain msg;
-	    _pAH->getMsg(msg);
-	    cout << msg << endl;
-	}
-    }
-    else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	throw Exception(EXLOC, msg);
-    }
+    Chain msg;
+    _pAH->getMsg(msg);
+
+    if ( _rawMode == false )
+	cout << msg << endl;
+
+    // reset to default
+    _xportMode = XML_XML_VALUE;
 }
 
 void CegoAdmAction::exportTableSetAction()
@@ -2066,9 +2544,9 @@ void CegoAdmAction::exportTableSetAction()
 
     if ( _rawMode == false )
 	cout << msg << endl;
-    
-    _xportMode = XML_XML_VALUE;
 
+    // reset to default
+    _xportMode = XML_XML_VALUE;
 }
 
 void CegoAdmAction::exportTableSetStructureAction()
@@ -2121,10 +2599,9 @@ void CegoAdmAction::importTableAction()
         
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->reqImportTable(tableSet, tableName, importFile, _doLogging, _xportMode);	
+    res = _pAH->reqImportTable(tableSet, tableName, importFile, _xportMode);	
     handleMedResult(res);
 
-    _doLogging = true;
     _xportMode = XML_XML_VALUE;
 
     Chain msg;
@@ -2149,10 +2626,9 @@ void CegoAdmAction::importTableSetAction()
         
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->reqImportTableSet(tableSet, false, importFile, _doLogging, _xportMode);
+    res = _pAH->reqImportTableSet(tableSet, false, importFile, _xportMode);
     handleMedResult(res);
 
-    _doLogging = true;
     _xportMode = XML_XML_VALUE;
 
     Chain msg;
@@ -2178,10 +2654,9 @@ void CegoAdmAction::importTableSetStructureAction()
         
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->reqImportTableSet(tableSet, true, importFile, _doLogging, _xportMode);
+    res = _pAH->reqImportTableSet(tableSet, true, importFile, _xportMode);
     handleMedResult(res);
 
-    _doLogging = true;
     _xportMode = XML_XML_VALUE;
 
     Chain msg;
@@ -2193,7 +2668,6 @@ void CegoAdmAction::importTableSetStructureAction()
 
 void CegoAdmAction::addDataFileAction()
 {
-
     int numPages;
     Chain tableSet;
     Chain dataFile(_stringBuf);
@@ -2516,7 +2990,7 @@ void CegoAdmAction::setTableSetPerm()
 
 void CegoAdmAction::setFilterPerm()
 {
-    _filterPerm = Chain(_stringBuf);    
+    _filterPerm = Chain(_stringBuf);
 }
 
 void CegoAdmAction::setRightPerm()
@@ -2530,7 +3004,6 @@ void CegoAdmAction::setRightPerm()
 
 void CegoAdmAction::removePermAction()
 {
-
     Chain role;
     Chain permid;
 
@@ -2700,6 +3173,48 @@ void CegoAdmAction::disableArchLogAction()
 	cout << msg << endl;
 }
 
+void CegoAdmAction::enableAppendModeAction()
+{
+    Chain tableSet;
+
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+        
+    CegoAdminHandler::ResultType res;   
+    res = _pAH->medEnableAppendMode(tableSet);
+    
+    handleMedResult(res);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
+void CegoAdmAction::disableAppendModeAction()
+{
+    Chain tableSet;
+
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	tableSet = *pS;
+    }
+        
+    CegoAdminHandler::ResultType res;   
+    res = _pAH->medDisableAppendMode(tableSet);
+    
+    handleMedResult(res);
+
+    Chain msg;
+    _pAH->getMsg(msg);
+    if ( _rawMode == false )
+	cout << msg << endl;
+}
+
 void CegoAdmAction::enableAutoCorrectAction()
 {
     Chain tableSet;
@@ -2897,7 +3412,6 @@ void CegoAdmAction::storeTSRootAttr()
 
 void CegoAdmAction::storePit()
 {
-    Chain* pS = getTokenList().First();
     _pit = Chain(_stringBuf);
 }
 
@@ -2929,7 +3443,6 @@ void CegoAdmAction::dumpTable()
 	_pAH->getMsg(tableDump);
 
 	cout << tableDump;
-
     }
     else if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -2961,14 +3474,12 @@ void CegoAdmAction::dumpUIndex()
 	
     if ( res == CegoAdminHandler::ADM_INFO )
     {
-	
 	Chain tableDump;
 
 	_pAH->nextInfo();
 	_pAH->getMsg(tableDump);
 
 	cout << tableDump;
-
     }
     else if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -2994,7 +3505,7 @@ void CegoAdmAction::handleMedResult(CegoAdminHandler::ResultType res)
     if ( _resultMode == VERBOSE )
 	output.headOut();
 
-    while ( res == CegoAdminHandler::ADM_INFO )
+    while ( res == CegoAdminHandler::ADM_INFO && _isAborted == false )
     {	
 	if ( _resultMode == VERBOSE )
 	{
@@ -3027,9 +3538,12 @@ void CegoAdmAction::handleMedResult(CegoAdminHandler::ResultType res)
 	    cout.flush();
 	}
 
-	res = _pAH->nextInfo();
-	
+	res = _pAH->nextInfo();	
     }
+
+    if ( _isAborted && res == CegoAdminHandler::ADM_INFO )
+	res = _pAH->abort();
+    	
     if ( _resultMode == VERBOSE )
 	output.tailOut();
     
@@ -3041,3 +3555,29 @@ void CegoAdmAction::handleMedResult(CegoAdminHandler::ResultType res)
     }
 }
 
+void CegoAdmAction::sigCatch(int sig) 
+{    
+    try
+    {	
+	install(SIGINT);
+#ifndef HAVE_MINGW
+	install(SIGPIPE);
+#endif
+
+	if ( _abortEnabled )
+	{
+	    cout << endl << "Aborting admin command .." << endl;
+	    _isAborted = true;
+	}
+	else
+	{
+	    cout << "Use quit to quit" << endl;
+	}
+    }
+    catch ( Exception e)
+    {
+	Chain msg;
+	e.pop(msg);
+	cout << "Error : " << msg << endl;
+    }   
+}
