@@ -6,7 +6,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2010-2016 Bjoern Lemke
+// (C)opyright 2010-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -53,7 +53,7 @@ CegoAdmNet::~CegoAdmNet()
 
 void CegoAdmNet::connect(const Chain& serverName, int port, const Chain& user, const Chain& pwd)
 {
-    Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN );
+    Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, NETMNG_MAXSENDLEN );
 
     _pN = n.connect(serverName, port);
 
@@ -71,14 +71,12 @@ void CegoAdmNet::connect(const Chain& serverName, int port, const Chain& user, c
 	    _pModule->logModule(modId, "dbdimp", Logger::DEBUG);
 	else
 	    _pModule->logModule(modId, "dbdimp", Logger::NONE);
-	
     }
     else
     {
 	_pModule = new CegoModule;
     }
 
-
     _pAH = new CegoAdminHandler( _pModule, _pN);
     
     CegoAdminHandler::ResultType res = _pAH->requestSession(user, pwd);
@@ -95,7 +93,6 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
 				 ListT<Chain>& fileInfoList,
 				 ListT<Chain>& logInfoList)
 {
-
     CegoAdminHandler::ResultType res;    
     res = _pAH->medGetDetailedTableSetInfo(tableSet);
     handleMedResult(res);
@@ -123,7 +120,6 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
 	pTSI = tsinfo.Next();
     }
 
-
     Chain format;
     ListT<ListT<CegoFieldValue> > fileinfo;
     _pAH->getDataFileInfo(oe, fileinfo, format);
@@ -131,7 +127,6 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
     ListT<CegoFieldValue> *pFI = fileinfo.First();
     while ( pFI )
     {
-
 	Chain name;
 	Chain type;
 	Chain size;
@@ -158,14 +153,12 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
 	pFI = fileinfo.Next();
     }
 
-
     ListT<ListT<CegoFieldValue> > loginfo;
     _pAH->getLogInfo(oe, loginfo);
 
     ListT<CegoFieldValue> *pLI = loginfo.First();
     while ( pLI )
     {
-
 	Chain name;
 	Chain status;
 	Chain size;
@@ -191,7 +184,6 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
 	if ( pF )
 	    usage= pF->valAsChain();
 	
-
 	Chain attrVal = name + Chain(":") + status + Chain(":") + size + Chain(":") + offset + Chain(":") + usage;
 	logInfoList.Insert( attrVal );
 
@@ -201,7 +193,6 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
 
 void CegoAdmNet::getTableSetList(ListT<Chain>& tslist)
 {
-        
     CegoAdminHandler::ResultType res;
     
     res = _pAH->medGetTableSetList();
@@ -222,14 +213,11 @@ void CegoAdmNet::getTableSetList(ListT<Chain>& tslist)
     }
 }
 
-void CegoAdmNet::startTableSet(const Chain& tableSet, bool doCleanup, bool forceload)
+void CegoAdmNet::startTableSet(const Chain& tableSet, bool doCleanup, bool forceload, bool cpDump, bool noInit)
 {
-
     CegoAdminHandler::ResultType res;
-    res = _pAH->medStartTableSet(tableSet, doCleanup, forceload);
-
-    handleMedResult(res);
-    
+    res = _pAH->medStartTableSet(tableSet, doCleanup, forceload, cpDump, noInit);
+    handleMedResult(res);    
 }
 
 void CegoAdmNet::stopTableSet(const Chain& tableSet)
@@ -241,7 +229,6 @@ void CegoAdmNet::stopTableSet(const Chain& tableSet)
 
 void CegoAdmNet::getThreadInfo(ListT<Chain>& threadInfoList)
 {
-
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqThreadInfo();
@@ -255,7 +242,6 @@ void CegoAdmNet::getThreadInfo(ListT<Chain>& threadInfoList)
     ListT<CegoFieldValue> *pTI = threadinfo.First();
     while ( pTI )
     {
-
 	Chain id;
 	Chain status;
 
@@ -274,8 +260,7 @@ void CegoAdmNet::getThreadInfo(ListT<Chain>& threadInfoList)
 }
 
 void CegoAdmNet::getDbThreadInfo(ListT<Chain>& dbThreadInfoList)
-{
-    
+{ 
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqDbThreadInfo();	
@@ -290,11 +275,9 @@ void CegoAdmNet::getDbThreadInfo(ListT<Chain>& dbThreadInfoList)
     ListT<CegoFieldValue> *pDBTI = dbthreadinfo.First();
     while ( pDBTI )
     {
-
 	Chain id;
 	Chain numReq;
 	Chain status;
-	Chain lastAction;
 
 	CegoFieldValue *pF = pDBTI->First();
 	if ( pF )
@@ -306,20 +289,7 @@ void CegoAdmNet::getDbThreadInfo(ListT<Chain>& dbThreadInfoList)
 	if ( pF )
 	    status = pF->valAsChain();
 
-	CegoTableObject oe;
-	ListT<ListT<CegoFieldValue> > lastactioninfo;
-	
-	Chain format;
-	_pAH->getDbThreadLastQuery(id.asInteger(), oe, lastactioninfo, format);
-	ListT<CegoFieldValue> *pLAI = lastactioninfo.First();
-	if ( pLAI )
-	{
-	    CegoFieldValue *pF = pLAI->First();
-	    if ( pF )
-		lastAction = pF->valAsChain();	    
-	}
-
-	Chain attrVal = id + Chain(":") + numReq + Chain(":") + status + Chain(":") + lastAction;
+	Chain attrVal = id + Chain(":") + numReq + Chain(":") + status;
 	
 	dbThreadInfoList.Insert( attrVal );
 
@@ -343,7 +313,6 @@ void CegoAdmNet::getAdmThreadInfo(ListT<Chain>& admThreadInfoList)
     ListT<CegoFieldValue> *pAdmTI = admthreadinfo.First();
     while ( pAdmTI )
     {
-
 	Chain id;
 	Chain numReq;
 	Chain status;
@@ -382,7 +351,6 @@ void CegoAdmNet::getLogThreadInfo(ListT<Chain>& logThreadInfoList)
     ListT<CegoFieldValue> *pLogTI = logthreadinfo.First();
     while ( pLogTI )
     {
-
 	Chain id;
 	Chain numReq;
 	Chain status;
@@ -407,14 +375,11 @@ void CegoAdmNet::getLogThreadInfo(ListT<Chain>& logThreadInfoList)
 
 void CegoAdmNet::importTableSet(const Chain& tableSet, const Chain& impMode, const Chain& impFile)
 {
-
     CegoAdminHandler::ResultType res;
     bool isStructure=false;
-    bool doLogging=false;
     
-    res = _pAH->reqImportTableSet(tableSet, isStructure, impFile, doLogging, impMode);
-    handleMedResult(res);
-        
+    res = _pAH->reqImportTableSet(tableSet, isStructure, impFile, impMode);
+    handleMedResult(res);       
 }
 
 void CegoAdmNet::exportTableSet(const Chain& tableSet, const Chain& expMode, const Chain& expFile)
@@ -443,7 +408,6 @@ void CegoAdmNet::defineTableSet(const Chain& tableSet,
 				int logNum, 
 				unsigned long long orderSize)
 {
-    
     CegoAdminHandler::ResultType res;
     res = _pAH->medDefineTableSet(tableSet,
 				  tsRoot,
@@ -456,7 +420,6 @@ void CegoAdmNet::defineTableSet(const Chain& tableSet,
 				  logNum, 
 				  orderSize);
     handleMedResult(res);
-
 }
 
 void CegoAdmNet::createTableSet(const Chain& tableSet)
@@ -501,7 +464,7 @@ void CegoAdmNet::relocateMediator(const Chain& tableSet, const Chain& mediator)
     handleMedResult(res);
 }
 
-void CegoAdmNet::recoverTableSet(const Chain& tableSet, int pit)
+void CegoAdmNet::recoverTableSet(const Chain& tableSet, const Chain& pit)
 {
     CegoAdminHandler::ResultType res;
     res = _pAH->medRecover(tableSet, pit);
@@ -510,7 +473,6 @@ void CegoAdmNet::recoverTableSet(const Chain& tableSet, int pit)
 
 void CegoAdmNet::handleMedResult(CegoAdminHandler::ResultType res)
 {
-
     Chain msg;
     _pAH->getMsg(msg);
     
@@ -522,8 +484,7 @@ void CegoAdmNet::handleMedResult(CegoAdminHandler::ResultType res)
     }
     
     while ( res == CegoAdminHandler::ADM_INFO )
-    {
-	
+    {	
 	if ( doQuiet == false )
 	{
 	    Chain hostRole;
@@ -537,12 +498,10 @@ void CegoAdmNet::handleMedResult(CegoAdminHandler::ResultType res)
 	    ListT<CegoFieldValue> fvl;
 	    fvl.Insert(CegoFieldValue(VARCHAR_TYPE, hostRole));
 	    fvl.Insert(CegoFieldValue(VARCHAR_TYPE, hostName));
-	    fvl.Insert(CegoFieldValue(VARCHAR_TYPE, msg));
-	    
+	    fvl.Insert(CegoFieldValue(VARCHAR_TYPE, msg));	    
 	}
 
 	res = _pAH->nextInfo();
-	
     }
     
     _pAH->getMsg(msg);
@@ -561,4 +520,3 @@ void CegoAdmNet::disconnect()
 {        
     _pAH->closeSession();
 }
-
