@@ -6,7 +6,7 @@
 //
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke                        
+// (C)opyright 2000-2025 Bjoern Lemke 
 //
 // IMPLEMENTATION MODULE
 //
@@ -33,9 +33,7 @@
 // CEGO INCLUDES
 #include "CegoDefs.h"
 #include "CegoAdmAction.h"
-#ifndef CGNOCURSES
-#include "CegoAdmMon.h"
-#endif
+#include "CegoAdmScreen.h"
 
 // POSIX INCLUDES
 #include <stdio.h>
@@ -47,12 +45,13 @@
 #define USAGE "Usage: cgadm --user=<user>/<password>\n\
    [ --server=<host>]\n\
    [ --port=<port> ]\n\
+   [ --prompt=<prompt value> ]\n\
    [ --batchfile=<batchfile> ]\n\
    [ --cmd=<command> ]\n\
    [ --logfile=<logfile> ]\n\
    [ --raw ]\n\
    [ --verbose ]\n\
-   [ --mon ]\n\
+   [ --screen ]\n\
    [ --ignore ]\n\
    [ --debug ] [ --version  ] [ --help ]"
 
@@ -60,13 +59,12 @@
 #define DEFAULTPORT 2000
 
 #define HISTFILE ".cgadm_history"
-#define PROMPT "CGADM > "
+#define DEFAULTPROMPT "CGADM > "
 #define PROMPT2 "> "
-
-enum RunMode { INTERACTIVE, BATCH, COMMAND, MONITOR };
+enum RunMode { INTERACTIVE, BATCH, COMMAND, SC };
 
 bool dispatchCmd(CegoAdmAction* pAdm, const Chain& cmd);
-void showMonitor(CegoAdminHandler *pAH);
+void showScreen(CegoAdminHandler *pAH);
 
 void printHelp(const Chain& cs);
 
@@ -89,9 +87,10 @@ int main(int argc, char **argv)
     longOpt.addOpt("debug");
     longOpt.addOpt("raw");
     longOpt.addOpt("verbose");
-    longOpt.addOpt("mon");
+    longOpt.addOpt("screen");
     longOpt.addOpt("ignore");
     longOpt.addOpt("server", DEFAULTSERVER);
+    longOpt.addOpt("prompt", DEFAULTPROMPT);
     longOpt.addOpt("port", Chain(DEFAULTPORT));
     longOpt.addOpt("simulate");
 
@@ -111,7 +110,6 @@ int main(int argc, char **argv)
     Chain user;
     Chain password;
     
-
 #ifdef HAVE_MINGW
     Chain homeDir(getenv("HOMEPATH"));
     Chain histPath = homeDir + "\\" + Chain(HISTFILE);
@@ -146,7 +144,7 @@ int main(int argc, char **argv)
 
     if ( longOpt.isSet( Chain("version") ) )
     {
-	cout << CEGO_PRODUCT << " Admin Client (" << sizeof(long) * 8 << " bit), Version " << CEGO_VERSION 
+	cout << CEGO_PRODUCT << " Admin Client (" << sizeof(void*) * 8 << " bit), Version " << CEGO_VERSION 
 	     << " [ lfc: " << __lfcVersionString  
 	     << ", lfcxml: " <<  __lfcxmlVersionString << " ]" << endl;
 	cout << CEGO_COPYRIGHT << endl;
@@ -155,6 +153,7 @@ int main(int argc, char **argv)
 
     Chain logFile = longOpt.getOptValue("logfile");
     Chain serverName = longOpt.getOptValue("server");
+    Chain prompt = longOpt.getOptValue("prompt");
     int portNo = longOpt.getOptValue("port").asInteger();
 
     Chain batchFileName;
@@ -171,9 +170,9 @@ int main(int argc, char **argv)
 	command = longOpt.getOptValue("cmd");
     }
 
-    else if ( longOpt.isSet("mon") )
+    else if ( longOpt.isSet("screen") )
     {
-	runMode = MONITOR;
+	runMode = SC;
     }
 
     CegoModule *pModule = 0;
@@ -195,7 +194,7 @@ int main(int argc, char **argv)
 	    throw Exception(EXLOC, "Password not set");
 	       
 	if ( logFile.length() > 0 )
-	    pModule = new CegoModule(logFile, Chain(""));
+	    pModule = new CegoModule(logFile, Chain());
 	else
 	    pModule = new CegoModule();
 		
@@ -206,7 +205,7 @@ int main(int argc, char **argv)
 	else
 	    pModule->logModule(modId, "CegoAdmin", Logger::NOTICE);
 		
-	Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN );
+	Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, NETMNG_MAXSENDLEN );
 	
 	pN = n.connect(serverName, portNo);
 	pAH = new CegoAdminHandler( pModule, pN);
@@ -227,40 +226,30 @@ int main(int argc, char **argv)
 	exit(1);
     }
 
-    pModule->log(modId, Logger::LOGERR, Chain("Got session... "));
-
     CegoAdmAction* pAdm = new CegoAdmAction(pAH, pModule, resultMode, rawMode);
 
     int exitCode = 0;
 
     try
     {
-
 	switch ( runMode )
 	{
-	case MONITOR:
+	case SC:
 	{	    
-#ifndef CGNOCURSES
-	    CegoAdmMon mon(pAH);
-	    mon.showMonitor();
-#else
-	    cout << "Curses not enabled" << endl;
-#endif
+	    CegoAdmScreen screen(pAH);
+	    screen.showScreen();
 	    break;	    	    
 	}
 	case BATCH:
-	{
-	    
+	{	    
 	    int lineNo=0;
-	    
-	    
+	    	    
 	    File batchFile(batchFileName);
 	    
 	    batchFile.open(File::READ);	    
 	    
 	    Chain cmd;
 	    Chain line;
-	    bool disableDelimiter=false;
 	    bool doQuit = false;
 	    
 	    while (doQuit == false && batchFile.readLine(line))
@@ -277,15 +266,14 @@ int main(int argc, char **argv)
 			isCommentLine = true;
 		    }
 		}
+		
 		if ( ! isCommentLine )
-		{
-		    
+		{		    
 		    cmd = cmd + Chain(" ") + line;
 		    cmd = cmd.cutTrailing(" \t");
 		    
 		    if ( cmd.length() > 0 )
-		    {
-			
+		    {			
 			if (cmd.subChain(cmd.length()-1, cmd.length()) == Chain(";")) 
 			{			
 			    try
@@ -305,10 +293,9 @@ int main(int argc, char **argv)
 				if ( ignoreError == true )
 				    cerr << "Ignored" << endl;
 				else
-				    throw Exception(EXLOC, msg);
-				
+				    throw Exception(EXLOC, msg);		
 			    }
-			    cmd = Chain("");			    
+			    cmd = Chain();			    
 			}
 		    }
 		}
@@ -323,28 +310,25 @@ int main(int argc, char **argv)
 	    break;
 	}
 	case COMMAND:
-	{		    
-	    
+	{		    	    
 	    Chain cmd = command.cutTrailing(" ;") + Chain(";");
 	    dispatchCmd(pAdm, cmd);	    
 	    break;
 	}
 	case INTERACTIVE:
-	{
-	    	    	
+	{	    	    	
 	    read_history((char*)histPath);
 	    
 	    bool doQuit = false;
 	    
 	    while ( doQuit == false )
-	    {			    		
-		
+	    {		
 		char *pC = 0;
 		
 		bool isTerminated = false;
 		Chain cs;
 		
-		pC = readline(PROMPT);
+		pC = readline(prompt);
 		
 		if (pC)
 		{
@@ -360,11 +344,9 @@ int main(int argc, char **argv)
 			cs = cs.cutTrailing(Chain(" \t"));
 			
 			if ( cs.length() > 1)
-			{		
-			    
+			{					    
 			    if ( cs[cs.length()-2] == ';')
-			    {
-				
+			    {				
 				try
 				{
 				    doQuit = dispatchCmd(pAdm, cs);
@@ -386,7 +368,14 @@ int main(int argc, char **argv)
 			
 			if ( ! isTerminated )
 			{
-			    pC = readline(PROMPT2);
+			    if ( cs.length() > 1 )
+			    {
+				pC = readline(PROMPT2);
+			    }
+			    else
+			    {
+				pC = readline(prompt);
+			    }
 			    
 			    if (pC)
 			    {
@@ -404,6 +393,8 @@ int main(int argc, char **argv)
 	    break;
 	}
 	}
+
+	pAH->closeSession();	
     }    
     catch ( Exception e)
     {
@@ -413,8 +404,6 @@ int main(int argc, char **argv)
 	exit(1);
     }
     
-    pAH->closeSession();
-    
     delete pAdm;
     delete pAH;
     delete pN;
@@ -425,7 +414,6 @@ int main(int argc, char **argv)
 
 bool dispatchCmd(CegoAdmAction *pAdm, const Chain& cmd)
 {
-
     // check if help is requested
     Tokenizer tok(cmd, " ;");
     Chain hcheck;
@@ -445,8 +433,10 @@ bool dispatchCmd(CegoAdmAction *pAdm, const Chain& cmd)
     
     Timer t(6,3);
     t.start();
-    		    		    
+
+    pAdm->enableAbort(true);
     pAdm->parse();
+    pAdm->enableAbort(false);
     
     t.stop();
     if ( pAdm->getRawMode() == false )
@@ -481,16 +471,22 @@ void helpOverview()
     cout << "   Database administration" << endl;
     cout << "   --------------------" << endl;
     cout << endl;
+    cout << "   [d0] show parameter" << endl;
     cout << "   [d1] show pool" << endl;
     cout << "   [d2] list pool" << endl;
     cout << "   [d3] lockstat" << endl;
-    cout << "   [d4] list < rec | rbrec | sysrec | tp | sp | dp | ix | rb| df | bp | ts > lock" << endl;
+    cout << "   [d4] list < rec | rbrec | sysrec | tp | sp | dp | ix | rb| df | bp | lm | qc | tc > lock" << endl;
     cout << "   [d5] list node" << endl;
     cout << "   [d6] list session" << endl;
     cout << "   [d7] list copy" << endl;
-    cout << "   [d8] threadinfo [ db [threadid] | adm | log ]" << endl;
-    cout << "   [d9] abort db thread <tid>" << endl;
-    
+    cout << "   [d8] threadinfo [ db | adm | log ]" << endl;
+    cout << "   [d9] abort db thread <thridx>" << endl;
+    cout << "   [d10] queryhist thread <thridx>" << endl;
+    cout << "   [d11] queryhist last <numLast>" << endl;
+    cout << "   [d12] queryhist cost <numLast>" << endl;
+    cout << "   [d13] set queryhist last <numLast>" << endl;
+    cout << "   [d14] set queryhist cost <numCost>" << endl;
+
     cout << endl;
     cout << "   Tableset administration" << endl;
     cout << "   -----------------------" << endl;
@@ -498,9 +494,9 @@ void helpOverview()
     cout << "   [t0] list tableset" << endl;
     cout << "   [t1] retrieve tableset from '<hostname>'" << endl;
     cout << "   [t2] define tableset <tableset> <attr1>=<value1> <attr2=value2> ..." << endl;	
-    cout << "   [t3] create tableset" << endl;
+    cout << "   [t3] create tableset <tableset>" << endl;
     cout << "   [t4] show tableset <tableset>" << endl;
-    cout << "   [t5] start tableset <tableset> [ cleanup ] [ forceload ]" << endl;
+    cout << "   [t5] start tableset <tableset> [ cleanup ] [ forceload ] [ cpdump ]" << endl;
     cout << "   [t6] stop tableset <tableset>" << endl;
     cout << "   [t7] copy tableset <tableset>" << endl;
     cout << "   [t8] switch tableset <tableset>" << endl;
@@ -531,13 +527,17 @@ void helpOverview()
     cout << "   [t33] list object for <tableset>" << endl;
     cout << "   [t34] reset tableset <tableset>" << endl;
     cout << "   [t35] [ enable | disable ] querycache for <tableset>" << endl;
+    cout << "   [t47] show querycache for <tableset>" << endl;
     cout << "   [t36] list querycache for <tableset>" << endl;
-    cout << "   [t37] set querycache entry <intval> for <tableset>" << endl;
-    cout << "   [t38] set querycache size <intval> for <tableset>" << endl;
-    cout << "   [t39] [ enable | disable ] tablecache for <tableset>" << endl;
-    cout << "   [t40] list tablecache for <tableset>" << endl;
-    cout << "   [t41] set tablecache entry <intval> for <tableset>" << endl;
-    cout << "   [t42] set tablecache size <intval> for <tableset>" << endl;
+    cout << "   [t37] set querycache maxentry = <intval>, maxsize = <intval>, threshold = <intval>, hashrange = <intval> for <tableset>" << endl;
+    cout << "   [t39] clean querycache for <tableset>" << endl;
+    cout << "   [t40] [ enable | disable ] tablecache for <tableset>" << endl;
+    cout << "   [t48] show tablecache for <tableset>" << endl;
+    cout << "   [t41] list tablecache for <tableset>" << endl;
+    cout << "   [t42] set tablecache filter = '<table filter>' maxentry = <intval>, maxsize = <intval>, hashrange = <intval> for <tableset>" << endl;
+    cout << "   [t44] clean tablecache for <tableset>" << endl;
+    cout << "   [t45] set loguser <username> for <tableset>" << endl;
+    cout << "   [t46] [ enable | disable ] appendmode for <tableset>" << endl;
 
     cout << endl;
     cout << "   User and role administration" << endl;
@@ -561,28 +561,32 @@ void helpOverview()
     cout << "   Backup and Recovery" << endl;
     cout << "   -------------------" << endl;
     cout << "   [b0] set logmng '<progname>' [ timeout <intval> ]" << endl;
-    cout << "   [b1] list archlog for <tableset>" << endl;
-    cout << "   [b2] enable archlog for <tableset>" << endl;
-    cout << "   [b3] enable autocorrect for <tableset>" << endl;
-    cout << "   [b4] disable archlog for <tableset>" << endl;
-    cout << "   [b5] add archlog <archid> path '<archpath>' to <tableset>" << endl;
-    cout << "   [b6] remove archlog <archid> from <tableset>" << endl;
-    cout << "   [b7] begin backup for <tableset> [ message 'system message' ]" << endl;
-    cout << "   [b8] end backup for <tableset> [ message 'system message' ] [ keep ticket ]" << endl;
-    cout << "   [b9] recover tableset <tableset> [ to <point in time> ]" << endl;
-    cout << "   [b10] export [ xml | binary | plain ]  table <table> from <tableset> to '<filename>'" << endl;
-    cout << "   [b11] export [ xml | binary | plain ] tableset [ structure ] <tableset> to '<filename>'" << endl;
-    cout << "   [b12] import [ xml | binary | plain ] table <table> to <tableset> from '<filename>' [ nologging ]" << endl;
-    cout << "   [b13] import [ xml | binary | plain ] tableset [ structure ] <tableset> from '<filename>' [ nologging ]" << endl;
-    cout << "   [b14] list bustat for <tableset>" << endl;
-    cout << "   [b15] reset bustat for <tableset>" << endl;
-    cout << "   [b16] show logmng" << endl;
-    cout << "   [b17] list bufile for <tableset>" << endl;
+    cout << "   [b1] show logmng" << endl;
+    cout << "   [b2] set backupmng '<progname>'" << endl;
+    cout << "   [b3] show backupmng" << endl;
+    cout << "   [b4] list archlog for <tableset>" << endl;
+    cout << "   [b5] enable archlog for <tableset>" << endl;
+    cout << "   [b6] enable autocorrect for <tableset>" << endl;
+    cout << "   [b7] disable archlog for <tableset>" << endl;
+    cout << "   [b8] add archlog <archid> path '<archpath>' to <tableset>" << endl;
+    cout << "   [b9] remove archlog <archid> from <tableset>" << endl;
+    cout << "   [b10] begin backup for <tableset> [ message 'system message' ]" << endl;
+    cout << "   [b11] backup tableset <tableset>" << endl;
+    cout << "   [b12] end backup for <tableset> [ message 'system message' ] [ keep ticket ]" << endl;
+    cout << "   [b13] list backup for <tableset> [ to '<point in time>' ]" << endl;
+    cout << "   [b14] restore tableset <tableset> from '<backupId>'" << endl;
+    cout << "   [b15] recover tableset <tableset> [ to '<point in time>' ]" << endl;
+    cout << "   [b16] export [ xml | binary | plain ]  table <table> from <tableset> to '<filename>'" << endl;
+    cout << "   [b17] export [ xml | binary | plain ] tableset [ structure ] <tableset> to '<filename>'" << endl;
+    cout << "   [b18] import [ xml | binary | plain ] table <table> to <tableset> from '<filename>'" << endl;
+    cout << "   [b19] import [ xml | binary | plain ] tableset [ structure ] <tableset> from '<filename>'" << endl;
+    cout << "   [b20] list bustat for <tableset>" << endl;
+    cout << "   [b21] reset bustat for <tableset>" << endl;
+
     cout << endl;
     cout << "   You can get a detailed help for each command by typing \"help <topic>\"," << endl;
     cout << "   where topic is the identifier in in the square brackets ( e.g. help t1; )" << endl;
     cout << endl;
-
 }
 
 void helpTopic(const Chain& topic)
@@ -596,6 +600,16 @@ void helpTopic(const Chain& topic)
 	cout << "   This might be usedful, if the command output should be parsed by another program" << endl;
 	cout << endl;
     }
+    else if ( topic == Chain("d0"))
+    {
+	cout << endl;
+	cout << "show parameter" << endl;
+	cout << "--------------" << endl;
+	cout << endl;
+	cout << "   This command list the global database parameters, which are valid for all tablesets." << endl;
+	cout << "   Most parameters can be customized in the database xml configuration file, if the database is shutdown" << endl;
+	cout << endl;     
+    }
     else if ( topic == Chain("d1"))
     {
 	cout << endl;
@@ -684,7 +698,7 @@ void helpTopic(const Chain& topic)
     else if ( topic == Chain("d4"))
     {
 	cout << endl;
-	cout << "list < rec | rbrec | sysrec | tp | sp | dp | ix | rb| df | bp | ts > lock" << endl;
+	cout << "list < rec | rbrec | sysrec | tp | sp | dp | ix | rb| df | bp | lm > lock" << endl;
 	cout << "-------------------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   List statistics for specific lock types" << endl;
@@ -699,7 +713,7 @@ void helpTopic(const Chain& topic)
 	cout << "   rb     - rollback page locks" << endl;
 	cout << "   df     - data file locks" << endl;
 	cout << "   bp     - buffer pool locks" << endl;
-	cout << "   ts     - table set locks" << endl;
+	cout << "   lm     - log manager locks" << endl;
 	cout << endl;
     }
     else if ( topic == Chain("d5"))
@@ -710,7 +724,6 @@ void helpTopic(const Chain& topic)
 	cout << endl;
 	cout << "   Lists all known nodes in the database configuration" << endl;
 	cout << endl;
-
     }
     else if ( topic == Chain("d6"))
     {
@@ -732,7 +745,6 @@ void helpTopic(const Chain& topic)
     }
     else if ( topic == Chain("d8"))
     {
-
 	cout << endl;
 	cout << "threadinfo [ db | adm | log]" << endl;
 	cout << "----------------------------" << endl;
@@ -747,12 +759,57 @@ void helpTopic(const Chain& topic)
     else if ( topic == Chain("d9"))
     {
 	cout << endl;
-	cout << "abort db thread <tid>" << endl;
+	cout << "abort db thread <thridx>" << endl;
 	cout << "---------------------" << endl;
 	cout << endl;
 	cout << "   Aborting the actual running query of an active db thread" << endl;
 	cout << endl;
     }
+    else if ( topic == Chain("d10"))
+    {
+	cout << endl;
+	cout << "queryhist thread <thridx>" << endl;
+	cout << "---------------------" << endl;
+	cout << endl;
+	cout << "   Shows the query history for the thread index" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("d11"))
+    {
+	cout << endl;
+	cout << "queryhist last <numLast>" << endl;
+	cout << "---------------------" << endl;
+	cout << endl;
+	cout << "   Shows the last <numLast> queries for all database threads" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("d12"))
+    {
+	cout << endl;
+	cout << "queryhist cost <numLast>" << endl;
+	cout << "---------------------" << endl;
+	cout << endl;
+	cout << "   Shows the <numLast> most expensive queries for all database threads" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("d13"))
+    {
+	cout << endl;
+	cout << "set queryhist last <numLast>" << endl;
+	cout << "---------------------" << endl;
+	cout << endl;
+	cout << "   Setup query last history configuration to <numCost> queries" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("d14"))
+    {
+	cout << endl;
+	cout << "set queryhist cost <numCost>" << endl;
+	cout << "---------------------" << endl;
+	cout << endl;
+	cout << "   Setup query cost history configuration to <numCost> queries" << endl;
+	cout << endl;
+    }
     else if ( topic == Chain("u0"))
     {
 	cout << endl;
@@ -798,7 +855,6 @@ void helpTopic(const Chain& topic)
 	cout << "   Removes the user from the database" << endl;
 	cout << endl;
     }
-
     else if ( topic == Chain("u5"))
     {	
 	cout << endl;
@@ -817,7 +873,6 @@ void helpTopic(const Chain& topic)
 	cout << "   Create the specified role" << endl;
 	cout << endl;
     }
-
     else if ( topic == Chain("u7"))
     {
 	cout << endl;
@@ -864,8 +919,7 @@ void helpTopic(const Chain& topic)
 	cout << "------------------------------" << endl;
 	cout << endl;
 	cout << "   Assigns the given role to the user" << endl;
-	cout << endl;
-	
+	cout << endl;	
     }
     else if ( topic == Chain("u11"))
     {
@@ -884,7 +938,6 @@ void helpTopic(const Chain& topic)
 	cout << endl;
 	cout << "   Drops the specified role" << endl;
 	cout << endl;
-
     }
     else if ( topic == Chain("t0"))
     {
@@ -972,10 +1025,13 @@ void helpTopic(const Chain& topic)
     else if ( topic == Chain("t5"))
     {
 	cout << endl;
-	cout << "start tableset <tableset>" << endl;
-	cout << "-------------------------" << endl;
+	cout << "start tableset <tableset> [ cleanup ] [ forceload ] [ cpdump ]" << endl;
+	cout << "--------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   Starts the specified tableset on the configured primary node." << endl;
+	cout << "   The forceload option enforces an initial load of all available views and procedure." << endl;
+	cout << "   With cpdump, a checkpoint dump is performed, which increases consistency probability in case of system crashs during checkpoints," << endl;
+        cout << "   but also slows down database performance" << endl;
 	cout << endl;
     }
     else if ( topic == Chain("t6"))
@@ -1060,7 +1116,6 @@ void helpTopic(const Chain& topic)
 	cout << "   Adds a new datafile with the specified size to the given tableset" << endl;
 	cout << endl;
     }
-
     else if ( topic == Chain("t16"))
     {
 	cout << endl;
@@ -1119,7 +1174,6 @@ void helpTopic(const Chain& topic)
 	cout << "   To perform this operation, the corresponding tableset must be in status defined" << endl;
 	cout << endl;
     }
-
     else if ( topic == Chain("t22"))
     {
 	cout << endl;
@@ -1178,7 +1232,6 @@ void helpTopic(const Chain& topic)
 	cout << "   Sets the file size in bytes of the redo log files for the correspoinding tableset." << endl;
 	cout << "   To perform this operation, the corresponding tableset must be in status defined" << endl;
 	cout << endl;
-
     }
     else if ( topic == Chain("t28"))
     {
@@ -1212,7 +1265,6 @@ void helpTopic(const Chain& topic)
 	cout << "   List all configured datafiles for the given tableset" << endl;
 	cout << endl;	
     }
-
     else if ( topic == Chain("t31"))
     {
 	cout << endl;
@@ -1266,25 +1318,39 @@ void helpTopic(const Chain& topic)
 	cout << "   Lists all queries, which are available in the query cache" << endl;
 	cout << endl;
     }
+    else if ( topic == Chain("t47"))
+    {
+	cout << endl;
+	cout << "show querycache for <tableset>" << endl;
+	cout << "------------------------------" << endl;
+	cout << endl;
+	cout << "   Lists configuration and usage of querycache for given tableset" << endl;
+	cout << endl;
+    }
     else if ( topic == Chain("t37"))
     {
 	cout << endl;
-	cout << "set querycache entry <intval> for <tableset>" << endl;
+	cout << "set querycache maxentry = <intval>, maxsize = <intval>, threshold = <intval>, hashrange = <intval> for <tableset>" << endl;
 	cout << "--------------------------------------------" << endl;
 	cout << endl;
-	cout << "   Sets the maximum number of entries for the query cache" << endl;
-	cout << endl;
-    }
-    else if ( topic == Chain("t38"))
-    {
-	cout << endl;
-	cout << "set querycache size <intval> for <tableset>" << endl;
-	cout << "-------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Sets the maximum size for a single query cache entry ( in byte )" << endl;
+	cout << "   Setup parameter values for the query cache of the given tableset." << endl;
+	cout << "   The maxentry value is the maximum number of cached entries." << endl;		
+	cout << "   The maxsize value gives the maximum entry size for the result set of an entry ( in byte )." << endl;
+	cout << "   The threshold value gives the minimum execution time, from which queries should be cached ( in msec )." << endl;
+	cout << "   The hashsize specifies the hash range where entries can be stored in the array." << endl;
+	cout << "   The tableset has to be restarted to active the current parameter settings" << endl;
 	cout << endl;
     }
     else if ( topic == Chain("t39"))
+    {
+	cout << endl;
+	cout << "clean querycache for <tableset>" << endl;
+	cout << "-------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Removes all caches query entries for the given tableset" << endl;
+	cout << endl;
+    }    
+    else if ( topic == Chain("t40"))
     {
 	cout << endl;
 	cout << "[ enable | disable ] tablecache for <tableset>" << endl;
@@ -1293,7 +1359,16 @@ void helpTopic(const Chain& topic)
 	cout << "   Enables or disables table cache for given tableset" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("t40"))
+    else if ( topic == Chain("t48"))
+    {
+	cout << endl;
+	cout << "show tablecache for <tableset>" << endl;
+	cout << "------------------------------" << endl;
+	cout << endl;
+	cout << "   Lists configuration and usage of tablecache for given tableset" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("t41"))
     {
 	cout << endl;
 	cout << "list tablecache for <tableset>" << endl;
@@ -1302,22 +1377,45 @@ void helpTopic(const Chain& topic)
 	cout << "   Lists all tables, which are available in the table cache" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("t41"))
-    {
-	cout << endl;
-	cout << "set tablecache entry <intval> for <tableset>" << endl;
-	cout << "--------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Sets the maximum number of entries for the table cache" << endl;
-	cout << endl;
-    }
     else if ( topic == Chain("t42"))
     {
 	cout << endl;
-	cout << "set tablecache size <intval> for <tableset>" << endl;
+	cout << "set tablecache filter = '<table filter>' maxentry = <intval>, maxsize = <intval>, hashrange = <intval> for <tableset>" << endl;
+	cout << "--------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Setup parameter values for the table cache of the given tableset." << endl;
+	cout << "   The filter value specifies the relevent set of cached tables." << endl;		
+	cout << "   The maxentry value is the maximum number of cached entries." << endl;		
+	cout << "   The maxsize value gives the maximum entry size for the result set of an entry ( in byte )." << endl;
+	cout << "   The hashsize specifies the hash range where entries can be stored in the array." << endl;
+	cout << "   The tableset has to be restarted to active the current parameter settings" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("t44"))
+    {
+	cout << endl;
+	cout << "clean tablecache for <tableset>" << endl;
 	cout << "-------------------------------------------" << endl;
 	cout << endl;
-	cout << "   Sets the maximum siue for a single table cache entry ( in byte )" << endl;
+	cout << "   Removes all table query entries for the given tableset" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("t45"))
+    {
+	cout << endl;
+	cout << "set loguser <username> for <tableset>" << endl;
+	cout << "-------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Sets the username, which is used to establish a log connection to the secondary node" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("t46"))
+    {
+	cout << endl;
+	cout << "[ enable | disable ] appendmode for <tableset>" << endl;
+	cout << "-------------------------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Enables od disables append mode at default for the given tableset." << endl;
 	cout << endl;
     }
     else if ( topic == Chain("b0"))
@@ -1328,6 +1426,32 @@ void helpTopic(const Chain& topic)
 	cout << endl;
     }
     else if ( topic == Chain("b1"))
+    {
+	cout << endl;
+	cout << "show logmng" << endl;
+	cout << "-----------------------------------------------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Prints the current log manager configuration" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("b2"))
+    {
+	cout << endl;
+	cout << "set backupmng '<progname>'" << endl;
+	cout << "-------------------------------------------------------------" << endl;
+	cout << "   Sets up the backup manager program, which should be triggered for backups and restores" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("b3"))
+    {
+	cout << endl;
+	cout << "show backupmng" << endl;
+	cout << "-----------------------------------------------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Prints the current configured backup manager program" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("b4"))
     {
 	cout << endl;
 	cout << "list archlog" << endl;
@@ -1336,7 +1460,7 @@ void helpTopic(const Chain& topic)
 	cout << "   List all configured archive log locations for the given tableset" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b2"))
+    else if ( topic == Chain("b5"))
     {
 	cout << endl;
 	cout << "enable archlog for <tableset>" << endl;
@@ -1346,16 +1470,7 @@ void helpTopic(const Chain& topic)
 	cout << "   At least one valid archive log location must be defined to enable archive log mode" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b3"))
-    {
-	cout << endl;
-	cout << "enable autocorrect for <tableset>" << endl;
-	cout << "-------------------------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Enables automatic index correction for the given tableset." << endl;
-	cout << endl;
-    }
-    else if ( topic == Chain("b4"))
+    else if ( topic == Chain("b7"))
     {	
 	cout << endl;
 	cout << "disable archlog for <tableset>" << endl;
@@ -1364,7 +1479,7 @@ void helpTopic(const Chain& topic)
 	cout << "   Disables archive log mode for the given tableset." << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b5"))
+    else if ( topic == Chain("b8"))
     {
 	cout << endl;
 	cout << "add archlog <archid> path '<archpath>' to <tableset>" << endl;
@@ -1373,7 +1488,7 @@ void helpTopic(const Chain& topic)
 	cout << "   Adds the specified archlog destination to the given tableset" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b6"))
+    else if ( topic == Chain("b9"))
     {
 	cout << endl;
 	cout << "remove archlog <archlog> from <tableset>" << endl;
@@ -1381,10 +1496,10 @@ void helpTopic(const Chain& topic)
 	cout << "   Removes the specified archlog destination from the given tableset" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b7"))
+    else if ( topic == Chain("b10"))
     {
 	cout << endl;
-	cout << "begin backup for <tableset>" << endl;
+	cout << "begin backup for <tableset> [ message 'message string' ]" << endl;
 	cout << "-------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   Starts online backup mode for the given tableset" << endl;
@@ -1392,17 +1507,47 @@ void helpTopic(const Chain& topic)
 	cout << "   If any recovery is required, the original page is restored during logfile recovery" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b8"))
+    else if ( topic == Chain("b11"))
     {
 	cout << endl;
-	cout << "end backup for <tableset>" << endl;
+	cout << "backup tableset <tableset>" << endl;
+	cout << "-------------------------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Performs a backup of the given tableset using the configured backup manager" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("b12"))
+    {
+	cout << endl;
+	cout << "end backup for <tableset> [ message 'message string' ]" << endl;
 	cout << "-------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   Finishes online backup mode for the given tableset" << endl;
 	cout << "   Normally this is done, after backup has been finished for all datafiles." << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b9"))
+    else if ( topic == Chain("b13"))
+    {
+	cout << endl;
+	cout << "list backup for <tableset>" << endl;
+	cout << "-----------------------------------------------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Lists all relevant files for an online backup for the given tableset" << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("b14"))
+    {
+	cout << endl;
+	cout << "restore tableset <tableset> from '<BackupId>'" << endl;
+	cout << "-------------------------------------------------------------" << endl;
+	cout << endl;
+	cout << "   Restores all required data files from a previously performed backup." << endl;
+	cout << "   A list of avaiable backups can be retrieved with the 'list backup' command ( b13 )" << endl;
+	cout << "   where each backup can be identified by a unique backup id" << endl;
+	cout << "   The corresponding tableset must be in status offline perform this action." << endl;
+	cout << endl;
+    }
+    else if ( topic == Chain("b15"))
     {
 	cout << endl;
 	cout << "recover tableset <tableset> [ to <point in time>]" << endl;
@@ -1412,17 +1557,17 @@ void helpTopic(const Chain& topic)
 	cout << "   The corresponding tableset must be in status offline perform this action." << endl;
 	cout << "   All required backup datafiles and offline redo logs have to be provided in the appropriate locations." << endl;
 	cout << "   If an online backup should be restored, a valid backup ticket file has to be provided." << endl;
+	cout << "   This can be done in a convenient way by using the 'restore tableset' command." << endl;
 	cout << endl;
 	cout << "   If point-in-time is used, an appropriate time stamp has to be provided with the server supported date format." << endl;
 	cout << "   The default format value is <dd.mm.YYYY HH:MM:SS>" << endl;
 	cout << endl;
-	cout << "   Sample : recover tableset TS1 to '08:12:34 09.07.2016';" << endl;
+	cout << "   Sample : recover tableset TS1 to '09.07.2016 08:12:34';" << endl;
 	cout << endl;
-	cout << "   After the ceovery has been finished, the corresponding tableset can be started up." << endl;
+	cout << "   After the recovery has been finished succesful, the corresponding tableset is online." << endl;
 	cout << endl;
     }
-
-    else if ( topic == Chain("b10"))
+    else if ( topic == Chain("b16"))
     {
 	cout << endl;
 	cout << "export [ xml | binary | plain ] table <tablename> from <tableset> to '<filename>'" << endl;
@@ -1432,7 +1577,7 @@ void helpTopic(const Chain& topic)
 	cout << "   Either xml, binary or plain export mode can be used. If no mode is specified, xml mode is used." << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b11"))
+    else if ( topic == Chain("b17"))
     {
 	cout << endl;
 	cout << "export [ xml | binary | plain ] tableset [ structure ] <tableset> to '<filename>'" << endl;
@@ -1442,25 +1587,22 @@ void helpTopic(const Chain& topic)
 	cout << "   This includes all defined user objects of the tableset." << endl;
 	cout << "   If the structure option is given, no table content is exported." << endl;
 	cout << "   Either xml, binary or plain export mode can be used. If no mode is specified, xml mode is used." << endl;
-	cout << endl;
-	
+	cout << endl;	
     }
-    else if ( topic == Chain("b12"))
+    else if ( topic == Chain("b18"))
     {
 	cout << endl;
-	cout << "import [ xml | binary | plain ] table <tablename> to <tableset> from '<filename>' [ nologging ]" << endl;
+	cout << "import [ xml | binary | plain ] table <tablename> to <tableset> from '<filename>'" << endl;
 	cout << "-----------------------------------------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   Import of a single table from the given export file to the given tableset ." << endl;
 	cout << "   Either xml, binary or plain export mode can be used. If no mode is specified, xml mode is used." << endl;
 	cout << endl;
-	cout << "   If the nologging option is added, the online redo log writing is disabled. This results in better import performance." << endl;
-	cout << endl;
     }
-    else if ( topic == Chain("b13"))
+    else if ( topic == Chain("b19"))
     {
 	cout << endl;
-	cout << "import [ xml | binary | plain ] tableset [ structure ] <tableset> from '<filename>' [ nologging ]" << endl;
+	cout << "import [ xml | binary | plain ] tableset [ structure ] <tableset> from '<filename>'" << endl;
 	cout << "-------------------------------------------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   Import of a tableset from an export file." << endl;
@@ -1468,10 +1610,8 @@ void helpTopic(const Chain& topic)
 	cout << "   If the structure option is given, no table content is imported." << endl;
 	cout << "   Either xml, binary or plain export mode can be used. If no mode is specified, xml mode is used." << endl;
 	cout << endl;
-	cout << "   If the nologging option is added, the online redo log writing is disabled. This results in better import performance." << endl;
-	cout << endl;
     }
-    else if ( topic == Chain("b14"))
+    else if ( topic == Chain("b20"))
     {
 	cout << endl;
 	cout << "list bustat for <tableset>" << endl;
@@ -1480,7 +1620,7 @@ void helpTopic(const Chain& topic)
 	cout << "   Lists the online backup statistics for the given tableset." << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b15"))
+    else if ( topic == Chain("b21"))
     {
 	cout << endl;
 	cout << "reset bustat for <tableset>" << endl;
@@ -1489,24 +1629,6 @@ void helpTopic(const Chain& topic)
 	cout << "   Resets the online backup statistics for the given tableset." << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("b16"))
-    {
-	cout << endl;
-	cout << "show logmng" << endl;
-	cout << "-----------------------------------------------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Prints the current log manager configuration" << endl;
-	cout << endl;
-    }
-    else if ( topic == Chain("b17"))
-    {
-	cout << endl;
-	cout << "list bufile for <tableset>" << endl;
-	cout << "-----------------------------------------------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Lists all relevant files for an online backup for the given tableset" << endl;
-	cout << endl;
-    }
     else
     {
 	helpOverview();
