@@ -27,6 +27,7 @@
 
 CegoAttrCond::CegoAttrCond()
 {
+    _isAnd=true;
 }
 
 CegoAttrCond::~CegoAttrCond()
@@ -51,8 +52,15 @@ Chain CegoAttrCond::getId() const
 void CegoAttrCond::add(const CegoAttrComp& attrComp)
 {
     CegoAttrComp *pAC;
-    if ( (pAC = _attrCompSet.Find(attrComp)) == 0 )
-    {	
+    if ( _isAnd )
+    {
+	if ( (pAC = _attrCompSet.Find(attrComp)) == 0 )
+	{	
+	    _attrCompSet.Insert(attrComp);
+	}
+    }
+    else
+    {
 	_attrCompSet.Insert(attrComp);
     }
 }
@@ -93,10 +101,32 @@ const TreeT<CegoAttrComp>& CegoAttrCond::getAttrCompSet() const
     return _attrCompSet;
 }
 
+void CegoAttrCond::clean()
+{
+    _attrCompSet.Empty();
+}
+
+bool CegoAttrCond::hasIndexCandidate()
+{
+    CegoAttrComp *pAC = _attrCompSet.First();
+    while ( pAC )
+    {
+	if ( pAC->getCompMode() == CegoAttrComp::VAL
+	     || pAC->getCompMode() == CegoAttrComp::ATTR
+	     || pAC->getCompMode() == CegoAttrComp::BTWN )
+	    return true;
+	
+	pAC = _attrCompSet.Next();
+    }
+    return false;
+}
+
 CegoAttrCond CegoAttrCond::getFilterCond(const ListT<CegoField>& fl, bool ignoreNullComp) const
 {
     CegoAttrCond ac;
 
+    ac.setAnd(_isAnd);
+    
     CegoField *pF = fl.First();
     while ( pF)
     {	
@@ -120,7 +150,9 @@ CegoAttrCond CegoAttrCond::getFilterCond(const ListT<CegoField>& fl, bool ignore
 CegoAttrCond CegoAttrCond::getIndexCond(const ListT<CegoField>& fl) const
 { 
     CegoAttrCond ac;
- 
+
+    ac.setAnd(_isAnd);
+    
     int pos = 0;
     CegoField *pF = fl.First();
  
@@ -221,78 +253,143 @@ bool CegoAttrCond::setup(ListT<CegoField>** pParentJoinBuf, int parentOffset, Li
 /*
   asConjunctionList returns for the given instance a list of predicates, which are needed for 
   CegoSelect to build up joins.
-  For this, each comparison is checked 
-
+  For this, each comparison is checked
+  From cego serion 2.52.23 and up, _isAnd flag is treated. If set to false, this is a disjunction and we have to return false
  */
+
 bool CegoAttrCond::asConjunctionList(const ListT<CegoExpr*>& exprList, ListT<CegoPredicate*>& conjunctionList) const
 {
-    bool isComplete = true;
-    
-    CegoAttrComp *pAC = _attrCompSet.First();
-    while ( pAC )
+    if ( _isAnd == true )
+    {	
+	bool isComplete = true;
+		
+	CegoAttrComp *pAC = _attrCompSet.First();
+	while ( pAC )
+	{
+	    CegoPredicate *pPred = getPred4Comp(exprList, pAC);
+
+	    if ( pPred )		
+		conjunctionList.Insert(pPred);
+	    else
+		isComplete=false;
+	    
+	    pAC = _attrCompSet.Next();
+	}
+	
+	return isComplete;
+    }
+    else
     {
 
-	// Get an expression clone for the view condition attribute alias 
-	CegoExpr *pExpr = getExpressionForAlias(exprList, pAC->getAttrName() );
-
-	if ( pExpr == 0 )
+	/* in case of _isAnd = false, we expect a straight list of compares for the same attribute
+	   as constructed for CegoPredicate::CompMode = IN
+	   So we construct in a reverse way the corresponding predicate for the view
+	 */
+	
+	CegoPredicate* pPred;
+	CegoExpr *pExpr = 0;
+	ListT<CegoExpr*> inExprList;
+	
+	CegoAttrComp *pAC = _attrCompSet.First();
+	while ( pAC )
 	{
-	    // if there is no alias, we assume this a an outer attribute reference from the view caller
-	    pExpr = new CegoExpr(new CegoTerm(new CegoFactor( new CegoAttrDesc(pAC->getAttrName()))));
+	    if ( pExpr == 0 )
+	    {
+		pExpr = getExpressionForAlias(exprList, pAC->getAttrName());		
+		if ( pExpr == 0 ) 
+		    pExpr = new CegoExpr(new CegoTerm(new CegoFactor( new CegoAttrDesc(pAC->getAttrName()))));
+	    }
+
+	    CegoExpr* pInExpr =  new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue())));
+	    inExprList.Insert(pInExpr);
+
+	    pAC = _attrCompSet.Next();
 	}
 
-	// we have to check for an aggregation in expression
-	// if so we have to skip this compare and return complete = false
-	if ( pExpr->getAggregationList().isEmpty() == false )
-	{
-	    isComplete = false;	    
-	}
-	else
-	{
+	pPred = new CegoPredicate(pExpr, inExprList, false);
 
-	    // Depending on the attribute comparison mode, an appropriate predicate is
-	    // build up
-	    CegoPredicate *pP;	    
-	    
-	    if ( pAC->getCompMode() == CegoAttrComp::ATTR && pAC->isSetup() == false )   
-	    {
-		CegoExpr* pExternExpr = new CegoExpr(new CegoTerm(new CegoFactor( pAC->getAttrDesc().clone())));
-		pP = new CegoPredicate(pExpr,
-				      pExternExpr,
-				      pAC->getComparison());		
-	    }
-	    else if ( pAC->getCompMode() == CegoAttrComp::VAL || 
-		      ( pAC->getCompMode() == CegoAttrComp::ATTR && pAC->isSetup() ) )
-	    {
-		pP = new CegoPredicate(pExpr,
-				      new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue()))),
-				      pAC->getComparison());
-	    }
-	    else if ( pAC->getCompMode() == CegoAttrComp::BTWN )
-	    {
-		pP = new CegoPredicate(pExpr,
-				      new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue()))),
-				      new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue2()))));
-	    }
-	    else if ( pAC->getCompMode() == CegoAttrComp::ISLIKE )
-	    {
-		pP = new CegoPredicate(pExpr,
-				      pAC->getPattern(),
-				      false);
-	    }
-	    else if ( pAC->getCompMode() == CegoAttrComp::ISNOTLIKE )
-	    {
-		pP = new CegoPredicate(pExpr,
-				      pAC->getPattern(),
-				      true);
-	    }	    
-	    conjunctionList.Insert(pP);
-	}
-	pAC = _attrCompSet.Next();
+	conjunctionList.Insert(pPred);
+	
+	return true;
     }
-    return isComplete;
 }
 
+
+CegoPredicate* CegoAttrCond::getPred4Comp(const ListT<CegoExpr*> exprList, CegoAttrComp* pAC) const
+{
+    
+    // Get an expression clone for the view condition attribute alias 
+    CegoExpr *pExpr = getExpressionForAlias(exprList, pAC->getAttrName() );
+    
+    if ( pExpr == 0 )
+    {
+	// if there is no alias, we assume this a an outer attribute reference from the view caller
+	pExpr = new CegoExpr(new CegoTerm(new CegoFactor( new CegoAttrDesc(pAC->getAttrName()))));
+    }
+    
+    // we have to check for an aggregation in expression
+    // if so we have to skip this compare and return complete = false
+    if ( pExpr->getAggregationList().isEmpty() == false )
+    {
+	return 0;
+	// isComplete = false;
+    }
+    else
+    {
+	
+	// Depending on the attribute comparison mode, an appropriate predicate is
+	// build up
+	CegoPredicate *pP;	    
+	
+	if ( pAC->getCompMode() == CegoAttrComp::ATTR && pAC->isSetup() == false )   
+	{
+	    CegoExpr* pExternExpr = new CegoExpr(new CegoTerm(new CegoFactor( pAC->getAttrDesc().clone())));
+	    pP = new CegoPredicate(pExpr,
+				   pExternExpr,
+				   pAC->getComparison());		
+	}
+	else if ( pAC->getCompMode() == CegoAttrComp::VAL || 
+		  ( pAC->getCompMode() == CegoAttrComp::ATTR && pAC->isSetup() ) )
+	{
+	    pP = new CegoPredicate(pExpr,
+				   new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue()))),
+				   pAC->getComparison());
+	}
+	else if ( pAC->getCompMode() == CegoAttrComp::BTWN )
+	{
+	    pP = new CegoPredicate(pExpr,
+				   new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue()))),
+				   new CegoExpr(new CegoTerm(new CegoFactor( pAC->getFieldValue2()))));
+	}
+	else if ( pAC->getCompMode() == CegoAttrComp::ISLIKE )
+	{
+	    pP = new CegoPredicate(pExpr,
+				   pAC->getPattern(),
+				   false, true);
+	}
+	else if ( pAC->getCompMode() == CegoAttrComp::ISNOTLIKE )
+	{
+	    pP = new CegoPredicate(pExpr,
+				   pAC->getPattern(),
+				   true, true);
+	}
+	else if ( pAC->getCompMode() == CegoAttrComp::ISNCLIKE )
+	{
+	    pP = new CegoPredicate(pExpr,
+				   pAC->getPattern(),
+				   false, false);
+	}
+	else if ( pAC->getCompMode() == CegoAttrComp::ISNOTNCLIKE )
+	{
+	    pP = new CegoPredicate(pExpr,
+				   pAC->getPattern(),
+				   true, false);
+	}
+
+	return pP;
+    }
+}	
+	
 CegoExpr* CegoAttrCond::getExpressionForAlias(const ListT<CegoExpr*>& exprList, const Chain& alias) const
 {
     CegoExpr **pExpr = exprList.First();
@@ -349,11 +446,13 @@ CegoAttrCond::IndexMatch CegoAttrCond::checkIndex(const ListT<CegoField>& schema
     
     return INAPP;
 }
-    
+
+/*
 void CegoAttrCond::setIdxSchema(const ListT<CegoField>& schema)
 {
     _idxSchema = schema;
 }
+*/
 
 void CegoAttrCond::setPrimaryComparison(CegoComparison comp)
 {
@@ -468,10 +567,43 @@ void CegoAttrCond::update( const CegoAttrCond& ac )
     }
 }
 
+void CegoAttrCond::setAnd(bool isAnd)
+{
+    _isAnd = isAnd;
+}
+
+bool CegoAttrCond::isAnd() const
+{
+    return _isAnd;
+}
+	
+ListT<CegoAttrCond> CegoAttrCond::getAndCondList() const
+{
+    ListT<CegoAttrCond> condList;
+
+    if ( _isAnd == false )
+    {		
+	CegoAttrComp *pAC = _attrCompSet.First();
+	while ( pAC )
+	{	
+	    CegoAttrCond ac;
+	    ac.add(*pAC);
+	    condList.Insert(ac);
+	    pAC = _attrCompSet.Next();
+	}
+	return condList;
+    }
+    else
+    {
+	throw Exception(EXLOC, Chain("Condition list is already and list"));
+    }
+}
+
 CegoAttrCond& CegoAttrCond::operator = ( const CegoAttrCond& ac)
 {
-    _idxSchema = ac._idxSchema;
+    // _idxSchema = ac._idxSchema;
     _attrCompSet = ac._attrCompSet;
+    _isAnd = ac._isAnd;
     return (*this);
 }
 
@@ -534,7 +666,12 @@ Chain CegoAttrCond::toChain() const
 	s += pAC->toChain();
 	pAC = _attrCompSet.Next();
 	if ( pAC )
-	    s += Chain(" and ");
+	{
+	    if ( _isAnd )
+		s += Chain(" and ");
+	    else
+		s += Chain(" or ");
+	}
     }
     return s;
 }
