@@ -8,7 +8,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -36,7 +36,7 @@ class CegoAttrDesc {
 public:
 
     CegoAttrDesc();
-    CegoAttrDesc(Element *pADE);
+    CegoAttrDesc(char *buf);
     CegoAttrDesc(const Chain& attrName);
     CegoAttrDesc(const Chain& tableName, const Chain& attrName, bool isValid = false);
     ~CegoAttrDesc();
@@ -53,16 +53,13 @@ public:
     CegoAttrDesc* clone() const;
 
     CegoAttrDesc& operator = ( const CegoAttrDesc& ad);
-    bool operator == ( const CegoAttrDesc& ad);
-    bool operator != ( const CegoAttrDesc& ad);
+    bool operator == ( const CegoAttrDesc& ad) const;
+    bool operator != ( const CegoAttrDesc& ad) const;
 
     Chain getId() const;
     Chain toChain() const;
     Chain dbFormat(CegoDatabaseFormater* pForm) const;
-	
-    Element* toElement() const;
-    void fromElement(Element *pAttrDescElement);
-
+    
     void encode(char *buf);
     void decode(char *buf);
     int getEncodingLength() const;
