@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -25,6 +25,7 @@
 #include <lfcbase/ListT.h>
 
 // CEGO INCLUDES
+#include "CegoDefs.h"
 #include "CegoField.h"
 #include "CegoBTreeValue.h"
 #include "CegoDataPointer.h"
@@ -39,37 +40,30 @@ public:
     CegoBTreeNode();
     ~CegoBTreeNode();
     
-    void setType(NodeType nt);
     const NodeType getType() const;
 
     void setPtr(void* p, int len);
     void* getPtr();
     int getLen() const;
 
-    void setFileId(int fileId);
-    int getFileId() const;
+    void setPageId(PageIdType pageId);
+    PageIdType getPageId() const;
 
-    void setPageId(int pageId);
-    int getPageId() const;
-
-    void setNextFileId(int fileId);
-    int getNextFileId() const;
-
-    void setNextPageId(int pageId);
-    int getNextPageId() const;
+    void setNextPageId(PageIdType pageId);
+    PageIdType getNextPageId() const;
 
     void initNode();
 
-    int maxEntries() const;
     int numEntries() const;
 
-    void getChildPage(const CegoBTreeValue& iv, int& fileId, int& pageId);
+    void getChildPage(const CegoBTreeValue& iv, PageIdType& pageId, bool traceMin);
 
-    void setSchema(ListT<CegoField>* pSchema, int keyLen);
+    void setSchema(NodeType nt, ListT<CegoField>* pSchema, int keyLen);
 
-    bool addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp, const Chain& btreeName, bool isUnique, CegoObjectManager *pOM, int tabSetId, unsigned long long tid, bool& duplicateAdded);
+    bool valueExists(const CegoBTreeValue& iv, CegoObjectManager *pOM, int tabSetId, unsigned long long tid) const;
+
+    bool addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp);
     bool deleteValue(const CegoBTreeValue& iv, const CegoDataPointer& dp);
-    bool valueExists(const CegoBTreeValue& iv);
     bool addNode(const CegoBTreeValue& iv, const CegoBTreeNode& node);
     bool propagate(const CegoBTreeValue& iv, const CegoBTreeNode& leftNode, const CegoBTreeNode& rightNode);
 
@@ -84,38 +78,41 @@ public:
     CegoBTreeNode& operator = (const CegoBTreeNode& n);
 
     bool verify();
-    
+    bool verifyLeafFull(int tabSetId, CegoObjectManager *pOM);
+	
     void printNode(int level = 0);
     
     void reset();
-    bool nextChildPointer(int& fileId, int &pageId);
+    void setPosition(int pos);
+    bool nextChildPointer(PageIdType &pageId);
 
-    void getLastChildPointer(int& fileId, int &pageId) const;
-    void setFirstChildPointer(int fileId, int pageId);
+    int getMedPage(int lb, int rb, PageIdType& pageId);
+    bool rightValue(int pos, CegoBTreeValue& val);
+
+    void getLastChildPointer(PageIdType &pageId) const;
+    void setFirstChildPointer(PageIdType pageId);
 
     bool rightChild(CegoBTreeValue& val);
 
+    void getValue(int pos, CegoBTreeValue& val, CegoDataPointer& dp);    
     bool nextValue(CegoBTreeValue& val, CegoDataPointer& dp);    
 
 private:
 
-    bool checkForDeleted(CegoObjectManager* pOM, const CegoDataPointer &dp, int tabSetId, unsigned long long tid);
-
-    bool valueExists(const CegoBTreeValue& iv, CegoDataPointer& dp);
+    bool isTupleVisible(CegoObjectManager* pOM, const CegoDataPointer &dp, int tabSetId, unsigned long long tid) const;
     
     void shiftEntries(int pos, int offset);
     int getEntrySize() const;
 
     Chain levelIndent(int level);
 
-    int _fileId;
-    int _pageId;
-
-    int _nextFileId;
-    int _nextPageId;
+    PageIdType _pageId;
+    PageIdType _nextPageId;
 
     ListT<CegoField>* _pSchema;
     int _keyLen;
+    int _entrySize;
+    int _maxEntries;
     NodeType _nt;
     void* _pI;
     int _len;
