@@ -1,12 +1,12 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                         
 // CegoBeatConnection.cc
-// -------------------------
+// ---------------------
 // Cego mediator connection class implementation
 //      
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -118,7 +118,7 @@ void CegoBeatConnection::beat(const ListT<Chain>& tsList, const ListT<Chain>& ru
 
 void CegoBeatConnection::connect()
 {
-    Net n ( NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN );   
+    Net n ( NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, NETMNG_MAXSENDLEN );   
     _pN = n.connect(_hostName, _portNo);
     _pAdminHandle = new CegoAdminHandler(_pDBMng, _pN);
     _pAdminHandle->requestSession(_user, _passwd, false);
@@ -126,10 +126,8 @@ void CegoBeatConnection::connect()
 
 void CegoBeatConnection::disconnect()
 {
-    
     if ( _pAdminHandle )
 	_pAdminHandle->closeSession();
-
 }
 
 CegoBeatConnection& CegoBeatConnection::operator = ( const CegoBeatConnection& mc )
