@@ -6,7 +6,7 @@
 //
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -50,7 +50,7 @@
 #define DEFAULTPROGID "cgblow"
 #define DEFAULTINTERVAL 1
 
-enum Operation { INSERT_OP, DELETE_OP, UPDATE_OP, ARB1_OP, ARB2_OP, ARB3_OP, PROC_OP, BLOB_OP }; 
+enum Operation { INSERT_OP, DELETE_OP, UPDATE_OP, ARB1_OP, ARB2_OP, ARB3_OP, PROC_OP, BLOB_OP, NONE_OP }; 
 
 #define INTCOL "i" 
 #define STRCOL "s" 
@@ -61,7 +61,7 @@ enum Operation { INSERT_OP, DELETE_OP, UPDATE_OP, ARB1_OP, ARB2_OP, ARB3_OP, PRO
           --user=<user>/<password>\n\
           [ --server=<host>]\n\
           [ --port=<port> ]\n\
-          [ --protocol={serial|xml} ]\n\
+          [ --protocol={serial|fastserial|xml} ]\n\
           [ --iset=<insert format> ] [ --pset=<proc format> ] [ --dcond=<delete condition> ] [ --uset=<update format> ] [ --ucond=<update condition>] [ --blobop=<format> ] \n\
           [ --count=<number of operations> ]\n\
           [ --proc=<procname> ]\n\
@@ -77,8 +77,8 @@ extern char __lfcxmlVersionString[];
 
 int main(int argc, char **argv) 
 { 
-    try { 
-	
+    try
+    { 	
 	GetLongOpt longOpt(argc, argv);
 
 	longOpt.addOpt("version");
@@ -188,7 +188,7 @@ int main(int argc, char **argv)
 	unsigned long long count = longOpt.getOptValue("count").asUnsignedLongLong();
 	int interval = longOpt.getOptValue("interval").asInteger();
 
-	Operation op;    
+	Operation op = NONE_OP;    
 	if ( mode == Chain("insert") )
 	{
 	    op=INSERT_OP;
@@ -235,6 +235,10 @@ int main(int argc, char **argv)
 	{
 	    protType = CegoDbHandler::SERIAL;
 	}
+	else if ( prot == Chain("fastserial") )
+	{
+	    protType = CegoDbHandler::FASTSERIAL;
+	}
 	else if ( prot == Chain("xml") )
 	{
 	    protType = CegoDbHandler::XML;
@@ -251,7 +255,7 @@ int main(int argc, char **argv)
 	{
 	    Chain logMode("notice");
 	    Chain logFile; // no logfile
-	    pCegoNet = new CegoNet( protType, logFile, Chain(""), logMode );	    
+	    pCegoNet = new CegoNet( protType, logFile, Chain(), logMode );	    
 	    pCegoNet->connect(serverName, dataPort, tableSet, user, password);
 	}
 		
@@ -264,8 +268,7 @@ int main(int argc, char **argv)
 	    else
 		cmd = "set append off;";
 	 
-	    dispatchCmd(pCegoNet, cmd);
-	    
+	    dispatchCmd(pCegoNet, cmd);	    
 	}
 	
 	Timer tim1(6,3);
@@ -283,12 +286,12 @@ int main(int argc, char **argv)
 	unsigned long long numInsert=0;
 	unsigned long long numUpdate=0;
 	unsigned long long numDelete=0;
-	unsigned long long  numCall=0;
+	unsigned long long numCall=0;
+	unsigned long long numSuccess=0;
 	
 	for ( unsigned long long i=1; i<=count; i++ ) 
-	{ 
-	    
-	    Operation actOp;
+	{	    
+	    Operation actOp = NONE_OP;
 	    if ( op == INSERT_OP )
 		actOp = INSERT_OP;
 	    else if ( op == DELETE_OP )
@@ -304,7 +307,7 @@ int main(int argc, char **argv)
 		int m = random() % 2;
 		if ( m == 0 )
 		    actOp = INSERT_OP;
-		else if ( m == 1 )
+		else
 		    actOp = DELETE_OP;
 	    }
 	    else if ( op == ARB2_OP )
@@ -314,7 +317,7 @@ int main(int argc, char **argv)
 		    actOp = INSERT_OP;
 		else if ( m == 1 )
 		    actOp = DELETE_OP;
-		else if ( m == 2 )
+		else
 		    actOp = UPDATE_OP;
 	    }
 	    else if ( op == ARB3_OP )
@@ -326,7 +329,7 @@ int main(int argc, char **argv)
 		    actOp = DELETE_OP;
 		else if ( m == 2 )
 		    actOp = UPDATE_OP;
-		else if ( m == 3 )
+		else
 		    actOp = PROC_OP;
 	    }
 
@@ -343,8 +346,7 @@ int main(int argc, char **argv)
 		{ 
 		    // cout << "col is " << col << endl; 
 		    if ( col[0] == 'i' ) 
-		    { 
-			
+		    { 			
 			Tokenizer tok(col, Chain(":")); 
 			Chain s, len; 
 			tok.nextToken(s); 
@@ -353,8 +355,7 @@ int main(int argc, char **argv)
 			cmd += Chain(random() % l); 
 		    } 
 		    else if ( col[0] == 's' )
-		    { 
-			
+		    { 	       	
 			Tokenizer tok(col, Chain(":")); 
 			Chain s, len; 
 			tok.nextToken(s); 
@@ -386,13 +387,13 @@ int main(int argc, char **argv)
 			{
 			    pCegoNet->putBlob(blob);
 			
-			    cout << "Blob stored to " << blob.getFileId() << " " << blob.getPageId() << endl;
+			    cout << "Blob stored to [" << blob.getPageId() << "]" << endl;
 			}
 			else
 			{
 			    cout << "put blob .." << endl;
 			}
-			cmd += Chain("[") + Chain(blob.getFileId()) + Chain(",") + Chain(blob.getPageId()) + Chain("]"); 
+			cmd += Chain("[") + Chain(blob.getPageId()) + Chain("]"); 
 		    }
 		    else if ( col[0] == 'c' )
 		    {
@@ -409,7 +410,7 @@ int main(int argc, char **argv)
 			{
 			    pCegoNet->putClob(clob);
 			
-			    cout << "Clob stored to " << clob.getFileId() << " " << clob.getPageId() << endl;
+			    cout << "Clob stored to [" << clob.getPageId() << "]" << endl;
 			}
 			else
 			{
@@ -580,8 +581,7 @@ int main(int argc, char **argv)
 
 		    moreToken = tokA.nextToken(col); 
 		    if ( moreToken ) 
-			cmd += Chain(","); 
-
+			cmd += Chain(",");
 		}
 
 		cmd += " where ";
@@ -625,8 +625,7 @@ int main(int argc, char **argv)
 		    
 		    moreToken = tokB.nextToken(col); 
 		    if ( moreToken ) 
-			cmd += Chain(" and "); 
-
+			cmd += Chain(" and ");
 		}
 		
 		cmd += Chain(";");
@@ -635,8 +634,6 @@ int main(int argc, char **argv)
 	    }
 	    case BLOB_OP:
 	    {
-		// cout << "Blob mode .." << endl;
-
 		Chain blobArg = longOpt.getOptValue("blobop");
 
 		Tokenizer tok(blobArg, Chain(":"));
@@ -655,10 +652,10 @@ int main(int argc, char **argv)
 		    if ( doSimulate == false )
 		    {
 			pCegoNet->putBlob(blob);
-			cout << "Blob stored to " << blob.getFileId() << " " << blob.getPageId() << endl;
+			cout << "Blob stored to [" << blob.getPageId() << "]" << endl;
 		    }
 		    else
-			cout << "Put blob .." << endl;
+			cout << "Put blob ..." << endl;
 		}
 		else if ( blobMode == Chain("get") )
 		{
@@ -668,17 +665,19 @@ int main(int argc, char **argv)
 		    tok.nextToken(blobFile);
 		    Tokenizer btok(blobRef, Chain(LOBSEP));
 
-		    Chain fstr;
-		    btok.nextToken(fstr);
 		    Chain pstr;
 		    btok.nextToken(pstr);
 		    		    
-		    CegoBlob blob(fstr.asInteger(), pstr.asInteger());
-		    
-		    cout << "Getting blob " << fstr << " " << pstr << " to " << blobFile << endl;
-		    pCegoNet->getBlob(blob);
-		    blob.writeBlob(blobFile);
-		    
+		    CegoBlob blob(pstr.asUnsignedLongLong());
+
+		    if ( doSimulate == false )
+		    {			
+			cout << "Getting blob [" << pstr << "] to " << blobFile << endl;
+			pCegoNet->getBlob(blob);
+			blob.writeBlob(blobFile);
+		    }
+		    else
+			cout << "Get blob ..." << endl;		    
 		}
 		else if ( blobMode == Chain("del") )
 		{
@@ -686,71 +685,75 @@ int main(int argc, char **argv)
 		    tok.nextToken(blobRef);
 		    Tokenizer btok(blobRef, Chain(LOBSEP));
 
-		    Chain fstr;
-		    btok.nextToken(fstr);
 		    Chain pstr;
 		    btok.nextToken(pstr);
 		    		    
-		    CegoBlob blob(fstr.asInteger(), pstr.asInteger());
-		    
-		    pCegoNet->deleteBlob(blob);
-		    
+		    CegoBlob blob(pstr.asUnsignedLongLong());
+		    if ( doSimulate == false )
+		    {    
+			pCegoNet->deleteBlob(blob);
+		    }
+		    else
+			cout << "Delete blob ..." << endl;
 		}
 		break;
 	    }
 	    case ARB1_OP:
 	    case ARB2_OP:
 	    case ARB3_OP:
+	    case NONE_OP:
 		break;
 	    }
-
+	    
 	    if ( actOp != BLOB_OP )
-		dispatchCmd(pCegoNet, cmd);
+		if ( dispatchCmd(pCegoNet, cmd) )
+		    numSuccess++;
 	
-	    if ( pCegoNet )
-	    {
-		if ( i % interval == 0)
+	    if ( i % interval == 0)
+	    {		
+		if ( transactionMode )
 		{
-
-		    if ( transactionMode )
-		    {
-			cmd = "commit;";	     
-			dispatchCmd(pCegoNet, cmd);
-		    }
+		    cmd = "commit;";	     
+		    dispatchCmd(pCegoNet, cmd);
+		}
 		    
-		    tim1.stop();
+		tim1.stop();
+
+		if ( pCegoNet )
+		{		    
 		    Chain msg = progid + Chain(" : ") + Chain(numInsert) + Chain(" insert / ")
 			+ Chain(numDelete) + Chain(" delete / ")
 			+ Chain(numUpdate) + Chain(" update / ")
-			+ Chain(numCall) + Chain(" call in ") + tim1.getUsed() + Chain(" sec");
+			+ Chain(numCall) + Chain(" call => ")
+			+ Chain(numSuccess) + Chain(" sucessful, Used Time = ") + tim1.getUsed() + Chain(" sec");
 		    cout << msg << endl;
 		    cout.flush();
-
-		    numInsert=0;
-		    numDelete=0;
-		    numUpdate=0;
-		    numCall=0;
-		    
-		    tim1.start();
-
-		    if ( transactionMode )
-		    {
-			cmd = "start transaction;";	     
-			dispatchCmd(pCegoNet, cmd);
-		    }
 		}
+		
+		numInsert=0;
+		numDelete=0;
+		numUpdate=0;
+		numCall=0;
+		numSuccess=0;
+		
+		tim1.start();
+		
+		if ( transactionMode && i<count )
+		{
+		    cmd = "start transaction;";	     
+		    dispatchCmd(pCegoNet, cmd);
+		}	  
 	    }
 	}
 	
-	if ( transactionMode )
+	if ( transactionMode && pCegoNet)
 	{
 	    cmd = "commit;";	     
 	    dispatchCmd(pCegoNet, cmd);
 	}
 		
 	if ( pCegoNet )
-	{
-	    
+	{	    
 	    tim1.stop();
 
 	    if ( numInsert || numDelete || numUpdate || numCall )
@@ -758,9 +761,9 @@ int main(int argc, char **argv)
 		Chain msg = progid + Chain(" : ") + Chain(numInsert) + Chain(" insert / ")
 		    + Chain(numDelete) + Chain(" delete / ")
 		    + Chain(numUpdate) + Chain(" update / ")
-		    + Chain(numCall) + Chain(" call in ") + tim1.getUsed() + Chain(" sec");
-		
-		cout << msg << endl;
+		    + Chain(numCall) + Chain(" call => ")
+		    + Chain(numSuccess) + Chain(" sucessful, Used Time = ") + tim1.getUsed() + Chain(" sec");
+		cout << msg << endl;		
 		cout.flush();
 	    }
 	    
@@ -774,8 +777,7 @@ int main(int argc, char **argv)
 	}	
     } 
     catch (Exception e) 
-    {
-	
+    {	
 	Chain msg;
 	e.pop(msg);
 	cerr << "CegoBlow Error : " << msg << endl;
@@ -792,11 +794,9 @@ bool dispatchCmd(CegoNet *pCegoNet, Chain cmd)
     }
     else
     {
-
-
 	try
 	{
-	    unsigned long long affCount = pCegoNet->doQuery(cmd);
+	    pCegoNet->doQuery(cmd);
 	}
 	catch ( Exception e )
 	{	    
@@ -805,7 +805,6 @@ bool dispatchCmd(CegoNet *pCegoNet, Chain cmd)
 	    return false;	
 	}
 	
-    
 	if ( pCegoNet->isFetchable() )
 	{		
 	    ListT<CegoField> schema;
@@ -821,18 +820,14 @@ bool dispatchCmd(CegoNet *pCegoNet, Chain cmd)
 	    output.headOut();
 	    
 	    ListT<CegoFieldValue> fvl;
-	
-	    unsigned long long count=0;
-	    
+		    
 	    while ( pCegoNet->fetchData(schema, fvl)  )
 	    {
 		output.rowOut(fvl);
 		fvl.Empty();
 	    }
-	    output.tailOut();
-	    
-	}
-	
+	    output.tailOut();	    
+	}	
 	return true;
     }
 }
