@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -39,13 +39,11 @@ CegoBufferPage::CegoBufferPage()
 {
     _isFixed = false;
     _pageId = 0;
-    _fileId = 0;
 }
 
 CegoBufferPage::CegoBufferPage(const CegoBufferPage &bp)
 {
     _pageId = bp._pageId;
-    _fileId = bp._fileId;
     
     _pageSize = bp._pageSize;
     _pagePtr = bp._pagePtr;
@@ -62,7 +60,6 @@ CegoBufferPage::CegoBufferPage(const CegoBufferPage &bp)
 
 CegoBufferPage::CegoBufferPage(void* pagePtr, int pageSize)
 {
-    // cout << "creating Buffer Page with pageptr " << (unsigned)pagePtr << endl;
     _pageSize = pageSize;       
     _pagePtr = (char*)pagePtr;
     _pageHead = (PageHead*)pagePtr;
@@ -88,7 +85,6 @@ void CegoBufferPage::initPage(CegoBufferPage::PageType t)
     PageHead ph;
     
     ph.pageType = t;
-    ph.nextFileId = 0;
     ph.nextPageId = 0;
 
     memcpy(_pagePtr, &ph, PAGEHEAD);
@@ -119,42 +115,22 @@ void CegoBufferPage::setPageSize(int pageSize)
     _pageSize = pageSize;
 }
 
-void CegoBufferPage::setFileId(int fileId)
-{
-    _fileId = fileId;
-}
-
-int CegoBufferPage::getFileId() const
-{
-    return _fileId;
-}
-
-void CegoBufferPage::setPageId(int pageId)
+void CegoBufferPage::setPageId(PageIdType pageId)
 {
     _pageId = pageId;
 }
 
-int CegoBufferPage::getPageId() const
+PageIdType& CegoBufferPage::getPageId()
 {
     return _pageId;
 }
 
-void CegoBufferPage::setNextFileId(int fileId)
-{
-    _pageHead->nextFileId = fileId;
-}
-
-int CegoBufferPage::getNextFileId() const
-{
-    return _pageHead->nextFileId;
-}
-
-void CegoBufferPage::setNextPageId(int pageId)
+void CegoBufferPage::setNextPageId(PageIdType pageId)
 {
     _pageHead->nextPageId = pageId;
 }
 
-int CegoBufferPage::getNextPageId() const
+PageIdType& CegoBufferPage::getNextPageId() const
 {
     return _pageHead->nextPageId;
 }
@@ -176,14 +152,13 @@ void CegoBufferPage::setType(CegoBufferPage::PageType t)
     _pageHead->pageType = t;
 }
 
-CegoBufferPage::PageType CegoBufferPage::getType() const
+CegoBufferPage::PageType& CegoBufferPage::getType() const
 {
     return _pageHead->pageType;
 }
 
 void* CegoBufferPage::newEntry(int size)
-{
-    
+{   
     if ( size % BUPMNG_ALIGNMENT )
 	size = ( size / BUPMNG_ALIGNMENT + 1) * BUPMNG_ALIGNMENT;
     
@@ -194,7 +169,6 @@ void* CegoBufferPage::newEntry(int size)
     
     while (*freePtr != 0 )
     {
-
 	ePtr = (int*)((long long)_pagePtr + *freePtr);
 	if (*ePtr >=  size && *ePtr <= size + ALLOCDELTA)
 	{
@@ -228,9 +202,7 @@ void* CegoBufferPage::newEntry(int size)
 	    return ePtr;
 	    
 	}
-	    
-	freePtr--;
-	
+	freePtr--;	
     }   
     
     // no appropriate entry found in freelist,
@@ -293,13 +265,11 @@ void CegoBufferPage::freeEntry(void* p)
 	}
 	else if (*freePtr + sizeof(int) + *(int*)(*freePtr + (long long)_pagePtr)  == ((long long)p - (long long)_pagePtr) - sizeof(int))
 	{
-	    // cout << "left free neighbour detected" << endl;
-	    
+	    // cout << "left free neighbour detected" << endl;   
 	    setptr[i]=freePtr;
 	    n=i;
 	    i++;
 	}
-	
 	freePtr--;
 	count++;
     }
@@ -311,12 +281,12 @@ void CegoBufferPage::freeEntry(void* p)
     switch (i)
     {
     case 0:
-	
+    {
 	*freePtr = (long long)p - (long long)_pagePtr - sizeof(int);
 	freePtr--;
 	*freePtr = 0;
 	break;
-	
+    }
     case 1:
     {
 	int newsize = *((int*)p -1) + *(int*)( *setptr[0] + (long long)_pagePtr) + sizeof(int);
@@ -331,13 +301,11 @@ void CegoBufferPage::freeEntry(void* p)
 	else if (*setptr[0] < (long long)p - (long long)_pagePtr)
 	{   
 	    *(int*)( *setptr[0] + (long long)_pagePtr) = newsize;
-	}
-	
+	}	
 	break;
     }
     case 2:
     {	
-
 	int newsize = *((int*)p -1) + *(int*)( *setptr[0] + (long long)_pagePtr) + *(int*)( *setptr[1] + (long long)_pagePtr) + 2 * sizeof(int);
 	
 	// cout << "Setup newsize with " << newsize << endl;
@@ -377,24 +345,23 @@ void* CegoBufferPage::getFirstEntry()
 
 void* CegoBufferPage::getNextEntry()
 {    
-    // cout << "BufferPage:  _ePtr is  " << (unsigned)_ePtr << endl;
+    // cout << "BufferPage:  _ePtr is  " << (unsigned long long)_ePtr << endl;
     // cout << "->  size is   " << *(int*)_ePtr << endl;
-    // cout << "->  delta to page end is  " << (unsigned)_ePtr - (unsigned)_pagePtr << endl;
+    // cout << "->  delta to page end is  " << (unsigned long long)_ePtr - (unsigned long long)_pagePtr << endl;
 
     // cout << "Next entry .." << endl;
-
+    
     while ( *(int*)_ePtr != 0 )
     {
 	// checking free list
-
 	int* freePtr = (int*)((long long)_pagePtr + (long long)_pageSize);
 
 	freePtr--;
-
+		
 	bool isFreeEntry = false;
 	
 	while ( *freePtr != 0 && ! isFreeEntry )
-	{	    
+	{
 	    if ( _ePtr == (char*)((long long)_pagePtr + *freePtr))
 	    {
 		isFreeEntry = true;
@@ -404,25 +371,19 @@ void* CegoBufferPage::getNextEntry()
 		freePtr--;
 	    }
 	}
-	
+		
 	if ( isFreeEntry )
 	{
 	    // skipping free entry
 	    _entryPos = _entryPos + *((int*)_ePtr) + sizeof(int);
-
 	    _ePtr = _ePtr + *((int*)_ePtr) + sizeof(int);
 	}
 	else
-	{
-	    
+	{	  
 	    _entryLen = *(int*)_ePtr; 
-
-	    char* rPtr = _ePtr + sizeof(int);
-	    
-	    _entryPos = _ePtr - _pagePtr + sizeof(int);
-	    
+	    char* rPtr = _ePtr + sizeof(int);	    
+	    _entryPos = _ePtr - _pagePtr + sizeof(int);	    
 	    _ePtr = _ePtr + *((int*)_ePtr) + sizeof(int);
-
 	    return rPtr;
     	}
     }
@@ -463,9 +424,7 @@ void CegoBufferPage::printPage()
 {
     cout << "--- BufferPage ---" << endl;
     cout << "PageId: " << _pageId << endl;
-    cout << "FileId: " << _fileId << endl;
     cout << "NextPageId: " << _pageHead->nextPageId << endl;
-    cout << "NextFileId: " << _pageHead->nextFileId << endl;
     cout << "PageSize: " << _pageSize << endl;
     cout << "PagePtr: " << (unsigned long long)_pagePtr << endl;
 
@@ -474,7 +433,6 @@ void CegoBufferPage::printPage()
     if (e)
     {
 	e--;
-	
 	cout << "Entry " << i << " Pos=" << (long long)e - (long long)_pagePtr << " Size=" << *e << endl;
 	i++;
 	while ( ( e = (int*)getNextEntry()) != 0  )
@@ -484,7 +442,6 @@ void CegoBufferPage::printPage()
 	    i++;
 	}
     }
-
     int* freePtr = (int*)((long long)_pagePtr + (long)_pageSize);
     freePtr--;
     
@@ -502,9 +459,7 @@ void CegoBufferPage::printPage()
 
 CegoBufferPage& CegoBufferPage::operator = ( const CegoBufferPage& bp )
 {
-    _pageId = bp._pageId;
-    _fileId = bp._fileId;
-    
+    _pageId = bp._pageId;    
     _pageSize = bp._pageSize;
     _pagePtr = bp._pagePtr;
     
@@ -522,14 +477,14 @@ CegoBufferPage& CegoBufferPage::operator = ( const CegoBufferPage& bp )
 
 bool CegoBufferPage::operator == ( const CegoBufferPage& bp)
 {
-    if ( _pageId == bp._pageId && _fileId == bp._fileId )
+    if ( _pageId == bp._pageId )
 	return true;
     return false;
 }
 
 bool CegoBufferPage::operator != ( const CegoBufferPage& bp)
 {
-    if ( _pageId != bp._pageId || _fileId != bp._fileId )
+    if ( _pageId != bp._pageId )
 	return true;
     return false;
 }
