@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -21,7 +21,6 @@
 // CEGO INCLUDES
 #include "CegoCheckObject.h"
 #include "CegoXMLdef.h"
-#include "CegoXMLHelper.h"
 
 // LFC INCLUDES
 #include <string.h>
@@ -36,7 +35,6 @@ CegoCheckObject::CegoCheckObject(const CegoCheckObject& co) : CegoDecodableObjec
 {
     _tabName = co._tabName;
     _pPredDesc = co._pPredDesc->clone();
-
 }
 
 CegoCheckObject::CegoCheckObject(ObjectType type, const Chain& objName, int tabSetId) : CegoDecodableObject(type, objName, tabSetId)
@@ -44,7 +42,7 @@ CegoCheckObject::CegoCheckObject(ObjectType type, const Chain& objName, int tabS
     _pPredDesc = 0;
 }
 
-CegoCheckObject::CegoCheckObject(int tabSetId, const Chain& checkName, const Chain& tabName, CegoPredDesc *pPredDesc) : CegoDecodableObject(CegoObject::CHECK, checkName, tabSetId)
+CegoCheckObject::CegoCheckObject(int tabSetId, const Chain& checkName, const Chain& tabName, CegoPredicate *pPredDesc) : CegoDecodableObject(CegoObject::CHECK, checkName, tabSetId)
 {
     _pPredDesc = pPredDesc;
     _tabName = tabName;
@@ -68,29 +66,28 @@ const Chain& CegoCheckObject::getTabName() const
     return _tabName;
 }
   
-void  CegoCheckObject::setPredDesc(CegoPredDesc *pPredDesc)
+void  CegoCheckObject::setPredDesc(CegoPredicate *pPredDesc)
 {
     _pPredDesc = pPredDesc;
 }
 
-CegoPredDesc* CegoCheckObject::getPredDesc()
+CegoPredicate* CegoCheckObject::getPredDesc()
 {
     return _pPredDesc;
 }
 
 int CegoCheckObject::getEntrySize() const
 {
-
     int entrySize = CegoObject::getBaseSize();
 
     entrySize += 1; // object tabname size
     entrySize += _tabName.length();
-    entrySize += _pPredDesc->getEncodingLength();
+    entrySize += _pPredDesc->getEncodingLength(0);
 
     return entrySize;
 }
 
-void CegoCheckObject::encode(char *buf)
+void CegoCheckObject::encode(char *buf) const
 {
     char* bufPtr = buf;
 
@@ -108,7 +105,7 @@ void CegoCheckObject::encode(char *buf)
     memcpy(bufPtr, (char*)_tabName, _tabName.length());    
     bufPtr=bufPtr + _tabName.length();
 
-    _pPredDesc->encode(bufPtr);
+    _pPredDesc->encode(bufPtr, 0);
 }
 
 void CegoCheckObject::decode(char *buf)
@@ -126,7 +123,7 @@ void CegoCheckObject::decode(char *buf)
     
     // TODO
     // No support for check objects which have to access table manager
-    _pPredDesc = new CegoPredDesc(bufPtr, 0, 0);
+    _pPredDesc = new CegoPredicate(bufPtr, 0, 0, getTabSetId() );
 }
 
 CegoCheckObject& CegoCheckObject::operator = ( const CegoCheckObject& co)
@@ -135,7 +132,6 @@ CegoCheckObject& CegoCheckObject::operator = ( const CegoCheckObject& co)
 
     _tabName = co._tabName;
     _pPredDesc = co._pPredDesc->clone();
-
     return (*this);
 }
 
@@ -144,65 +140,17 @@ bool CegoCheckObject::operator == ( const CegoCheckObject& co)
     return CegoObject::operator==(co);
 }
 
-Chain CegoCheckObject::toChain() const
+Chain CegoCheckObject::toChain(int defTabSetId) const
 {
     Chain s;
     s = CegoObject::toChain();
 
     s += Chain("TabName: ") + _tabName + Chain("\n");
-    s += Chain("PredDesc: ") + _pPredDesc->toChain();
+    s += Chain("PredDesc: ") + _pPredDesc->toChain(defTabSetId);
     
     return s;
 }
 
-Element* CegoCheckObject::getElement() const
-{
-    Element* pRoot = new Element(XML_OBJ_ELEMENT);
-
-    pRoot->setAttribute(XML_TSID_ATTR, Chain(getTabSetId()));
-    pRoot->setAttribute(XML_OBJTYPE_ATTR, XML_CHECKOBJ_VALUE);
-    pRoot->setAttribute(XML_OBJNAME_ATTR, getName());
-
-    pRoot->setAttribute(XML_TABLENAME_ATTR, _tabName);
-
-
-    Element *pPDElement = _pPredDesc->toElement();
-
-    pRoot->addContent(pPDElement);
-
-    return pRoot;
-}
-
-void CegoCheckObject::putElement(Element* pElement)
-{
-    Element *pRoot = pElement;
-    
-    if ( pRoot )
-    {
-	
-	Chain objName = pRoot->getAttributeValue(XML_OBJNAME_ATTR); 
-	setName(objName);
-
-	int tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asInteger();
-	setTabSetId(tabSetId);	
-
-	_tabName = pRoot->getAttributeValue(XML_TABLENAME_ATTR); 
-
-	Chain objType = pRoot->getAttributeValue(XML_OBJTYPE_ATTR);
-	setType(CegoObject::CHECK);
-
-	ListT<Element*> predList = pRoot->getChildren(XML_PRED_ELEMENT);
-	Element **pPredElement = predList.First();
-	if ( pPredElement )
-	{
-	    if ( _pPredDesc )
-		delete _pPredDesc;
-
-	    _pPredDesc = new CegoPredDesc(*pPredElement, 0);
-	}
-    }
-}
-
 Chain CegoCheckObject::getFormatted() const
 {
     Chain s;
@@ -218,7 +166,6 @@ Chain CegoCheckObject::getFormatted() const
 	
     s += "| ObjectType : check " +  fill(" ", maxAttrLen - 18) + "|\n";
 
-
     s += "| Table      : " + _tabName;
     s += fill(" ", maxAttrLen - 12 - _tabName.length()) + "|" + "\n";
 	
@@ -226,23 +173,20 @@ Chain CegoCheckObject::getFormatted() const
     s += "| Check   " +  fill(" ", maxAttrLen1-9) + "          " +  fill(" ", maxAttrLen2-9) + "|\n";
     s += "+---------" + fill("-", maxAttrLen1-9) + "+---------" +  fill("-", maxAttrLen2-9) + "+\n";
 	
-    s += _pPredDesc->toChain();
+    s += _pPredDesc->toChain(0);
 
     s +="+" + fill("-", maxAttrLen1) + "+" + fill("-", maxAttrLen2) + "+\n";
 
-    
     return s;
 }
 
 Chain CegoCheckObject::fill(const Chain& s, int num) const
-{
-    
-    Chain fs = Chain("");
+{    
+    Chain fs = Chain();
     while (num > 0)
     {
 	fs = fs + s;
 	num--;
     }
-
     return fs;
 }
