@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -27,7 +27,7 @@
 // CEGO INCLUDES
 #include "CegoField.h"
 #include "CegoObject.h"
-#include "CegoPredDesc.h"
+#include "CegoPredicate.h"
 #include "CegoDecodableObject.h"
 
 class CegoCheckObject : public CegoDecodableObject {
@@ -37,29 +37,24 @@ class CegoCheckObject : public CegoDecodableObject {
     CegoCheckObject();
     CegoCheckObject(const CegoCheckObject& co);
     CegoCheckObject(ObjectType type,  const Chain& objName, int tabSetId = 0);
-
-    CegoCheckObject(int tabSetId, const Chain& checkName, const Chain& tabName, CegoPredDesc *pPredDesc);
-	
+    CegoCheckObject(int tabSetId, const Chain& checkName, const Chain& tabName, CegoPredicate *pPredDesc);	
     ~CegoCheckObject();
 
     void setTabName(const Chain& name);
     const Chain& getTabName() const;
     
-    void setPredDesc(CegoPredDesc *pPredDesc);   
-    CegoPredDesc* getPredDesc();
+    void setPredDesc(CegoPredicate *pPredDesc);   
+    CegoPredicate* getPredDesc();
 
     int getEntrySize() const;
 
-    void encode(char *buf);
+    void encode(char *buf) const;
     void decode(char *buf);
     
     CegoCheckObject& operator = ( const CegoCheckObject& oe);
     bool operator == ( const CegoCheckObject& oe);
     
-    Chain toChain() const;
-
-    Element* getElement() const;
-    void putElement(Element* pElement);
+    Chain toChain(int defTabSetId) const;
 
     Chain getFormatted() const;
 
@@ -68,6 +63,6 @@ class CegoCheckObject : public CegoDecodableObject {
     Chain fill(const Chain& s, int num) const;
 
     Chain _tabName;
-    CegoPredDesc *_pPredDesc;
+    CegoPredicate *_pPredDesc;
 };
 #endif
