@@ -115,6 +115,9 @@
 /* Lock Management Parameters */
 /******************************/
 
+/* heart beat delay for writing lock file */
+#define LCKMNG_BEATDELAY 15
+
 /* the amount of semaphores used for locking database data files  */
 #define LCKMNG_NUM_DATAFILE_SEMA 1021
 
@@ -300,9 +303,6 @@
 #define NETMNG_MAXTUPLECOUNT 500
 #define NETMNG_MAXBYTECOUNT 10000000
 
-/* heart beat of managed nodes to send status request to mediator ( in seconds )  */
-#define NETMNG_BEATDELAY 15
-
 /* check interval to check for expired db connections in seconds */
 #define NETMNG_DBHANDLE_CHK 10
 
@@ -495,4 +495,13 @@
 /* delay in msec */
 #define TABLECACHE_TRYDELAYBASE 10
 
+
+// we take a wednesday in september as proof day, since wednesday and september are max name len
+#define PROOFDATE_VALUE  "04.09.2024 12:00:00"
+#define PROOFDATE_FORMAT "%d.%m.%Y %H:%M:%S"
+
+#define REPLACER_MAXNUM 100
+#define REPLACER_HASHRANGE 3
+
+
 #endif
