@@ -83,6 +83,7 @@ bool CegoDistManager::ActiveTSUser::operator == (const CegoDistManager::ActiveTS
 CegoDistManager::CegoDistManager(CegoDatabaseManager *pDBMng) : CegoTableManager(pDBMng)
 {
     _modId = pDBMng->getModId("CegoDistManager");
+    _pRepHash = new HashT<CegoReplacer>(REPLACER_MAXNUM, REPLACER_HASHRANGE);
     _authEnabled = true;
     _numAllocated = 0;
     _threadId = 0;
@@ -93,6 +94,18 @@ CegoDistManager::~CegoDistManager()
 {
     if ( _pPA )
 	delete _pPA;
+
+    if ( _pRepHash )
+    {
+	CegoReplacer *pRep = _pRepHash->First();
+	while ( pRep )
+	{
+	    pRep->clean();
+	    pRep = _pRepHash->Next();
+	}
+	if ( _pRepHash )
+	    delete _pRepHash;
+    }
 }
 
 void CegoDistManager::createTableSet(const Chain& tableSet)
@@ -341,11 +354,8 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 	    }
 	    catch ( Exception e)
 	    {
-		Chain msg;
-		e.pop(msg);
-		_pDBMng->log(_modId, Logger::LOGERR, msg);
 	    	_pDBMng->setTableSetRunState(tableSet, XML_OFFLINE_VALUE);
-		throw Exception(EXLOC, Chain("Cannot start tableset ") + tableSet + Chain(" : ") + msg);
+		throw Exception(EXLOC, Chain("Cannot start tableset ") + tableSet, e);
 	    }
 	}
 	else
@@ -370,11 +380,9 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 	    }
 	    catch ( Exception e)
 	    {
-		Chain msg;
-		e.pop(msg);
-		_pDBMng->log(_modId, Logger::LOGERR, msg);
+		// _pDBMng->log(_modId, Logger::LOGERR, msg);
 		stopTableSet(tableSet, false);
-		throw Exception(EXLOC, Chain("Cannot correct tableset ") + tableSet + Chain(" : ") + msg);
+		throw Exception(EXLOC, Chain("Cannot correct tableset ") + tableSet, e);
 	    }
 	}
 
@@ -2864,6 +2872,25 @@ CegoView* CegoDistManager::getView(int tabSetId, const Chain& viewName)
     return getCompView(tabSetId, viewName );
 }
 
+
+CegoProcedure* CegoDistManager::getProcedure(int tabSetId, const Chain& procName)
+{
+    if ( checkCompProcedure(tabSetId, procName) == false )
+	reloadProcedure( tabSetId, procName );
+    return getCompProcedure(tabSetId, procName );
+}
+
+CegoAction* CegoDistManager::getParser()
+{
+    if ( _pPA == 0 )
+    {
+	_pPA = new CegoAction(this);
+	_pPA->setGraceMode(_isGrace);
+    }
+	
+    return _pPA;
+}
+
 void CegoDistManager::reloadView(int tabSetId, const Chain& viewName)
 {
     CegoViewObject vo;
@@ -2923,6 +2950,46 @@ void CegoDistManager::reloadView(int tabSetId, const Chain& viewName)
     delete pPA;
 }
 
+void CegoDistManager::reloadProcedure(int tabSetId, const Chain& procName)
+{    
+    CegoProcObject po;
+    getObject(tabSetId, procName, CegoObject::PROCEDURE, po);
+    
+    Chain loadString = Chain("load ") + po.getProcText();
+
+    // cout << "Load String = " << loadString << endl;
+    // since this message is produced for each database thread, we avoid this
+    // _pDBMng->log(_modId, Logger::NOTICE, Chain("Procedure ") + procName + Chain(" is reloaded"));        
+
+    // since procedures can be nested, we have to use dedicated parser here
+    CegoAction *pPA = new CegoAction(this);
+    
+    try 
+    {
+	Chain tableSet = _pDBMng->getTabSetName(tabSetId);
+	pPA->setTableSet(tableSet);
+	pPA->setCommandChain(loadString);
+	pPA->parse();
+	
+	CegoProcedure* pProc = pPA->getProcedure(true);
+
+	pProc->enableProcCache(_pDBMng->getProcCacheEnabled(tabSetId));
+	
+	addCompProcedure(tabSetId, pProc);
+    }
+    catch ( Exception e )
+    {
+	if ( pPA )
+	    delete pPA;
+	
+	Chain msg = Chain("Cannot load procedure ") + procName; 
+	throw Exception(EXLOC, msg, e);
+    }
+
+    delete pPA;
+}
+
+
 CegoTrigger* CegoDistManager::getTrigger(int tabSetId, const Chain& triggerName)
 {
     if ( checkCompTrigger(tabSetId, triggerName) == false )
@@ -2976,59 +3043,24 @@ bool CegoDistManager::isGraceMode() const
     return _isGrace;
 }
 
-CegoProcedure* CegoDistManager::getProcedure(int tabSetId, const Chain& procName)
+CegoReplacer* CegoDistManager::getReplacer(const Chain& pattern, const Chain& replace)
 {
-    if ( checkCompProcedure(tabSetId, procName) == false )
-	reloadProcedure( tabSetId, procName );
-    return getCompProcedure(tabSetId, procName );
-}
+    CegoReplacer *pRep = _pRepHash->Find(CegoReplacer(pattern, replace));
 
-CegoAction* CegoDistManager::getParser()
-{
-    if ( _pPA == 0 )
+    if ( pRep == 0 )
     {
-	_pPA = new CegoAction(this);
-	_pPA->setGraceMode(_isGrace);
+	CegoReplacer rep(pattern, replace);
+	bool wasInserted = _pRepHash->Insert(rep);
+	if ( wasInserted )
+	{
+	    return _pRepHash->Find(CegoReplacer(pattern, replace));
+	}
+	else
+	{
+	    throw Exception(EXLOC, "Replace Hash Error");
+	}
     }
-	
-    return _pPA;
-}
-
-void CegoDistManager::reloadProcedure(int tabSetId, const Chain& procName)
-{    
-    CegoProcObject po;
-    getObject(tabSetId, procName, CegoObject::PROCEDURE, po);
     
-    Chain loadString = Chain("load ") + po.getProcText();
-
-    // cout << "Load String = " << loadString << endl;
-    // since this message is produced for each database thread, we avoid this
-    // _pDBMng->log(_modId, Logger::NOTICE, Chain("Procedure ") + procName + Chain(" is reloaded"));        
-
-    // since procedures can be nested, we have to use dedicated parser here
-    CegoAction *pPA = new CegoAction(this);
-    
-    try 
-    {
-	Chain tableSet = _pDBMng->getTabSetName(tabSetId);
-	pPA->setTableSet(tableSet);
-	pPA->setCommandChain(loadString);
-	pPA->parse();
-	
-	CegoProcedure* pProc = pPA->getProcedure(true);
-
-	pProc->enableProcCache(_pDBMng->getProcCacheEnabled(tabSetId));
-	
-	addCompProcedure(tabSetId, pProc);
-    }
-    catch ( Exception e )
-    {
-	if ( pPA )
-	    delete pPA;
-	
-	Chain msg = Chain("Cannot load procedure ") + procName; 
-	throw Exception(EXLOC, msg, e);
-    }
-
-    delete pPA;
+    return pRep;
 }
+
