@@ -8,7 +8,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2013 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -20,14 +20,12 @@
 
 enum CegoException {
     NONE_EXCEP,
-    INVALID_OBJECT_EXCEP,
-    INVALID_ATTRIBUTE_EXCEP,
     COREOP_EXCEP,
     OTHER_EXCEP,
     ANY_EXCEP,
-    RETURN_EXCEP
+    RETURN_EXCEP,
+    ABORT_EXCEP
 };
-
 #endif
 
 
