@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -44,6 +44,11 @@ CegoExpOutStream::~CegoExpOutStream()
     delete _pOC;
 }
 
+unsigned long long CegoExpOutStream::numExported() const
+{
+    return _rowCount;
+}
+
 Element* CegoExpOutStream::getFirst()
 {
     CegoDataPointer dp;
@@ -77,8 +82,10 @@ Element* CegoExpOutStream::getNext()
 
 	if ( _pAH && ( _rowCount % XP_ROWINTERVAL == 0 ) )
 	    _pAH->sendInfo(Chain(_rowCount) + Chain(" rows\r"));
+	
 	return getRowElement(_schema);
     }
+
     if ( _pAH )
 	_pAH->sendInfo(Chain(_rowCount) + Chain(" rows exported\n"));
 			   
@@ -103,34 +110,30 @@ Element* CegoExpOutStream::getRowElement(ListT<CegoField>& schema)
 		nextBlobId++;
 		pRowElement->setAttribute(pF->getAttrName(), blobId);
 		
-		int fileId;
-		int pageId;
-		memcpy(&fileId, pF->getValue().getValue(), sizeof(int));
-		memcpy(&pageId, (void*)((long long)pF->getValue().getValue() + sizeof(int)), sizeof(int));
+		PageIdType pageId;
+		memcpy(&pageId, pF->getValue().getValue(), sizeof(PageIdType));
 		
 		unsigned long long blobSize;
-		unsigned char* blobBuf = _pGTM->getBlobData(_tabSetId, fileId, pageId, blobSize);
+		unsigned char* blobBuf = _pGTM->getBlobData(_tabSetId, pageId, blobSize);
 
 		Base64Coder b64;
-		pRowElement->addData(b64.encode(blobSize, blobBuf));
-				
+		pRowElement->addData(b64.encode(blobSize, blobBuf));	     			
 	    }
 	    else if ( pF->getType() == CLOB_TYPE )
 	    {
+		
 		Chain clobId = Chain(XML_CLOBPREFIX) + Chain(nextClobId);
 		nextClobId++;
 		pRowElement->setAttribute(pF->getAttrName(), clobId);
 		
-		int fileId;
-		int pageId;
-		memcpy(&fileId, pF->getValue().getValue(), sizeof(int));
-		memcpy(&pageId, (void*)((long long)pF->getValue().getValue() + sizeof(int)), sizeof(int));
+		PageIdType pageId;
+		memcpy(&pageId, pF->getValue().getValue(), sizeof(PageIdType));
 		
 		unsigned long long clobSize;
-		char* clobBuf = _pGTM->getClobData(_tabSetId, fileId, pageId, clobSize);
-
+		char* clobBuf = _pGTM->getClobData(_tabSetId, pageId, clobSize);
+		
 		pRowElement->addData(clobBuf);
-				
+		
 	    }
 	    else
 	    {
