@@ -8,7 +8,7 @@
 //
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -38,10 +38,12 @@ public:
     
     CegoExpOutStream(int tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoDistManager* pGTM, CegoAdminHandler* pAH = 0);
     ~CegoExpOutStream();
+
+    unsigned long long numExported() const;
     
     Element* getFirst();
     Element* getNext();
-    
+
 private:
 
     Element* getRowElement(ListT<CegoField>& schema);
@@ -51,7 +53,7 @@ private:
     CegoObjectCursor* _pOC;
     ListT<CegoField> _schema;
     Chain _tableName;
-    long _rowCount;
+    unsigned long long _rowCount;
     int _tabSetId;
 };
 #endif
