@@ -372,6 +372,16 @@ CegoAttrDesc* CegoFactor::checkAttr() const
     return 0;
 }
 
+CegoCondition* CegoFactor::checkCondition() const
+{
+    if ( _type == CONDITION )
+    {
+	return _pCond;
+    }
+    return 0;
+}
+
+
 bool CegoFactor::checkLob(CegoFieldValue& fv, CegoProcBlock *pBlock)
 {
     switch ( _type )
@@ -411,6 +421,17 @@ bool CegoFactor::checkLob(CegoFieldValue& fv, CegoProcBlock *pBlock)
     return false;
 }
 
+void CegoFactor::getSelectQueryList(ListT<CegoSelect*>& queryList)
+{
+    if ( _pSelect )
+	queryList.Insert(_pSelect);
+    if ( _pCaseCond )
+	_pCaseCond->getSelectQueryList(queryList);
+    if ( _pCond )
+	_pCond->getSelectQueryList(queryList);		 
+}
+
+
 CegoAttrDesc* CegoFactor::getAttr() const
 {
     return _pAttrDesc;
@@ -670,6 +691,7 @@ CegoField CegoFactor::evalField(const ListT<CegoField>& fl, bool graceful) const
     case CegoFactor::FUNCTION:
     {
 	f = CegoField("FUNC", "FUNC", _pFunction->toChain(0), _pFunction->getReturnType(), _pFunction->getReturnTypeLen(fl));
+	f.setDim(_pFunction->getReturnTypeDim());
 	_pFunction->cleanUp();
 	break;
     }
@@ -810,11 +832,13 @@ CegoFieldValue CegoFactor::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlock
     {
 	try 
 	{
+	    
 	    _pSelect->setParentJoinBuf(pFLA);
 	    _pSelect->setProcBlock(pBlock);
+
 	    _pSelect->prepare();
 
-	    _pSelect->reset(false);
+	    _pSelect->reset();
 
 	    ListT<CegoField> fl;
 
@@ -822,7 +846,7 @@ CegoFieldValue CegoFactor::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlock
 
 	    if ( ! _pSelect->nextTuple(fl) )
 	    {
-		_pSelect->reset(true);
+		_pSelect->reset();
 		return CegoFieldValue();
 	    }
 	    else
@@ -833,24 +857,21 @@ CegoFieldValue CegoFactor::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlock
 		// before, we have to save value to local copy
 		CegoField *pSF = fl.First();
 		val = pSF->getValue().getLocalCopy();
-		
+
 		ListT<CegoField> nfl;		
 		_pSelect->nextTuple(nfl);
+
 	    }
-	    	    
-	    _pSelect->reset(true);
+
+	    _pSelect->reset();
+	    _pSelect->setParentJoinBuf();
 	    
 	    return val;
 	}
 	catch ( Exception e ) 
 	{
-	    _pSelect->cleanUp();
-
-	    e.print();
-	    
-	    Chain msg;
-	    e.pop(msg);
-	    throw Exception(EXLOC, Chain("Cannot eval select : ") + msg);
+	    _pSelect->cleanUp();	    
+	    throw Exception(EXLOC, Chain("Cannot eval select"), e);
 	}
     }
     case CegoFactor::CASECOND:
@@ -891,7 +912,8 @@ ListT<CegoAggregation*> CegoFactor::getAggregationList()
     }
     case CegoFactor::QUERY:
     {
-	throw Exception(EXLOC, "Query not supported in aggregation");
+	// nothing to add
+	break;
     }
     case CegoFactor::CASECOND:
     {
@@ -905,7 +927,8 @@ ListT<CegoAggregation*> CegoFactor::getAggregationList()
     }
     case CegoFactor::FETCH:
     {
-	throw Exception(EXLOC, "Fetch not supported in aggregation");
+	// nothing to add
+	break;
     }
     case CegoFactor::AGGREGATION:
     {
@@ -1085,7 +1108,7 @@ Chain CegoFactor::toChain(int defTabSetId, const Chain& indent) const
 	s = _pCaseCond->toChain(defTabSetId);
 	break;
     case CegoFactor::CONDITION:
-	s = _pCond->toChain(defTabSetId);
+	s = Chain("(") + _pCond->toChain(defTabSetId) + Chain(")");
 	break;
     }
     return s;
@@ -1335,11 +1358,11 @@ int CegoFactor::getEncodingLength(CegoProcBlock *pBlock) const
 void CegoFactor::getPlanList(ListT<Element*>& planList)
 {
     if ( _pSelect )
-    planList.Insert(_pSelect->getPlan());
+	planList.Insert(_pSelect->getPlan());
     if ( _pCaseCond )
-    _pCaseCond->getPlanList(planList);
+	_pCaseCond->getPlanList(planList);
     if ( _pCond )
-    _pCond->getPlanList(planList);
+	_pCond->getPlanList(planList);
 }
 
 ostream& operator << (ostream& s, const CegoFactor& pf)
@@ -1347,3 +1370,70 @@ ostream& operator << (ostream& s, const CegoFactor& pf)
     s << pf.toChain(0, Chain());
     return s;
 }
+
+CegoFactor* CegoFactor::map(const Chain& viewAlias, const ListT<CegoExpr*>& exprList) const
+{
+
+    switch ( _type ) 
+    {
+    case CegoFactor::ATTR:
+    {	
+	CegoExpr **pExpr = exprList.First();
+	while ( pExpr )
+	{
+	    if ( (*pExpr)->getAlias() == _pAttrDesc->getAttrName() )
+		return new CegoFactor ( (*pExpr)->clone() );
+	    pExpr = exprList.Next();
+	}
+	return 0;
+    }
+    case CegoFactor::CONSTVAL:
+    {
+	return ( new CegoFactor( _fv ) );
+    }
+    case CegoFactor::VAR:
+    {
+	return ( new CegoFactor( _varName ) );
+    }
+    case CegoFactor::EXPR:
+    {
+	CegoExpr* pMapExpr = _pExpr->map(viewAlias, exprList);
+	if ( pMapExpr )
+	    return new CegoFactor( pMapExpr );
+	return 0;
+    }
+    case CegoFactor::FUNCTION:
+    {
+	CegoFunction* pMapFunction = _pFunction->map(viewAlias, exprList);
+	if ( pMapFunction )
+	    return new CegoFactor( pMapFunction );
+	return 0;
+    }
+    case CegoFactor::AGGREGATION:
+    {
+	return 0;
+    }
+    case CegoFactor::QUERY:
+    {
+	return 0;
+    }
+    case CegoFactor::CASECOND:
+    {
+	CegoCaseCond* pMapCaseCond = _pCaseCond->map(viewAlias, exprList);
+	if ( pMapCaseCond )
+	    return new CegoFactor( pMapCaseCond );
+	return 0;	
+    }
+    case CegoFactor::CONDITION:
+    {
+	CegoCondition* pMapCond = _pCond->map(viewAlias, exprList);
+	if ( pMapCond )
+	    return new CegoFactor( pMapCond );
+	return 0;
+    }
+    case CegoFactor::FETCH:
+	return 0;
+	
+    }
+    return 0;
+}
