@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -33,18 +33,17 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoImpInStream::CegoImpInStream(const Chain& tableSet, CegoDistManager* pGTM, bool doLogging, CegoAdminHandler* pAH)
+CegoImpInStream::CegoImpInStream(const Chain& tableSet, CegoDistManager* pGTM, CegoAdminHandler* pAH)
 {
     _pGTM = pGTM;
     _tableSet = tableSet;
     _pDBMng = _pGTM->getDBMng();
     _pAH = pAH;
     _mode = IMP_ALL;
-    _doLogging = doLogging;
     _modId = _pDBMng->getModId("CegoImpInStream");
 }
 
-CegoImpInStream::CegoImpInStream(const Chain& tableSet, const Chain& tableName, CegoDistManager* pGTM, bool doLogging, CegoAdminHandler* pAH)
+CegoImpInStream::CegoImpInStream(const Chain& tableSet, const Chain& tableName, CegoDistManager* pGTM, CegoAdminHandler* pAH)
 {
     _pGTM = pGTM;
     _tableSet = tableSet;
@@ -52,7 +51,6 @@ CegoImpInStream::CegoImpInStream(const Chain& tableSet, const Chain& tableName,
     _pDBMng = _pGTM->getDBMng();
     _pAH = pAH;
     _mode = IMP_TABLE;
-    _doLogging = doLogging;
     _modId = _pDBMng->getModId("CegoImpInStream");
 }
 
@@ -62,9 +60,13 @@ CegoImpInStream::~CegoImpInStream()
 	_pDBMng->bufferUnfix(_bp, true, _pGTM->getLockHandler());  
 }
 
-void CegoImpInStream::putFirst(Element* pParent, const Chain& name, const ListT<Attribute>& attrList, ListT<char*> dataList)
+unsigned long long CegoImpInStream::numImported() const
 {
+    return _rowCount;
+}
 
+void CegoImpInStream::putFirst(Element* pParent, const Chain& name, const ListT<Attribute>& attrList, ListT<char*>& dataList)
+{
     _isFirst = true;
     _rowCount = 0;
 
@@ -77,7 +79,6 @@ void CegoImpInStream::putFirst(Element* pParent, const Chain& name, const ListT<
     
     if ( _mode == IMP_ALL ||  ( _mode == IMP_TABLE && tabName == _impTable) )
     {
-
 	_rowCount++;
 
 	if ( _pAH )
@@ -98,62 +99,90 @@ void CegoImpInStream::putFirst(Element* pParent, const Chain& name, const ListT<
 	    
 	    Element **pCol = colList.First();
 	    while ( pCol ) 
-	    {
-		
+	    {		
 		Chain colName = (*pCol)->getAttributeValue(XML_COLNAME_ATTR);
 		Chain colType = (*pCol)->getAttributeValue(XML_COLTYPE_ATTR);
-		Chain colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR);
+
+		CegoDataType dt = CegoTypeConverter::getTypeId( colType );
+
+		int colSize;
+		
+		if (dt == VARCHAR_TYPE
+		    || dt == BIGINT_TYPE
+		    || dt == DECIMAL_TYPE )
+		{
+		    colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR).asInteger();
+		}
+		else
+		{
+		    colSize = CegoTypeConverter::getTypeLen( dt );
+		}
+		
+		int colDim;
+		
+		if ( dt == DECIMAL_TYPE )
+		{
+		    Chain dimCheck = (*pCol)->getAttributeValue(XML_COLDIM_ATTR);
+		    if ( dimCheck == Chain() )
+		    {
+			colDim = colSize;
+			colSize = RESERVED_BTREE_FLOATLEN;
+		    }
+		    else
+		    {
+			colDim = dimCheck.asInteger();
+		    }
+		}
+		else
+		{
+		    colDim = 0;
+		}
+		
 		Chain colNullable = (*pCol)->getAttributeValue(XML_COLNULLABLE_ATTR);
 		bool isNullable;
 		if ( colNullable == Chain(XML_TRUE_VALUE) ) 
 		    isNullable = true;
 		else
 		    isNullable = false;
-
 		
-		CegoTypeConverter tc;
-		CegoDataType type = tc.getTypeId( colType );
+		CegoDataType type = CegoTypeConverter::getTypeId( colType );
 		
 		CegoFieldValue defValue;
 		Chain colDefValue = (*pCol)->getAttributeValue(XML_COLDEFVALUE_ATTR);
 		
-		if ( colDefValue != Chain(""))
+		if ( colDefValue != Chain())
 		    defValue = CegoFieldValue(type, colDefValue);
-				
-		CegoField f(CegoField(tabName, tabName, colName, type, colSize.asInteger(), defValue, isNullable));		
+		
+		CegoField f(CegoField(tabName, tabName, colName, dt, colSize, colDim, defValue, isNullable));		
 		_schema.Insert(f);
 		
 		pCol = colList.Next();
 	    }
-	    
+
 	    ListT<CegoField> idxList;
 	    _pGTM->createDistDataTable(_tableSet, tabName, CegoObject::TABLE, _schema, idxList);		
 	    _pGTM->setAppend(true);
-
 	}
 	insertData(tabName, attrList, dataList);
     }
 }
 
-void CegoImpInStream::putNext(Element* pParent, const Chain& name, const ListT<Attribute>& attrList, ListT<char*> dataList)
-{
+void CegoImpInStream::putNext(Element* pParent, const Chain& name, const ListT<Attribute>& attrList, ListT<char*>& dataList)
+{    
     Chain tabName = pParent->getAttributeValue(XML_NAME_ATTR);
     if ( _mode == IMP_ALL || ( _mode == IMP_TABLE && tabName == _impTable) )
     {
-
 	_rowCount++;
 	
 	if ( _pAH && ( _rowCount % XP_ROWINTERVAL == 0 ) )
 	    _pAH->sendInfo(Chain(_rowCount) + Chain(" rows\r"));
-
+	
 	insertData(tabName, attrList, dataList);
     }
 }
 
 void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& attrList, ListT<char*> dataList)
-{
-    // _pDBMng->log(_modId, Logger::DEBUG, Chain("Inserting data into ") + tabName + Chain(" ..."));
-
+{	 
     if ( attrList.Size() == 0 )
 	return;
     
@@ -162,7 +191,6 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
     CegoField *pF = _schema.First();
     while ( pF ) 
     {
-
 	Chain colName = pF->getAttrName();
 	
 	Attribute *pAttr = attrList.Find( Attribute( colName ) );
@@ -171,17 +199,12 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
 	{
 	    Chain colVal = pAttr->getValue();
 	    
-	    CegoTypeConverter tc;
 	    if ( pF->getType() == BLOB_TYPE )
 	    {
-
 		int blobPos = colVal.cutTrailing(XML_BLOBPREFIX).asInteger();
 		
 		int tabSetId = _pDBMng->getTabSetId(_tableSet);
-		
-		int fileId;
-		int pageId;
-		
+				
 		unsigned long long decBufSize = strlen(dataList[blobPos]);
 		
 		Base64Coder b64;
@@ -190,45 +213,62 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
 		{
 		    throw Exception(EXLOC, "malloc system error");     
 		}
-		
-		unsigned long long blobSize = b64.decode(dataList[blobPos], decBuf, blobSize);
-		
-		_pGTM->putBlobData(tabSetId, decBuf, blobSize, fileId, pageId);
-		
-		free (decBuf );
-		
-		int len = tc.getTypeLen(pF->getType(), colVal);
+
+		int len = CegoTypeConverter::getTypeLen(pF->getType(), colVal);
 		CegoField f(CegoField(pF->getTableName(), pF->getTableAlias(), colName, pF->getType(), len));
-		Chain blobRef = Chain("[") + Chain(fileId) + Chain(",") + Chain(pageId) + Chain("]");
-		CegoFieldValue fv(pF->getType(), blobRef);
-		f.setValue(fv);
+		
+		if ( blobPos < dataList.Size() )
+		{
+		    unsigned long long blobSize = b64.decode(dataList[blobPos], decBuf, decBufSize);
+
+		    PageIdType pageId;
+		    _pGTM->putBlobData(tabSetId, decBuf, blobSize, pageId);
+		    
+		    free (decBuf );
+		
+		    Chain blobRef = Chain("[") + Chain(pageId) + Chain("]");
+		    CegoFieldValue fv(pF->getType(), blobRef);
+		    f.setValue(fv);
+		}
+		else
+		{
+		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Missing blob information in stream for table ") + tabName);
+		    // set to zero
+		    CegoFieldValue fv;
+		    f.setValue(fv);		    
+		}
 		fvl.Insert(f);
 	    }
 	    else if ( pF->getType() == CLOB_TYPE )
 	    {
-
 		int clobPos = colVal.cutTrailing(XML_CLOBPREFIX).asInteger();
 		
 		int tabSetId = _pDBMng->getTabSetId(_tableSet);
 		
-		int fileId;
-		int pageId;
-			    				
-		_pGTM->putClobData(tabSetId, dataList[clobPos], strlen(dataList[clobPos]), fileId, pageId);
-		
-		
-		int len = tc.getTypeLen(pF->getType(), colVal);
-		CegoField f(CegoField(pF->getTableName(), pF->getTableAlias(), colName, pF->getType(), len));
-		Chain clobRef = Chain("[") + Chain(fileId) + Chain(",") + Chain(pageId) + Chain("]");
-		CegoFieldValue fv(pF->getType(), clobRef);
-		f.setValue(fv);
-		fvl.Insert(f);
+		PageIdType pageId;
 
+		int len = CegoTypeConverter::getTypeLen(pF->getType(), colVal);
+		CegoField f(CegoField(pF->getTableName(), pF->getTableAlias(), colName, pF->getType(), len));
+		
+		if ( clobPos < dataList.Size() )
+		{
+		    _pGTM->putClobData(tabSetId, dataList[clobPos], strlen(dataList[clobPos]), pageId);
+		    Chain clobRef = Chain("[") + Chain(pageId) + Chain("]");
+		    CegoFieldValue fv(pF->getType(), clobRef);
+		    f.setValue(fv);
+		}
+		else
+		{
+		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Missing clob information in stream for table ") + tabName);
+		    // set to zero
+		    CegoFieldValue fv;
+		    f.setValue(fv);
+		}
+		fvl.Insert(f);
 	    }
 	    else
 	    {
-		int len = tc.getTypeLen(pF->getType(), colVal);
-		CegoField f(CegoField(pF->getTableName(), pF->getTableAlias(), colName, pF->getType(), len));
+		CegoField f(pF->getTableName(), pF->getTableAlias(), colName, pF->getType(), pF->getLength(), pF->getDim());
 		CegoFieldValue fv(pF->getType(), colVal);
 		f.setValue(fv);
 		fvl.Insert(f);
@@ -239,8 +279,7 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
 	    // null value
 	    CegoField f(CegoField(pF->getTableName(), colName));		    
 	    fvl.Insert(f);
-	}
-	
+	}	
 	pF = _schema.Next();
     }
         
@@ -250,15 +289,12 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
 	_keyList.Empty();
 	_checkList.Empty();
 
-
 	int tabSetId = _pDBMng->getTabSetId(_tableSet);	
 	_pGTM->getObjectWithFix(tabSetId, tabName, CegoObject::TABLE, _oe, _bp);
-	_sysEntry = CegoDataPointer(_bp.getFileId(), _bp.getPageId(), _bp.getEntryPos());
-
-	// _pDBMng->bufferUnfix(_bp, false, _pGTM->getLockHandle());
+	_sysEntry = CegoDataPointer(_bp.getPageId(), _bp.getEntryPos());
 
 	int numInvalid;
-	_pGTM->getObjectListByTable(_oe.getTabSetId(), _oe.getName(), _idxList, _btreeList, _keyList, _checkList, numInvalid);
+	_pGTM->getObjectListByTable(_oe.getTabSetId(), _oe.getName(), _idxList, _btreeList, _keyList, _checkList, _triggerList, _aliasList, numInvalid);
 	_isFirst = false;
     }
 
@@ -268,14 +304,12 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
     while ( pCF && pCV)
     {	    
 	CegoFieldValue fv = pCV->getValue();
-	
+
 	CegoQueryHelper::prepareFieldValue(pCF, fv, _pGTM, _oe.getTabSetId());
-	
 	pCV->setValue(fv); 
 	
 	pCF = _schema.Next();
-	pCV = fvl.Next();
-	
+	pCV = fvl.Next();	
     }
     if ( pCF || pCV )
     {
@@ -284,7 +318,6 @@ void CegoImpInStream::insertData(const Chain& tabName, const ListT<Attribute>& a
 
     CegoDataPointer dp;
     Chain virginIndex;
-
-    _pGTM->insertDataTable(_oe, fvl, _idxList, _btreeList, _keyList, _checkList, _sysEntry, virginIndex, dp, _doLogging);
     
+    _pGTM->insertDataTable(_oe, fvl, _idxList, _btreeList, _keyList, _checkList, _sysEntry, virginIndex, dp, false, true, false, false);
 }
