@@ -270,21 +270,21 @@ Chain CegoJoinObject::toChain(int defTabSetId) const
     {
     case INNER:
     {
-	s += _pLeftObject->toChain(defTabSetId) + Chain(" inner join ") + _pRightObject->toChain(defTabSetId);
+	s += _pLeftObject->toChain(defTabSetId) + Chain("\ninner join ") + _pRightObject->toChain(defTabSetId);
 	if ( _pPred )
 	    s += Chain(" on ") + _pPred->toChain(defTabSetId);
 	break;
     }
     case LEFTOUTER:
     {
-	s += _pLeftObject->toChain(defTabSetId) + Chain(" left outer join ") + _pRightObject->toChain(defTabSetId);
+	s += _pLeftObject->toChain(defTabSetId) + Chain("\nleft outer join ") + _pRightObject->toChain(defTabSetId);
 	if ( _pPred )
 	    s += Chain(" on ") + _pPred->toChain(defTabSetId);
 	break;
     }
     case RIGHTOUTER:
     {
-	s += _pLeftObject->toChain(defTabSetId) + Chain(" right outer join ") + _pRightObject->toChain(defTabSetId);
+	s += _pLeftObject->toChain(defTabSetId) + Chain("\nright outer join ") + _pRightObject->toChain(defTabSetId);
 	if ( _pPred )
 	    s += Chain(" on ") + _pPred->toChain(defTabSetId);
 	break;
@@ -310,6 +310,31 @@ Chain CegoJoinObject::getFormatted() const
     return s;
 }
 
+ListT<Chain> CegoJoinObject::getSubAliasList() const
+{
+
+    ListT<Chain> subList;
+    
+    if ( _pLeftObject )
+    {
+	if ( _pLeftObject->getType() == CegoObject::JOIN )
+	    subList += ((CegoJoinObject*)_pLeftObject)->getSubAliasList();
+	else
+	    subList.Insert(_pLeftObject->getTabAlias());
+    }
+    
+    if ( _pRightObject )
+    {
+	if ( _pRightObject->getType() == CegoObject::JOIN )
+	    subList += ((CegoJoinObject*)_pRightObject)->getSubAliasList();
+	else
+	    subList.Insert(_pRightObject->getTabAlias());
+    }
+
+    return subList;
+}
+
+
 Chain CegoJoinObject::fill(const Chain& s, int num) const
 {
     Chain fs = Chain();
