@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -21,7 +21,6 @@
 // CEGO INCLUDES
 #include "CegoKeyObject.h"
 #include "CegoXMLdef.h"
-#include "CegoXMLHelper.h"
 
 // POSIX INCLUDES
 #include <string.h>
@@ -34,8 +33,6 @@ CegoKeyObject::CegoKeyObject()
 CegoKeyObject::CegoKeyObject(const CegoKeyObject& ko)  : CegoDecodableObject(ko)
 {
     _refTable = ko._refTable;
-    _refLen = ko._refLen;
-    _keyLen = ko._keyLen;
     _keySchema = ko._keySchema;
     _refSchema = ko._refSchema;
     _tabName = ko._tabName;
@@ -99,7 +96,6 @@ const ListT<CegoField>& CegoKeyObject::getRefSchema() const
 
 int CegoKeyObject::getEntrySize() const
 {
-
     int entrySize = CegoObject::getBaseSize();
 
     entrySize += 1; // object tabname size
@@ -127,7 +123,7 @@ int CegoKeyObject::getEntrySize() const
     return entrySize;
 }
 
-void CegoKeyObject::encode(char *buf)
+void CegoKeyObject::encode(char *buf) const
 {
     char* bufPtr = buf;
 
@@ -150,13 +146,13 @@ void CegoKeyObject::encode(char *buf)
     // memcpy (bufPtr, &c , 1);
     bufPtr++;
 	
-    _keyLen = 0;
+    char keyLen = 0;
     CegoField* pK = _keySchema.First();
     while (pK)
     {
 	memcpy(bufPtr, (char*)pK->getAttrName(), pK->getAttrName().length());    
 	bufPtr=bufPtr + pK->getAttrName().length();
-	_keyLen += pK->getAttrName().length();
+	keyLen += pK->getAttrName().length();
 	pK = _keySchema.Next();
     }
     
@@ -167,25 +163,23 @@ void CegoKeyObject::encode(char *buf)
     // memcpy (bufPtr, &c , 1);
     bufPtr++;
 
-    _refLen = 0;
+    char refLen = 0;
     CegoField* pR = _refSchema.First();
     while (pR)
     {
 	// key information
 	memcpy(bufPtr, (char*)pR->getAttrName(), pR->getAttrName().length());    
 	bufPtr=bufPtr + pR->getAttrName().length();
-	_refLen += pR->getAttrName().length();
+	refLen += pR->getAttrName().length();
 	pR = _refSchema.Next();
     }
     
-    memcpy (keyLenPtr, &_keyLen , 1);
-    memcpy (refLenPtr, &_refLen , 1);
-    
+    memcpy (keyLenPtr, &keyLen , 1);
+    memcpy (refLenPtr, &refLen , 1);    
 }
 
 void CegoKeyObject::decode(char *buf)
 {
-
     char* bufPtr = buf;
 
     int size;
@@ -239,10 +233,6 @@ CegoKeyObject& CegoKeyObject::operator = ( const CegoKeyObject& ko)
     CegoObject::operator=(ko);
 
     _refTable = ko._refTable;
-
-    _refLen = ko._refLen;
-    _keyLen = ko._keyLen;
-
     _keySchema = ko._keySchema;
     _refSchema = ko._refSchema;
     _tabName = ko._tabName;
@@ -287,120 +277,6 @@ Chain CegoKeyObject::toChain() const
     return s;
 }
 
-Element* CegoKeyObject::getElement() const
-{
-
-    Element* pRoot = new Element(XML_OBJ_ELEMENT);
-
-    pRoot->setAttribute(XML_TSID_ATTR, Chain(getTabSetId()));
-    pRoot->setAttribute(XML_OBJTYPE_ATTR, XML_FKEYOBJ_VALUE);
-    pRoot->setAttribute(XML_OBJNAME_ATTR, getName());
-
-    pRoot->setAttribute(XML_TABLENAME_ATTR, _tabName);
-    pRoot->setAttribute(XML_REFTABLENAME_ATTR, _refTable);
-
-
-    Element *pKSElement = new Element(XML_KEYSCHEMA_ELEMENT);
-
-    CegoField *pK = _keySchema.First();
-    while ( pK ) 
-    {
-
-	Element *pColElement = new Element(XML_COL_ELEMENT);
-	
-	CegoXMLHelper xh;
-	xh.setColInfo(pColElement, pK);
-
-	pKSElement->addContent(pColElement);
-	pK = _keySchema.Next();
-    }
-
-    pRoot->addContent(pKSElement);
-
-
-    Element *pRSElement = new Element(XML_REFSCHEMA_ELEMENT);
-
-    CegoField *pR = _refSchema.First();
-    while ( pR ) 
-    {
-	Element *pColElement = new Element(XML_COL_ELEMENT);
-
-	CegoXMLHelper xh;
-	xh.setColInfo(pColElement, pR);
-
-	pRSElement->addContent(pColElement);
-	pR = _refSchema.Next();
-    }
-
-    pRoot->addContent(pRSElement);
-
-    return pRoot;
-}
-
-void CegoKeyObject::putElement(Element* pElement)
-{
-    Element *pRoot = pElement;
-    
-    if ( pRoot )
-    {
-	
-	Chain objName = pRoot->getAttributeValue(XML_OBJNAME_ATTR); 
-	setName(objName);
-
-	int tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asInteger();
-	setTabSetId(tabSetId);	
-
-	_tabName = pRoot->getAttributeValue(XML_TABLENAME_ATTR); 
-	_refTable = pRoot->getAttributeValue(XML_REFTABLENAME_ATTR); 
-
-	Chain objType = pRoot->getAttributeValue(XML_OBJTYPE_ATTR);
-	setType(CegoObject::FKEY);
-	
-	ListT<Element*> keySchemaList = pRoot->getChildren(XML_KEYSCHEMA_ELEMENT);
-	
-	ListT<CegoField> kfl;
-	Element **pKS = keySchemaList.First();
-	if ( pKS ) 
-	{
-	    
-	    ListT<Element*> keyColList = (*pKS)->getChildren(XML_COL_ELEMENT);
-	    Element **pCol = keyColList.First();
-	    while( pCol ) 
-	    {
-		CegoXMLHelper xh;
-		CegoField f;
-		xh.getColInfo(objName, *pCol, f);
-		kfl.Insert(f);
-		pCol = keyColList.Next();
-	    }
-	}
-
-	setKeySchema(kfl);
-
-	ListT<Element*> refSchemaList = pRoot->getChildren(XML_REFSCHEMA_ELEMENT);
-	
-	ListT<CegoField> rfl;
-	Element **pRS = refSchemaList.First();
-	if ( pRS ) 
-	{
-	    
-	    ListT<Element*> refColList = (*pRS)->getChildren(XML_COL_ELEMENT);
-	    Element **pCol = refColList.First();
-	    while( pCol ) 
-	    {
-		CegoXMLHelper xh;
-		CegoField f;
-		xh.getColInfo(objName, *pCol, f);
-		rfl.Insert(f);
-		pCol = refColList.Next();
-	    }
-	}
-	
-	setRefSchema(rfl);
-
-    }
-}
-
 Chain CegoKeyObject::getFormatted() const
 {
     Chain s;
@@ -432,12 +308,10 @@ Chain CegoKeyObject::getFormatted() const
 	
     s += "| ObjectType : fkey " +  fill(" ", maxAttrLen - 18) + "|\n";
 
-
     s += "| Table      : " + _tabName;
     s += fill(" ", maxAttrLen - 12 - _tabName.length()) + "|" + "\n";
     s += "| RefTable   : " + _refTable;
     s += fill(" ", maxAttrLen - 12 -_refTable.length()) + "|" + "\n";
-
 	
     s += "+---------" + fill("-", maxAttrLen1-9)  + "+---------" +  fill("-", maxAttrLen2-9) + "+\n";
     s += "| KeyAttr " +  fill(" ", maxAttrLen1-9) + "| RefAttr " +  fill(" ", maxAttrLen2-9) + "|\n";
@@ -446,8 +320,7 @@ Chain CegoKeyObject::getFormatted() const
     pK = _keySchema.First();
     pR = _refSchema.First();
     while (pK && pR)
-    {
-	
+    {	
 	int num = maxAttrLen1 - pK->getAttrName().length() ;
 
 	s += "| " + pK->getAttrName() + fill(" ", num) + "| ";
@@ -457,23 +330,19 @@ Chain CegoKeyObject::getFormatted() const
 
 	pK = _keySchema.Next();
 	pR = _refSchema.Next();
-
     }
     s +="+" + fill("-", maxAttrLen1) + "+" + fill("-", maxAttrLen2) + "+\n";
-
-    
+   
     return s;
 }
 
 Chain CegoKeyObject::fill(const Chain& s, int num) const
-{
-    
-    Chain fs = Chain("");
+{    
+    Chain fs = Chain();
     while (num > 0)
     {
 	fs = fs + s;
 	num--;
     }
-
     return fs;
 }
