@@ -6,7 +6,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -46,7 +46,7 @@ CegoLogHandler::~CegoLogHandler()
     delete pDoc;
 }
 
-void CegoLogHandler::requestLogSession(const Chain& tableSet)
+void CegoLogHandler::requestLogSession(const Chain& tableSet, const Chain& logUser, const Chain& logPwd)
 {
     _pModule->log(_modId, Logger::DEBUG, Chain("Request log session ..."));
     _xml.getDocument()->clear();
@@ -54,7 +54,10 @@ void CegoLogHandler::requestLogSession(const Chain& tableSet)
     Element* pRoot = new Element(XML_FRAME_ELEMENT);
     _xml.getDocument()->setRootElement(pRoot);
     _xml.getDocument()->setDocType(Chain(XML_LOGSESSION_REQUEST));
+    
     _xml.getDocument()->setAttribute(XML_TABLESET_ATTR, tableSet);
+    _xml.getDocument()->setAttribute(XML_USER_ATTR, logUser);
+    _xml.getDocument()->setAttribute(XML_PASSWD_ATTR, logPwd);
 
     Chain request;
     _xml.getXMLChain(request);
@@ -63,13 +66,12 @@ void CegoLogHandler::requestLogSession(const Chain& tableSet)
     _pN->recvAck();
 }
 
-bool CegoLogHandler::acceptLogSession(Chain& tableSet)
+bool CegoLogHandler::acceptLogSession(Chain& tableSet, Chain& logUser, Chain& logPwd)
 {
-	    
     _pModule->log(_modId, Logger::DEBUG, Chain("Accepting session"));
             
-    try {
-
+    try
+    {
 	_xml.getDocument()->clear();
 	_xml.setChain( _pN->getMsg() );	
 	_xml.parse();
@@ -84,21 +86,20 @@ bool CegoLogHandler::acceptLogSession(Chain& tableSet)
 	else
 	{
 	    tableSet = _xml.getDocument()->getAttributeValue(XML_TABLESET_ATTR);
+	    
 	    _pN->sendAck();
 	    return true;
 	}	
     }
     catch ( Exception e)
-    {
-	
+    {	
 	Chain msg;
 	e.pop(msg);
 	
 	_pModule->log(_modId, Logger::LOGERR, Chain("Aborting session. Reason=") + msg);
 	
 	_pN->sendNack();
-	return false;
-	
+	return false;	
     }
 }
 
@@ -129,7 +130,6 @@ void CegoLogHandler::getTableSet(Chain& tableSet)
 
 bool CegoLogHandler::sendLogEntry(char* logBuf, int len)
 {
-
     try 
     {
 	_pN->setMsg(logBuf, len);
@@ -154,7 +154,6 @@ void CegoLogHandler::closeSession()
 
 bool CegoLogHandler::receiveLogEntry(char* &logBuf, int &len)
 {
-
     try 
     {
 	_pN->readMsg();
