@@ -41,6 +41,7 @@
 #include <lfcbase/Host.h>
 #include <lfcbase/ThreadLock.h>
 #include <lfcxml/XMLSuite.h>
+#include <lfcbase/Datetime.h>
 
 // CEGO INCLUDES
 #include "CegoDbThreadPool.h"
@@ -81,6 +82,9 @@
                            --dbxml=<filename>\n\
 \n\
   Creation Mode:      cego --mode=create --tableset=<string> --dbxml=<filename>\n\
+\n\
+  Query Cache Mode:   cego --mode=querycache --tableset=<string> [ --enable ]\n\
+                         [ --maxsize=<int> ] [ --maxentry=<int> ] [ --hashrange=<int> ] [ --threshold=<int> ] --dbxml=<filename>\n\
 \n\
   Export Mode:        cego --mode={xmlexport|binexport|plainexport} --expfile=<filename>\n\
                            --tableset=<string> --dbxml=<filename> --user=<string>/<string>\n\
@@ -97,7 +101,7 @@
                            [ --poolsize=[<numseg>x]<segsize> ] [ --pidfile=<filename> ] [ --protocol={serial|xml|fastserial}]\n\
                            [ --master=<host>:<port>:<user>:<passwd> ]\n\
 \n\
-  General Options:    [ --logfile=<filename> ] [--syslog=yes|no ] [ --lockfile=<filename> ] [ --lockstat ] [ --fsync ]\n"
+  General Options:    [ --logfile=<filename> ] [--syslog=yes|no ] [ --lockfile=<filename> ] [ --lockexpire=<int> ] [ --lockstat ] [ --fsync ]\n"
 
 // DEFINES
 #define SYSLOGPROGNAME "cego"
@@ -132,7 +136,7 @@
 #define DEFAULTLOGPORT 3000
 #define DEFAULTCSMODE "ID"
 #define DEFAULTQESCMODE "ON"
-
+#define DEFAULTLOCKEXPIRE 0
 #define DEFAULTLOGLEVEL "NOTICE"
 
 #define LANGUAGE_ENV "LANG"
@@ -151,9 +155,11 @@ extern char __quoteEscapeFlag;
 extern char __allowDuplicateNull;
 extern char __currencySymbol;
 extern char __decimalPoint;
+extern BigDecimal::RoundMode __roundMode;
 
 // how to format date on default
 extern Chain __dateTimeFormat;
+extern int __dateLength;
 // valid date time scan formats
 extern ListT<Chain> __dateFormatList;
 // since the date format list is accessed by several threads, we have to provide a mutex lock for it
@@ -177,6 +183,7 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format);
 int runBatch(GetLongOpt& longOpt);
 int runDaemon(GetLongOpt& longOpt);
 bool getPoolInfo(const Chain& poolSize, int& numSeg, int& segSize);
+int setQueryCache(GetLongOpt& longOpt);
 
 int main(int argc, char **argv)
 {	
@@ -201,6 +208,7 @@ int main(int argc, char **argv)
     longOpt.addOpt("cleanup");
     longOpt.addOpt("cpdump");
     longOpt.addOpt("forceload");
+    longOpt.addOpt("lockexpire", Chain(DEFAULTLOCKEXPIRE));
     longOpt.addOpt("lockstat");
     longOpt.addOpt("fsync");
     longOpt.addOpt("role", DEFAULTROLE);
@@ -217,6 +225,13 @@ int main(int argc, char **argv)
     longOpt.addOpt("numadminthread", Chain(DEFAULTADMINTHREADNUM));
     longOpt.addOpt("numlogthread", Chain(DEFAULTLOGTHREADNUM));
     longOpt.addOpt("master");
+    // query cache options
+    longOpt.addOpt("enable");
+    longOpt.addOpt("maxsize");
+    longOpt.addOpt("maxentry");
+    longOpt.addOpt("hashrange");
+    longOpt.addOpt("threshold");
+    // general options
     longOpt.addOpt("logfile", DEFAULTLOGFILE);
     longOpt.addOpt("syslog", DEFAULTSYSLOG);
     longOpt.addOpt("lockfile", DEFAULTLOCKFILE);
@@ -408,6 +423,11 @@ int main(int argc, char **argv)
 	// don't run as background daemon
 	exitCode = runDaemon(longOpt);
     }
+    else if ( mode == Chain("querycache") )
+    {
+	exitCode = setQueryCache(longOpt);
+    }
+
     else
     {
 	cerr << USAGE << endl;
@@ -434,6 +454,9 @@ void readParameter(CegoDatabaseManager *pDBMng)
     if ( __dateTimeFormat == Chain() )
 	__dateTimeFormat = Chain(DEFAULTDATETIMEFORMAT1);
 
+    Datetime d(PROOFDATE_VALUE, PROOFDATE_FORMAT);
+    __dateLength = d.asChain(__dateTimeFormat).length();
+    
     __dateFormatLock.writeLock(DF_LOCKTIMEOUT);    
     __dateFormatList = pDBMng->getDateFormatList();	
     if ( __dateFormatList.Size() == 0 )
@@ -444,6 +467,9 @@ void readParameter(CegoDatabaseManager *pDBMng)
 	__dateFormatList.Insert(DEFAULTDATETIMEFORMAT4);
     }
     __dateFormatLock.unlock();
+
+    __roundMode = pDBMng->getRoundMode();
+    
 }
 
 int init(GetLongOpt& longOpt)
@@ -466,6 +492,8 @@ int init(GetLongOpt& longOpt)
 	Chain admport = longOpt.getOptValue("admport");
 	Chain logport = longOpt.getOptValue("logport");
 	Chain csmode = longOpt.getOptValue("csmode");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	
 	if ( csmode != Chain(XML_ID_VALUE) && csmode != Chain(XML_STR_VALUE) && csmode != Chain(XML_NONE_VALUE))
 	{
 	    throw Exception(EXLOC, "Invalid value for csmode ( must be ID, STR or NONE)");
@@ -496,7 +524,7 @@ int init(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 
 	pDBMng->initXml(dbName, pgsize.asInteger(), hostname, dbport.asInteger(), admport.asInteger(), logport.asInteger(), pidfile, logLevel,
 			csmode, qescmode == Chain(XML_ON_VALUE) );
@@ -526,7 +554,9 @@ int addUser(GetLongOpt& longOpt)
     {	
 	Chain syslog = longOpt.getOptValue("syslog");	
 	Chain logFile = longOpt.getOptValue("logfile");	
-	Chain lockFile = longOpt.getOptValue("lockfile");	
+	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain userName = longOpt.getOptValue("user");
 	Chain userRole = longOpt.getOptValue("role");
@@ -556,7 +586,7 @@ int addUser(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 	
 	pDBMng->xml2Doc();
 	pDBMng->configureLogger();
@@ -592,7 +622,9 @@ int setPwd(GetLongOpt& longOpt)
     {	
 	Chain syslog = longOpt.getOptValue("syslog");	
 	Chain logFile = longOpt.getOptValue("logfile");	
-	Chain lockFile = longOpt.getOptValue("lockfile");	
+	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain userName = longOpt.getOptValue("user");
 
@@ -621,7 +653,7 @@ int setPwd(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 	
 	pDBMng->xml2Doc();
 	pDBMng->configureLogger();
@@ -657,6 +689,8 @@ int addRole(GetLongOpt& longOpt)
 	Chain syslog = longOpt.getOptValue("syslog");
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain role = longOpt.getOptValue("role");
 	Chain filter = longOpt.getOptValue("filter");
@@ -671,7 +705,7 @@ int addRole(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 		
 	pDBMng->xml2Doc();
 	pDBMng->configureLogger();     
@@ -705,6 +739,8 @@ int addPerm(GetLongOpt& longOpt)
 	Chain syslog = longOpt.getOptValue("syslog");
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain role = longOpt.getOptValue("role");
 	Chain filter = longOpt.getOptValue("filter");
@@ -721,7 +757,7 @@ int addPerm(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);       
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);       
 	
 	pDBMng->xml2Doc();
 	pDBMng->configureLogger();	
@@ -754,7 +790,8 @@ int defineTableSet(GetLongOpt& longOpt)
     {	
 	Chain syslog = longOpt.getOptValue("syslog");
 	Chain logFile = longOpt.getOptValue("logfile");
-	Chain lockFile = longOpt.getOptValue("lockfile"); 
+	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire"); 
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain tableSet = longOpt.getOptValue("tableset");
 	Chain tsDef = longOpt.getOptValue("tsdef");
@@ -776,7 +813,7 @@ int defineTableSet(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 	       
 	pDBMng->xml2Doc();
 	pDBMng->configureLogger();
@@ -867,7 +904,8 @@ int createTableSet(GetLongOpt& longOpt)
     {	
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain syslog = longOpt.getOptValue("syslog");
-	Chain lockFile = longOpt.getOptValue("lockfile");	
+	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain tableSet = longOpt.getOptValue("tableset");
 	Chain poolSize = longOpt.getOptValue("poolsize");
@@ -886,8 +924,8 @@ int createTableSet(GetLongOpt& longOpt)
 	Chain progName = SYSLOGPROGNAME;
 	if ( syslog == Chain("no") )
 	    progName=Chain();
-
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire,logFile, progName);
 
 	pDBMng->xml2Doc();
 	pDBMng->initDoc();
@@ -945,6 +983,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	Chain syslog = longOpt.getOptValue("syslog");
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain tableSet = longOpt.getOptValue("tableset");
 	Chain poolSize = longOpt.getOptValue("poolsize");
@@ -976,7 +1015,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 
 	pDBMng->xml2Doc();
 	pDBMng->initDoc();
@@ -1114,6 +1153,7 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	Chain syslog = longOpt.getOptValue("syslog");
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain tableSet = longOpt.getOptValue("tableset");
 	Chain poolSize = longOpt.getOptValue("poolsize");
@@ -1146,7 +1186,7 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 	pDBMng->setReadOnly(true);	
 	pDBMng->xml2Doc();
 	pDBMng->initDoc();
@@ -1283,6 +1323,7 @@ int runBatch(GetLongOpt& longOpt)
 	Chain syslog = longOpt.getOptValue("syslog");
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain tableSet = longOpt.getOptValue("tableset");
 	Chain poolSize = longOpt.getOptValue("poolsize");
@@ -1313,7 +1354,7 @@ int runBatch(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 
 	pDBMng->xml2Doc();
 	
@@ -1440,6 +1481,7 @@ int runDaemon(GetLongOpt& longOpt)
 	Chain numLogThread = longOpt.getOptValue("numlogthread");
 	Chain master = longOpt.getOptValue("master");
 	Chain protocol = longOpt.getOptValue("protocol");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
 	bool cleanIt = longOpt.isSet("cleanup");
 	bool forceload = longOpt.isSet("forceload");
 	bool cpDump = longOpt.isSet("cpdump");
@@ -1471,7 +1513,7 @@ int runDaemon(GetLongOpt& longOpt)
 	if ( syslog == Chain("no") )
 	    progName=Chain();
 	
-	pDBMng = new CegoDatabaseManager(dbXML, lockFile, logFile, progName, protType);
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName, protType);
 		
 	pMedThread = new CegoMediatorThread(pDBMng);
 	    	
@@ -1766,7 +1808,7 @@ int runDaemon(GetLongOpt& longOpt)
 	    pDBMng->beat();
 	    
 	    Sleeper s;
-	    s.secSleep(NETMNG_BEATDELAY);
+	    s.secSleep(LCKMNG_BEATDELAY);
 	}
 	
 	cout << "Terminating ..." << endl;
@@ -1872,6 +1914,112 @@ int runDaemon(GetLongOpt& longOpt)
 }
 
 
+int setQueryCache(GetLongOpt& longOpt)
+{
+    int exitCode = 0;
+
+    CegoDatabaseManager* pDBMng = 0;
+
+    try
+    {	
+
+	Chain syslog = longOpt.getOptValue("syslog");
+	Chain logFile = longOpt.getOptValue("logfile");
+	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	Chain dbXML = longOpt.getOptValue("dbxml");
+	Chain tableSet = longOpt.getOptValue("tableset");
+	bool isEnabled = longOpt.isSet("enable");
+	
+	Chain maxSize;
+	if ( longOpt.isSet("maxsize") )
+	    maxSize = longOpt.getOptValue("maxsize");
+	
+	Chain maxEntry;
+	if ( longOpt.isSet("maxentry") )
+	    maxEntry = longOpt.getOptValue("maxentry");
+	
+	Chain hashRange;
+	if ( longOpt.isSet("hashrange") )
+	    hashRange = longOpt.getOptValue("hashrange");
+	
+	Chain threshold;
+	if ( longOpt.isSet("threshold") )
+	    threshold = longOpt.getOptValue("threshold");	
+
+	if ( dbXML.length() == 0  || dbXML == Chain() )
+	{
+	    throw Exception(EXLOC, "No dbxml set");
+	}
+	if ( tableSet.length() == 0 || tableSet == Chain() )
+	{
+	    throw Exception(EXLOC, "No tableSet set");
+	}
+
+	Chain progName = SYSLOGPROGNAME;
+	if ( syslog == Chain("no") )
+	    progName=Chain();
+	
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
+	       
+	pDBMng->xml2Doc();
+	pDBMng->configureLogger();
+	
+	pDBMng->setQueryCacheMode(tableSet,
+				  isEnabled);
+
+	if ( maxSize.length() > 0 )
+	{
+	    if ( maxSize.isNum() )
+		pDBMng->setMaxQueryCacheSize(tableSet, maxSize.asInteger());
+	    else
+		throw Exception(EXLOC, "Invalid querycache maxsize");
+	}
+	
+	if ( maxEntry.length() > 0 )
+	{
+	    if ( maxEntry.isNum() )
+		pDBMng->setMaxQueryCacheEntry(tableSet, maxEntry.asInteger());
+	    else
+		throw Exception(EXLOC, "Invalid querycache maxentry");
+	}
+
+	if ( threshold.length() > 0 )
+	{
+	    if ( threshold.isNum() )
+		pDBMng->setQueryCacheThreshold(tableSet, threshold.asInteger());
+	    else
+		throw Exception(EXLOC, "Invalid querycache threshold");
+	}
+	
+	if ( hashRange.length() > 0 )
+	{
+	    if ( hashRange.isNum() )
+		pDBMng->setQueryCacheHashRange(tableSet, hashRange.asInteger());
+	    else
+		throw Exception(EXLOC, "Invalid querycache hashrange");
+	}
+	       	
+	pDBMng->doc2Xml();
+	
+	delete pDBMng;	
+    }
+    catch (Exception e)
+    {
+	if ( pDBMng ) 
+	    delete pDBMng;
+
+	Chain msg;
+	e.pop(msg);
+	cerr << msg << endl;
+	exitCode = 1;
+    }
+    
+    return exitCode;
+}
+
+
+
 bool getPoolInfo(const Chain& poolSize, int& numSeg, int& segSize)
 {
     Tokenizer tok(poolSize, "xX");
