@@ -6,7 +6,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke
 //               
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -43,7 +43,7 @@ CegoMediatorThread::~CegoMediatorThread()
     while ( _joined == false && count < 10 )
     {
 	Sleeper s;
-	s.secSleep(1);
+	s.milliSleep(100);
 	count++;
     }
     
@@ -61,8 +61,7 @@ CegoMediatorThread::~CegoMediatorThread()
 
 void CegoMediatorThread::getDbSpec(const Chain& dbSpecFileName, const Chain& medHost, int medPort, const Chain& user, const Chain& passwd)
 {
-
-    Net n ( NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN );
+    Net n ( NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, NETMNG_MAXSENDLEN );
     
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Connecting to ") + medHost + Chain(":") + Chain(medPort) + Chain(" ..."));
 
@@ -80,8 +79,7 @@ void CegoMediatorThread::getDbSpec(const Chain& dbSpecFileName, const Chain& med
 	_pDBMng->log(_modId, Logger::NOTICE,  msg);
     }
     else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	
+    {	
 	Chain msg;
 	pAH->getMsg(msg);
 
@@ -89,8 +87,7 @@ void CegoMediatorThread::getDbSpec(const Chain& dbSpecFileName, const Chain& med
 	delete pN;
 
 	throw Exception(EXLOC, msg);
-    }
-	    
+    }	    
     
     Chain dbSpec;
     res = pAH->reqGetDbSpec(dbSpec);
@@ -101,18 +98,15 @@ void CegoMediatorThread::getDbSpec(const Chain& dbSpecFileName, const Chain& med
 	pAH->getMsg(msg);
 	
 	_pDBMng->log(_modId, Logger::NOTICE,  msg);
-	
-	
+		
 	File dbSpecFile(dbSpecFileName);
 	
 	dbSpecFile.open(File::WRITE);
 	dbSpecFile.writeChain(dbSpec);
 	dbSpecFile.close();
-	
     }
     else if ( res == CegoAdminHandler::ADM_ERROR )
     {
-	
 	Chain msg;
 	pAH->getMsg(msg);
 
@@ -120,38 +114,37 @@ void CegoMediatorThread::getDbSpec(const Chain& dbSpecFileName, const Chain& med
 	delete pAH;
 	delete pN;
 
-	throw Exception(EXLOC, msg);
-       
+	throw Exception(EXLOC, msg);  
     } 
 
     pAH->closeSession();
     
     delete pAH;
     delete pN;
-
 }
 
 void* CegoMediatorThread::job(void* arg)
 {
-
     while ( _terminated == false )
     {
 	try
 	{
 	    _pDBMng->cleanSession(NETMNG_DBHANDLE_TTL);
-	    
+
+	    int i=0;
 	    Sleeper s;
-	    s.secSleep(NETMNG_DBHANDLE_CHK);
-	    
+	    // NETMNG_DBHANDLE_CHK is given in seconds
+	    while( i < NETMNG_DBHANDLE_CHK * 1000 && _terminated == false )
+	    {
+		s.milliSleep(100);
+		i+=100;
+	    }   
 	}
 	catch ( Exception e)
 	{
 	    e.print();
-	}
-	
+	}	
     }
-
     _joined = true;
-
     return 0;
 }
