@@ -6,7 +6,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2010-2016 Bjoern Lemke
+// (C)opyright 2010-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -20,6 +20,7 @@
 
 // POSIX INCLUDES
 #include <locale.h>
+#include <stdlib.h>
 
 // CEGO INCLUDES
 #include "CegoNet.h"
@@ -34,6 +35,7 @@
 extern Chain __dateTimeFormat;
 extern char __currencySymbol;
 extern char __decimalPoint;
+extern char __quoteEscapeFlag;
 
 CegoNet::CegoNet(CegoDbHandler::ProtocolType protType, const Chain& logFile, const Chain& progName, const Chain& logMode)
 {
@@ -68,9 +70,9 @@ CegoNet::~CegoNet()
 	delete _pModule;
 }
 
-void CegoNet::connect(const Chain& serverName, int port, const Chain& tableSet, const Chain& user, const Chain& pwd)
+void CegoNet::connect(const Chain& serverName, int port, const Chain& tableSet, const Chain& user, const Chain& pwd, int maxSendLen)
 {
-    Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN );
+    Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, maxSendLen );
 
     _pN = n.connect(serverName, port);
 
@@ -100,28 +102,24 @@ void CegoNet::connect(const Chain& serverName, int port, const Chain& tableSet,
     }
 
     __dateTimeFormat = _pSH->getDateFormat();
-
+    __quoteEscapeFlag = _pSH->getQuoteEscapeFlag();
+    
     const struct lconv * const currentlocale = localeconv();
 
     __currencySymbol = *currentlocale->currency_symbol;
-    __decimalPoint = *currentlocale->decimal_point;        
-    
+    __decimalPoint = *currentlocale->decimal_point;    
 }
    
-long CegoNet::doQuery(const Chain& query)
+unsigned long long CegoNet::doQuery(const Chain& query)
 {        
-
-    CegoDbHandler::ResultType res;
-
     _isFetchable=false;
-
-    res = _pSH->reqQueryOp(query);
-
+   
+    CegoDbHandler::ResultType res = _pSH->reqQueryOp(query);
+        
     if ( res == CegoDbHandler::DB_OK )
     {
 	Chain msg = _pSH->getMsg();
-	long affCount = _pSH->getAffected();
-	return affCount;
+	return _pSH->getAffected();
     }
     else if ( res == CegoDbHandler::DB_DATA )
     {
@@ -138,9 +136,7 @@ long CegoNet::doQuery(const Chain& query)
 	Chain msg = _pSH->getMsg();
 	throw Exception(EXLOC, msg);      
     }
-
     return 0;
-
 }
 
 void CegoNet::putBlob(CegoBlob& blob)
@@ -179,10 +175,8 @@ void CegoNet::deleteClob(CegoClob& clob)
 	throw Exception(EXLOC, Chain("Cannot delete clob"));
 }
 
-
 bool CegoNet::fetchData(const ListT<CegoField>& schema, ListT<CegoFieldValue>& fvl)
 {
-
     if ( _isFetchable == true )
     {
 	CegoDbHandler::ResultType res;
@@ -226,6 +220,16 @@ unsigned long long CegoNet::getTid() const
     return _pSH->getTid();
 }
 
+const Chain& CegoNet::getDbName() const
+{
+    return _pSH->getDbName();
+}
+
+const Chain& CegoNet::getDbVersion() const
+{
+    return _pSH->getDbVersion();
+}
+
 void CegoNet::reqAbortQuery(unsigned long long tid)
 {
     _pSH->reqQueryAbort(tid);	    	    
