@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -41,38 +41,34 @@ public:
 		      PBTREE,
 		      UBTREE,
 		      BTREE,
+		      TRIGGER,
+		      ALIAS,
 		      UNDEFINED};
 
     CegoObject();
     CegoObject(const CegoObject& oe);
     CegoObject(ObjectType type,  const Chain& objName, int tabSetId = 0);
-
     ~CegoObject();
     
     void setName(const Chain& name);
     const Chain& getName() const;
-
     void setType(ObjectType type);
     ObjectType getType() const;
-
     void setTabSetId(int tabSetId);
     int getTabSetId() const;
-
     int getBaseSize() const;
-    void encodeBase(char *buf, int entrySize);
+    void encodeBase(char *buf, int entrySize) const;
     void decodeBase(char *buf, int& entrySize);
+    int size() const;
+    Chain toChain() const;
             
     CegoObject& operator = ( const CegoObject& oe);
     bool operator == ( const CegoObject& oe);
 
-    int size() const;
-    Chain toChain() const;
-
 private:
     
     ObjectType _type;
     Chain _name;
-    int _tabSetId;
-    
+    int _tabSetId;    
 };
 #endif
