@@ -6,7 +6,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -22,9 +22,10 @@
 #include "CegoOrderCursor.h"
 #include "CegoOrderNode.h"
 
-CegoOrderCursor::CegoOrderCursor(AVLTreeT<CegoOrderNode> *pAVL)
+CegoOrderCursor::CegoOrderCursor(AVLTreeT<CegoOrderNode> *pAVL, ListT<CegoField>& schema)
 {
     _pAVL = pAVL;
+    _schema = schema;
 }
 
 CegoOrderCursor::~CegoOrderCursor()
@@ -37,7 +38,16 @@ bool CegoOrderCursor::getFirst(ListT<CegoField>& fl)
 
     if ( pN )
     {
-	fl = pN->getTuple();
+	fl = _schema;
+
+	CegoField* pF = fl.First();
+	CegoFieldValue* pV = pN->getTuple().First();
+	while ( pF && pV)
+	{
+	    pF->setValue(*pV);
+	    pF = fl.Next();
+	    pV = pN->getTuple().Next();
+	}
 	return true;
     }
     return false;
@@ -45,12 +55,20 @@ bool CegoOrderCursor::getFirst(ListT<CegoField>& fl)
 
 bool CegoOrderCursor::getNext(ListT<CegoField>& fl)
 {
-
     CegoOrderNode* pN = _pAVL->Next();
 
     if ( pN )
     {
-	fl = pN->getTuple();
+	fl = _schema;
+
+	CegoField* pF = fl.First();
+	CegoFieldValue* pV = pN->getTuple().First();
+	while ( pF && pV)
+	{
+	    pF->setValue(*pV);
+	    pF = fl.Next();
+	    pV = pN->getTuple().Next();
+	}
 	return true;
     }
     return false;
