@@ -6,7 +6,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -22,6 +22,7 @@
 #include <lfcbase/Exception.h>
 #include <lfcbase/Tokenizer.h>
 #include <lfcbase/Datetime.h>
+
 // CEGO INCLUDES
 #include "CegoProcAssignStmt.h"
 #include "CegoDatabaseFormater.h"
@@ -31,7 +32,7 @@ CegoProcAssignStmt::CegoProcAssignStmt(CegoExpr *pExpr,
 {
     _mode = EXPR2NULL;
     _pExpr = pExpr;
-    _pExpr->setBlock(pBlock);
+    _pBlock = pBlock;
 }
 
 CegoProcAssignStmt::CegoProcAssignStmt(const Chain& paramName,
@@ -41,7 +42,7 @@ CegoProcAssignStmt::CegoProcAssignStmt(const Chain& paramName,
     _mode = EXPR2PARAM;
     _paramName = paramName;
     _pExpr = pExpr;
-    _pExpr->setBlock(pBlock);
+    _pBlock = pBlock;
 }
 
 CegoProcAssignStmt::~CegoProcAssignStmt()  
@@ -53,25 +54,66 @@ CegoProcAssignStmt::~CegoProcAssignStmt()
 }
 
 CegoException CegoProcAssignStmt::execute()
-{    
-    switch ( _mode )
+{
+    try
     {
-    case CegoProcAssignStmt::EXPR2NULL:
+	/*
+	ListT<CegoField> *pFL = getParentBlock()->getTriggerValueList();
+	
+	if ( pFL )
+	{
+	    CegoField *pF = pFL->First();
+	    while ( pF )
+	    {
+		pF = pFL->Next();
+	    }
+	}
+	*/
+	
+	
+	switch ( _mode )
+	{
+	case CegoProcAssignStmt::EXPR2NULL:
+	{
+	    CegoFieldValue fv;
+
+	    ListT<CegoField>* fl[2];
+	    fl[0] = _pBlock->getTriggerValueList();
+	    fl[1] = 0;
+
+	    fv = _pExpr->evalFieldValue(fl, _pBlock);
+	    break;
+	}
+	case CegoProcAssignStmt::EXPR2PARAM:
+	{
+	    ListT<CegoField>* fl[2];
+	    fl[0] = _pBlock->getTriggerValueList();
+	    fl[1] = 0;
+
+	    setValue(_paramName, _pExpr->evalFieldValue(fl, _pBlock));
+	    break;
+	}
+	}
+	return NONE_EXCEP;
+    }
+    catch ( Exception e )
     {
-	CegoFieldValue fv;
-	fv = _pExpr->evalFieldValue();
-	break;
+	Chain excepMsg;
+	e.pop(excepMsg);
+	getParentBlock()->setExceptionMsg(excepMsg);
+	return COREOP_EXCEP;
     }
-    case CegoProcAssignStmt::EXPR2PARAM:
-    {
-	setValue(_paramName, _pExpr->evalFieldValue());
-	break;
-    }
-    }
-    return NONE_EXCEP;
 }
 
-Chain CegoProcAssignStmt::toChain(const Chain& indent) const
+void CegoProcAssignStmt::cleanUp()  
+{
+    if ( _pExpr )
+    {
+	_pExpr->cleanUp();
+    }
+}
+
+Chain CegoProcAssignStmt::toChain(int defTabSetId, const Chain& indent) const
 {
     Chain s;
 	
@@ -79,16 +121,19 @@ Chain CegoProcAssignStmt::toChain(const Chain& indent) const
     {
     case CegoProcAssignStmt::EXPR2NULL:
     {
-	s =  indent + _pExpr->toChain();
+	s =  indent + _pExpr->toChain(defTabSetId, indent);
 	break;
     }
     case CegoProcAssignStmt::EXPR2PARAM:
     {
-	s = indent + Chain(":")  + _paramName + " = " + _pExpr->toChain();
+	Chain prefix = Chain(":")  + _paramName + Chain(" = ");
+	Chain addIndent;
+	for ( int i=0; i<prefix.length(); i++ )
+	    addIndent += Chain(" ");
+	s = indent + prefix + _pExpr->toChain(defTabSetId, indent + addIndent);
 	break;
     }
     }
-
     return s;
 }
 
@@ -96,3 +141,16 @@ Chain CegoProcAssignStmt::dbFormat(CegoDatabaseFormater *pForm) const
 {
     return pForm->formatProcAssignStmt(_mode, _paramName, _pExpr);
 }
+
+bool CegoProcAssignStmt::isStatic() const
+{
+    try
+    {
+	_pExpr->getId(_pBlock);
+	return true;
+    }
+    catch ( Exception e )
+    {
+	return false;
+    }
+}
