@@ -6,7 +6,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke
 //               
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -28,10 +28,12 @@
 CegoProcBlock::CegoProcBlock(CegoProcBlock *pParentBlock)
 {
     _pParentBlock = pParentBlock;
+    _pTriggerValueList = 0;
+    _isEval=false;
 }
 
 CegoProcBlock::~CegoProcBlock()  
-{
+{    
     CegoProcStmt **pStmt = _stmtList.First();
     while (pStmt)
     {
@@ -114,7 +116,6 @@ CegoProcBlock* CegoProcBlock::getParentBlock()
 
 void CegoProcBlock::setValue(const Chain& varName, const CegoFieldValue& fv)
 {
-
     CegoProcVar *pVar = _varList.Find(CegoProcVar(varName));
     if ( pVar )
     {
@@ -136,7 +137,6 @@ void CegoProcBlock::setValue(const Chain& varName, const CegoFieldValue& fv)
 
 CegoFieldValue CegoProcBlock::getValue(const Chain& varName)
 {
-
     if ( varName ==  Chain(EXCEPINFO))
 	return CegoFieldValue(VARCHAR_TYPE, _exceptionMsg);
     
@@ -170,15 +170,14 @@ void CegoProcBlock::addException(CegoProcException* pE)
     _exceptionList.Insert(pE);   
 }
 
-CegoException CegoProcBlock::execute() 
-{
-        
+CegoException CegoProcBlock::execute(ListT<CegoField> *pFVL) 
+{       
     CegoProcStmt **pStmt = _stmtList.First();
 
     while (pStmt)
     {
-	try {
-
+	try
+	{
 	    CegoException excep;
 
 	    if ( ( excep = (*pStmt)->execute() ) != NONE_EXCEP ) 
@@ -201,23 +200,27 @@ CegoException CegoProcBlock::execute()
 		    }
 		    pException = _exceptionList.Next();
 		}
-		// propagate exception to parent block
-		if ( excep != NONE_EXCEP &&  _pParentBlock )
+		
+		// propagate exception to parent block		
+		if ( excep != NONE_EXCEP && _pParentBlock )
 		    _pParentBlock->setExceptionMsg( getExceptionMsg() );
+
 		closeBlock();
+		
 		return excep;
 	    }
 	}
 	catch ( Exception e )
-	{	    
-	    // Chain msg = Chain("Procedure error at stmt \n----------\n") + (*pStmt)->toChain() + Chain("\n----------\nwith error\n##########\n") +  e.getBaseMsg() + Chain("\n##########");
-
+	{
+	    Chain errMsg;
+	    e.pop(errMsg);
 	    Chain plainStmt;
-	    (*pStmt)->toChain().replaceAll(Chain("\n"), Chain(" "), plainStmt);
-	    Chain msg = Chain("Procedure error at stmt <") + plainStmt + Chain(">");
+	    (*pStmt)->toChain(0).replaceAll(Chain("\n"), Chain(" "), plainStmt);
+	    Chain msg = Chain("Procedure block error at stmt <") + plainStmt + Chain("> : ") + errMsg;
+
 	    closeBlock();
 
-	    throw Exception(EXLOC, msg, e);
+	    throw Exception(EXLOC, msg);
 			      
 	}
 	pStmt = _stmtList.Next();
@@ -239,7 +242,7 @@ void CegoProcBlock::cleanBlock()
 }
 
 void CegoProcBlock::closeBlock()
-{
+{    
     CegoProcCursor **pCur = _cursorList.First();
     while ( pCur ) 
     {
@@ -257,11 +260,11 @@ void CegoProcBlock::setRetVal(const CegoFieldValue& retVal)
 }
 
 CegoFieldValue& CegoProcBlock::getRetVal()
-{
+{    
     return _retVal;
 }
 
-void CegoProcBlock::setExceptionMsg(const Chain msg)
+void CegoProcBlock::setExceptionMsg(const Chain& msg)
 {
     _exceptionMsg = msg;
 }
@@ -281,7 +284,7 @@ const ListT<CegoProcException*>& CegoProcBlock::getExceptionList() const
     return _exceptionList;
 }
 
-Chain CegoProcBlock::toChain(const Chain& indent) const
+Chain CegoProcBlock::toChain(int defTabSetId, const Chain& indent) const
 {
     Chain s;
     CegoProcVar *pVar = _varList.First();
@@ -306,10 +309,7 @@ Chain CegoProcBlock::toChain(const Chain& indent) const
 		s += Chain(" bigint(") + Chain(pVar->getLength()) + Chain(");\n"); 
 		break;
 	    case DECIMAL_TYPE:
-		s += Chain(" decimal(") + Chain(pVar->getLength()) + Chain(");\n"); 
-		break;
-	    case FIXED_TYPE:
-		s += Chain(" fixed(") + Chain(pVar->getLength()) + Chain(");\n"); 
+		s += Chain(" decimal(") + Chain(pVar->getLength()) + Chain(",") + Chain(pVar->getDim()) + Chain(");\n");
 		break;
 	    case BOOL_TYPE:
 		s += Chain(" bool;\n"); 
@@ -338,6 +338,8 @@ Chain CegoProcBlock::toChain(const Chain& indent) const
 	    case CLOB_TYPE:
 		s += Chain(" clob;\n"); 
 		break;
+	    case PAGEID_TYPE:
+		break;
 	    }
 	}
 
@@ -347,15 +349,15 @@ Chain CegoProcBlock::toChain(const Chain& indent) const
     CegoProcStmt **pStmt = _stmtList.First();
     while (pStmt)
     {
-	s += (*pStmt)->toChain(indent) + Chain(";\n");
+	s += (*pStmt)->toChain(defTabSetId, indent) + Chain(";\n");
 	pStmt = _stmtList.Next();
     }
 
     CegoProcException **pException = _exceptionList.First();
     while ( pException ) 
     {
-	s += Chain("exception when ") + (*pException)->toChain() + Chain("\nthen\n");	
-	s += (*pException)->getBlock()->toChain(indent + indent);
+	s += Chain("exception when ") + (*pException)->toChain(defTabSetId) + Chain("\nthen\n");	
+	s += (*pException)->getBlock()->toChain(defTabSetId, indent + Chain(DEFAULTINDENT));
 	pException = _exceptionList.Next();
     }
     
@@ -366,3 +368,46 @@ Chain CegoProcBlock::dbFormat(CegoDatabaseFormater *pForm) const
 {
     return pForm->formatProcBlock(_varList, _stmtList, _exceptionList);
 }
+
+void CegoProcBlock::setTriggerValueList(ListT<CegoField>* pTriggerValueList)
+{
+    _pTriggerValueList = pTriggerValueList;    
+}
+
+ListT<CegoField>* CegoProcBlock::getTriggerValueList()
+{
+    return _pTriggerValueList;
+}
+
+void CegoProcBlock::cleanUp()
+{
+    CegoProcStmt **pStmt = _stmtList.First();
+    while ( pStmt )
+    {
+	(*pStmt)->cleanUp();
+	pStmt = _stmtList.Next();
+    }
+}
+
+bool CegoProcBlock::isStatic()
+{
+    if ( _isEval )
+	return _isStatic;
+    
+    CegoProcStmt **pStmt = _stmtList.First();
+    while ( pStmt )
+    {
+	if ( (*pStmt)->isStatic() == false )
+	{
+	    _isEval = true;
+	    _isStatic = false;
+	    return _isStatic;
+	}
+	
+	pStmt = _stmtList.Next();
+    }
+    
+    _isEval = true;
+    _isStatic = true;
+    return _isStatic;
+}
