@@ -8,7 +8,7 @@
 //              
 // Design and Implementation by Bjoern Lemke
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -30,15 +30,14 @@ public:
 
     CegoProcBlockStmt(CegoProcBlock *pBlock,
 		      CegoProcBlock *pParentBlock);
-    
     ~CegoProcBlockStmt();
 
     void setBlock(CegoProcBlock* pBlock);
-    
     CegoException execute();
-    
-    Chain toChain(const Chain& indent = Chain("")) const;
+    void cleanUp();
+    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
+    bool isStatic() const;
     
 private:
 
