@@ -8,7 +8,7 @@
 //
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -22,6 +22,7 @@
 
 // LFC INCLUDES
 #include <lfcbase/Chain.h>
+
 // CEGO INCLUDES
 #include "CegoProcStmt.h"
 #include "CegoProcCursor.h"
@@ -32,17 +33,16 @@ class CegoProcCursorCloseStmt : public CegoProcStmt  {
 public:
     
     CegoProcCursorCloseStmt(CegoProcCursor *pCur, CegoProcBlock *pBlock);
-    
     ~CegoProcCursorCloseStmt();
     
     CegoException execute();
-    
-    Chain toChain(const Chain& indent = Chain("")) const;
+    void cleanUp();
+    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
+    bool isStatic() const;
     
 private:
 
     CegoProcCursor* _pCur;
-
 };
 #endif
