@@ -6,7 +6,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -26,7 +26,7 @@
 #include "CegoDatabaseFormater.h"
 
 CegoProcCursorCreateStmt::CegoProcCursorCreateStmt(const Chain& name, CegoSelect *pSelect,
-				       CegoProcBlock *pBlock) : CegoProcStmt(pBlock)
+						   CegoProcBlock *pBlock) : CegoProcStmt(pBlock)
 {
     _name = name;
     _pSelect = pSelect;
@@ -46,14 +46,22 @@ CegoException CegoProcCursorCreateStmt::execute()
     return NONE_EXCEP;
 }
 
-Chain CegoProcCursorCreateStmt::toChain(const Chain& indent) const
+void CegoProcCursorCreateStmt::cleanUp()
+{
+    if ( _pSelect )
+    {
+	_pSelect->cleanUp();
+    }
+}
+
+Chain CegoProcCursorCreateStmt::toChain(int defTabSetId, const Chain& indent) const
 {
     Chain s;
 
     s += indent + Chain("cursor ");
     s += _name;
     s += Chain(" as\n");
-    s += _pSelect->toChain(indent + indent);
+    s += indent + _pSelect->toChain(defTabSetId, indent + Chain(DEFAULTINDENT));
     return s;
 }
 
@@ -61,3 +69,8 @@ Chain CegoProcCursorCreateStmt::dbFormat(CegoDatabaseFormater *pForm) const
 {
     return pForm->formatProcCursorCreateStmt(_name, _pSelect);
 }
+
+bool CegoProcCursorCreateStmt::isStatic() const
+{
+    return false;
+}
