@@ -1,12 +1,12 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                         
 // CegoProcNoopStmt.cc  
-// ---------------------                                                     
+// -------------------
 // Cego procedure noop statement implementation
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -40,7 +40,11 @@ CegoException CegoProcNoopStmt::execute()
     return NONE_EXCEP;
 }
 
-Chain CegoProcNoopStmt::toChain(const Chain& indent) const
+void CegoProcNoopStmt::cleanUp()
+{
+}
+
+Chain CegoProcNoopStmt::toChain(int defTabSetId, const Chain& indent) const
 {
     Chain s;
     s = indent + Chain("noop");
@@ -51,3 +55,8 @@ Chain CegoProcNoopStmt::dbFormat(CegoDatabaseFormater *pForm) const
 {
     return pForm->formatProcNoopStmt();
 }
+
+bool CegoProcNoopStmt::isStatic() const
+{
+    return true;
+}
