@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -32,37 +32,30 @@
 
 class CegoProcObject : public CegoDecodableObject {
 
- public:
+public:
 
     CegoProcObject();
     CegoProcObject(const CegoProcObject& ko);
     CegoProcObject(const Chain& procName, int tabSetId = 0);
-
     CegoProcObject(int tabSetId, const Chain& procName, const Chain& procText);
-	
     ~CegoProcObject();
     
     int getEntrySize() const;
-
-    void encode(char *buf);
+    void encode(char *buf) const;
     void decode(char *buf);
-
     const Chain& getProcText() const;
-
     void setEmpty();
+    Chain toChain() const;    
+    Chain getFormatted() const;
     
     CegoProcObject& operator = ( const CegoProcObject& oe);
     bool operator == ( const CegoProcObject& oe);
-    
-    Chain toChain() const;
 
-    Element* getElement() const;
-    void putElement(Element* pElement);
-    Chain getFormatted() const;
-
- private:
+private:
 
     Chain _procText;
+
     Chain fill(const Chain& s, int num) const;
 };
 #endif
+
