@@ -3,12 +3,12 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                         
 // CegoProcQueryStmt.h  
-// --------------------
+// -------------------
 // Cego procedure query statement implementation
 //
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -39,12 +39,13 @@ public:
     ~CegoProcQueryStmt();
 
     CegoException execute();
-    Chain toChain(const Chain& indent = Chain("")) const;
+    void cleanUp();
+    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
+    bool isStatic() const;
     
 private:
 
-    CegoQuery *_pQuery;
-    
+    CegoQuery *_pQuery;    
 };
 #endif
