@@ -8,7 +8,7 @@
 //
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -34,17 +34,17 @@ public:
     
     CegoProcReturnStmt(CegoProcBlock *pBlock);
     CegoProcReturnStmt(CegoExpr *pExpr, CegoProcBlock *pBlock);
-
     ~CegoProcReturnStmt();
 
     CegoException execute();
-
-    Chain toChain(const Chain& indent = Chain("")) const;
+    void cleanUp();
+    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
+    bool isStatic() const;
     
 private:
 
     CegoExpr *_pExpr;
-
+    CegoProcBlock *_pBlock;
 };
 #endif
