@@ -8,7 +8,7 @@
 //
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -28,7 +28,7 @@
 
 // cego includes
 #include "CegoDistManager.h"
-#include "CegoPredDesc.h"
+#include "CegoPredicate.h"
 #include "CegoExpr.h"
 #include "CegoAlterDesc.h"
 #include "CegoReturnVar.h"
@@ -48,37 +48,56 @@ public:
 		     RENAME_QUERY,
 		     START_QUERY,
 		     COMMIT_QUERY,
-		     ROLLBACK_QUERY};
+		     ROLLBACK_QUERY,
+		     LOCK_QUERY,
+		     UNLOCK_QUERY };
 
     enum TransactionOp { START, COMMIT, ROLLBACK };
 
     CegoQuery(CegoDistManager* pGTM, const Chain& tableSet, TransactionOp to);
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& tableName,
+	      const Chain& tableAlias,
+	      CegoPredicate* pPred);
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& tableName,
+	      const Chain& tableAlias,
+	      CegoPredicate* pPred,
+	      ListT<CegoField>& updSchema,
+	      const ListT<CegoExpr*>& updList,
+	      const ListT<CegoReturnVar*> retVarList,
+	      bool onFirst);
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& tableName,
+	      bool doLock);
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& tableName,
+	      const ListT<CegoField>& schema,
+	      const ListT<ListT<CegoExpr*> >& exprListArray);
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& tableName,
+	      const ListT<CegoField>& schema,
+	      CegoSelect* pSelect);
 
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableName, const Chain& tableAlias, const Chain& tableSet, CegoPredDesc* pPred);
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableName, const Chain& tableAlias, const Chain& tableSet, CegoPredDesc* pPred, ListT<CegoField>& updSchema, const ListT<CegoExpr*>& updList, const ListT<CegoReturnVar*> retVarList);
-
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableName, const Chain& tableSet, const ListT<CegoField>& schema, const ListT<ListT<CegoExpr*> >& exprListArray);
-
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableName, const Chain& tableSet,  const ListT<CegoField>& schema, CegoSelect* pSelect);
-
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableName, const Chain& tableSet, const ListT<CegoAlterDesc>& alterList);
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& tableName,
+	      const ListT<CegoAlterDesc>& alterList);
     
-    CegoQuery(CegoDistManager* pGTM,   const Chain& tableSet, const Chain& objName, CegoObject::ObjectType objType, const Chain& newObjName );    
-   
+    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+	      const Chain& objName,
+	      CegoObject::ObjectType objType,
+	      const Chain& newObjName );    
     ~CegoQuery();
 
-    void setBlock(CegoProcBlock *pBlock);
-
+    // void setBlock(CegoProcBlock *pBlock);
     Chain execute(CegoProcBlock* pBlock = 0);
-
+    void cleanUp();
     long getAffectedCount() const;
-    
-    Chain toChain(const Chain& indent) const;
+    Chain toChain(int defTabSetId, const Chain& indent) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
 private:
 
-
     void prepareFieldValue(CegoField *pFV, CegoFieldValue& fv, int pos);
 
     QueryMode _mode;
@@ -87,22 +106,16 @@ private:
     Chain _tableAlias;
     Chain _objName;
     CegoObject::ObjectType _objType;
-
     Chain _newObjName;
     Chain _tableSet;
-
     ListT<CegoField> _schema;
     ListT<CegoExpr*> _updList;
     ListT<ListT<CegoExpr*> > _exprListArray;
     ListT<CegoReturnVar*> _retVarList;
+    bool _returnOnFirst;
     ListT<CegoAlterDesc> _alterList; 
-    CegoPredDesc *_pPred;
+    CegoPredicate *_pPred;
     CegoSelect *_pSelect;
     long _affCount;
 };
-
 #endif
-
-
-
-
