@@ -22,6 +22,7 @@
 #include <lfcbase/Datetime.h>
 #include <lfcbase/SetT.h>
 #include <lfcbase/StackT.h>
+#include <lfcbase/BigDecimal.h>
 
 // CEGO INCLUDES
 #include "CegoSelect.h"
@@ -60,6 +61,7 @@ CegoSelect::CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock,
 	_attrCondFlag[i] = false;
 	_firstTuple[i]=true;
 	_attrPred[i]=0;
+	_cursorPred[i]=0;
 	i++;
     }
 
@@ -78,7 +80,8 @@ CegoSelect::CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock,
 
     _pOrderCursor=0;
     _pGroupCursor=0;
-	    
+
+    _joinLevel = 0;
     _isDistinct = false;
     _pParentJoinBuf = 0;
     _isPrepared = false;
@@ -134,6 +137,7 @@ CegoSelect::CegoSelect(ListT<CegoContentObject*>& coList,
 	_attrCondFlag[i] = false;
 	_firstTuple[i]=true;
 	_attrPred[i]=0;
+	_cursorPred[i]=0;	
 	i++;
     }
     
@@ -153,6 +157,7 @@ CegoSelect::CegoSelect(ListT<CegoContentObject*>& coList,
     _pOrderCursor=0;
     _pGroupCursor=0;
 
+    _joinLevel = 0;
     _isDistinct = isDistinct;
     _pParentJoinBuf = 0;
     _tabSetId = 0;
@@ -176,7 +181,7 @@ CegoSelect::~CegoSelect()
 
     CegoPredicate **pP = _viewConjunctionList.First();
     while ( pP )
-    {      
+    {
 	delete (*pP);
 	pP = _viewConjunctionList.Next();
     }
@@ -387,6 +392,7 @@ void CegoSelect::cleanUp()
 	_attrCondFlag[i] = false;
 	_firstTuple[i]=true;
 	_attrPred[i]=0;
+	_cursorPred[i]=0;
 	i++;
     }
     
@@ -500,6 +506,12 @@ void CegoSelect::prepare(bool graceful)
 	}	
     }
 
+
+#ifdef CGDEBUG
+    _pDBMng->log(_modId, Logger::DEBUG, Chain("Eval schema ..."));	
+#endif
+
+
     // provide schema
     evalSchema(graceful);
 }
@@ -508,7 +520,7 @@ void CegoSelect::prepare(bool graceful)
 // actions. This method can be used, if there was no change on any included join variables
 // If the query result was cached, cache is still valid after reset
 
-void CegoSelect::reset(bool doRelease)
+void CegoSelect::reset()
 {
     if ( _selectMode == AGGREGATION )
 	_aggDone=false;
@@ -535,12 +547,7 @@ void CegoSelect::reset(bool doRelease)
     {
 	if ( _pTC[i] )
 	{
-	    _pTC[i]->reset();
-	    if ( doRelease )
-	    {
-		delete _pTC[i];
-		_pTC[i] = 0;
-	    }
+	    _pTC[i]->reset();	    
 	}
 	i++;
     }
@@ -551,7 +558,7 @@ void CegoSelect::reset(bool doRelease)
     if ( _pUnionSelect )
     {
 	_checkUnion = false;
-	_pUnionSelect->reset(doRelease);
+	_pUnionSelect->reset();
     }
     
     if ( _pOrderSpace )
@@ -673,6 +680,12 @@ Element* CegoSelect::getPlan()
 	throw Exception(EXLOC, Chain("No valid table manager"));
     
     prepare();
+
+    #ifdef CGDEBUG	
+    _pDBMng->log(_modId, Logger::DEBUG, Chain("Checking valid references"));
+#endif	
+
+    
     checkValidRef();
     setParentJoinBuf();
 
@@ -683,10 +696,9 @@ Element* CegoSelect::getPlan()
 #ifdef CGDEBUG	
 	_pDBMng->log(_modId, Logger::DEBUG, Chain("Plan : Creating cursor for ") + _joinList[_joinLevel]->getTabName() + Chain(" on join level ") + Chain(_joinLevel));
 #endif	
-
     
 	_pTC[_joinLevel] = 
-	    new CegoDistCursor(_pGTM, _joinList[_joinLevel]);
+	    new CegoDistCursor(_pGTM, _joinList[_joinLevel], _pBlock);
 	
 	if ( _attrCondFlag[_joinLevel] == true )
 	{
@@ -694,7 +706,6 @@ Element* CegoSelect::getPlan()
 	    _pDBMng->log(_modId, Logger::DEBUG, Chain("Plan : Setting attrcond for ") + _joinList[_joinLevel]->getName() + Chain(" to ") + _attrCond[_joinLevel].toChain() + Chain(" on level ") + Chain(_joinLevel));
 #endif
 
-	
 	    if ( _attrCond[_joinLevel].setup(_joinBuf, 0 ) == false )
 	    {
 		// attribute condition can not be resolved on this join level
@@ -711,14 +722,32 @@ Element* CegoSelect::getPlan()
 		    _attrPred[_joinLevel]->setChecked(false);
 		}
 	    }
-	    _pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _joinBuf);
+	    if ( _pParentJoinBuf == 0 )
+		_pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _joinBuf, _cursorPred[_joinLevel]);
+	    else
+	    {
+		mergeBuffer();
+		_pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _pMergedBuf, _cursorPred[_joinLevel]);
+	    }
+		
 	}
 	else
 	{
 #ifdef CGDEBUG	    
 	    _pDBMng->log(_modId, Logger::DEBUG, Chain("Plan : Setting no attrcond for ") + _joinList[_joinLevel]->getName() + Chain(" on level ") + Chain(_joinLevel));
 #endif
-	    _pTC[_joinLevel]->distSetup(_joinBuf);
+
+
+	    // since cursor predicate may contain parent references, we just up, if parent join buf is empty
+
+	    if ( _pParentJoinBuf == 0 )
+		_pTC[_joinLevel]->distSetup(_joinBuf, _cursorPred[_joinLevel]);
+	    else
+	    {
+		mergeBuffer();
+		_pTC[_joinLevel]->distSetup(_pMergedBuf, _cursorPred[_joinLevel]);
+	    }
+
 	}
 	
 	Element* pCursorPlan = _pTC[_joinLevel]->getPlan();
@@ -727,21 +756,42 @@ Element* CegoSelect::getPlan()
 	
 	_joinLevel++;
     }
-    
+
+    CegoPredicate **pPred = _conjunctionList.First();
+
+    while ( pPred )
+    {			
+	if ( ! (*pPred)->isChecked() )
+	{	  
+	    Element *pPredElement = new Element(XML_PRED_ELEMENT);
+	    pPredElement->setAttribute(XML_PRED_ATTR, (*pPred)->toChain(0));
+	    pPlan->addContent(pPredElement);
+	}
+	pPred = _conjunctionList.Next();
+    }
+
     ListT<Element*> planList;
     
     CegoExpr **pExpr = _exprList.First();
     while ( pExpr )
-    {	
-	// (*pExpr)->setFieldListArray( _joinBuf  );
-	
+    {
+	ListT<CegoSelect*> queryList;
+	(*pExpr)->getSelectQueryList(queryList);
+
+	CegoSelect** pSelect = queryList.First();
+	while ( pSelect )
+	{
+	    (*pSelect)->setParentJoinBuf(_joinBuf);
+	    pSelect = queryList.Next();
+	}
+
 	(*pExpr)->getPlanList(planList);
 	pExpr = _exprList.Next();
     }
     
     if ( _pPred ) 
     {	
-	_pPred->getPlanList(planList);    
+	_pPred->getPlanList(planList);
     }
 
     Element** pSubPlan = planList.First();
@@ -785,7 +835,7 @@ void CegoSelect::checkValidRef()
     {	
 	if ( (*pAD)->isValid() == false )
 	{
-	    throw Exception(EXLOC, Chain("Unknown attribute ") + (*pAD)->toChain()); 
+	    throw Exception(EXLOC, Chain("Unknown attribute ") + (*pAD)->toChain() + Chain(" for query ") + toChain(0)); 
 	}
 
 #ifdef CGDEBUG
@@ -800,22 +850,6 @@ void CegoSelect::setProcBlock(CegoProcBlock *pBlock)
 {
     _pBlock = pBlock;
 
-    /*
-    CegoExpr** pExpr = _exprList.First();
-    while (pExpr)
-    {
-	(*pExpr)->setBlock(_pBlock);	    
-	pExpr = _exprList.Next();
-    }
-    */
-
-    /*
-    if ( _pPred ) 
-    {	
-	_pPred->setBlock(pBlock);    
-    }
-    */
-
     if ( _pUnionSelect )
     {
 	_pUnionSelect->setProcBlock(pBlock);
@@ -828,35 +862,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
     {
 	if ( _cacheEnabled && _pCacheList )
 	{
-	    _isCached = true;
-	    SetT<CegoObject> objList;
-	    getObjectList(objList);
-
-	    // check object list for foreign objects
-	    bool hasForeign=false;
-	    CegoObject *pObj = objList.First();
-	    while ( pObj && hasForeign == false)
-	    {
-		if ( pObj->getTabSetId() != _tabSetId )
-		    hasForeign = true;
-		
-		pObj = objList.Next();
-	    }
-
-	    Chain queryId = getQueryId();
-
-	    _execTime.stop();
-	    // get queryTime in msec 
-	    int queryTime = _execTime.getSum()  / 1000000;
-	    
-	    if ( hasForeign == false && queryId != Chain(MOD_QUERY_ID) && _pCache->getThreshold() <= queryTime )
-	    {
-		_pCache->addEntry( queryId, objList, _pCacheList, _cacheSchema );
-	    }
-	    delete _pCacheList;
-	    
-	    _pCacheList = 0;
-	    _rowCount=0;
+	    finishCaching();
 	}
 
 	if ( _pCache && _pCacheArray )
@@ -877,28 +883,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 	}
 	else
 	{
-	    _isCached = false;
-	    _cacheEntrySize = 0;
-
-	    // check for system objects
-	    SetT<CegoObject> tableList;
-	    getObjectList(tableList);
-	    bool sysTableFound=false;
-	    CegoObject *pO = tableList.First();
-	    while ( pO && sysTableFound == false)
-	    {
-		if ( pO->getType() == CegoObject::SYSTEM )
-		{
-		    sysTableFound=true;
-		}
-		pO = tableList.Next();
-	    }
-	    if ( sysTableFound == false )
-	    {
-		_execTime.reset();
-		_execTime.start();
-		_pCacheList = new ListT< ListT< CegoFieldValue > >;
-	    }
+	    startCaching();	    
 	}
     }
 
@@ -1020,40 +1005,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 
 	if ( _cacheEnabled && _pCacheList )
 	{
-	    _isCached = true;
-
-	    SetT<CegoObject> tableList;
-
-	    getObjectList(tableList);
-
-	    // check object list for foreign objects
-	    bool hasForeign=false;
-	    CegoObject *pTable = tableList.First();
-	    while ( pTable && hasForeign == false)
-	    {
-		if ( pTable->getTabSetId() != _tabSetId )
-		{		    
-		    hasForeign = true;
-		}
-		pTable = tableList.Next();
-	    }
-
-	    // we just add cache entries, if the tablelist does not contain any tables from  foreign tablesets
-	    Chain queryId = getQueryId();
-
-	    _execTime.stop();
-	    // get queryTime in msec 
-	    int queryTime = (int) ( _execTime.getSum()  / 1000000 );
-	    
-	    if ( hasForeign == false && queryId != Chain(MOD_QUERY_ID) && _pCache->getThreshold() <= queryTime )
-	    {
-		_pCache->addEntry( queryId , tableList, _pCacheList, _cacheSchema );
-	    }
-	    	    
-	    delete _pCacheList;
-	    
-	    _pCacheList = 0;
-	    _rowCount=0;
+	    finishCaching();
 	}
 	return false;
     }
@@ -1069,6 +1021,69 @@ bool CegoSelect::isCacheEnabled() const
     return _cacheEnabled;
 }
 
+void CegoSelect::startCaching()
+{
+    _isCached = false;
+    _cacheEntrySize = 0;
+    
+    // check for system objects
+    SetT<CegoObject> tableList;
+    getObjectList(tableList);
+    bool sysTableFound=false;
+    CegoObject *pO = tableList.First();
+    while ( pO && sysTableFound == false)
+    {
+	if ( pO->getType() == CegoObject::SYSTEM )
+	{
+	    sysTableFound=true;
+	}
+	pO = tableList.Next();
+    }
+    if ( sysTableFound == false )
+    {
+	_execTime.reset();
+	_execTime.start();
+	_pCacheList = new ListT< ListT< CegoFieldValue > >;
+    }
+}
+
+void CegoSelect::finishCaching()
+{
+    _isCached = true;   
+    SetT<CegoObject> tableList;
+  
+    getObjectList(tableList);
+    
+    // check object list for foreign objects
+    bool hasForeign=false;
+    CegoObject *pTable = tableList.First();
+    while ( pTable && hasForeign == false)
+    {
+	if ( pTable->getTabSetId() != _tabSetId )
+	{		    
+	    hasForeign = true;
+	}
+	pTable = tableList.Next();
+    }
+    
+    // we just add cache entries, if the tablelist does not contain any tables from  foreign tablesets
+    Chain queryId = getQueryId();
+    
+    _execTime.stop();
+    // get queryTime in msec 
+    int queryTime = (int) ( _execTime.getSum()  / 1000000 );
+    
+    if ( hasForeign == false && queryId != Chain(MOD_QUERY_ID) && _pCache->getThreshold() <= queryTime )
+    {
+	_pCache->addEntry( queryId , tableList, _pCacheList, _cacheSchema );
+    }
+    
+    delete _pCacheList;
+    
+    _pCacheList = 0;
+    _rowCount=0;
+    
+}
 Chain CegoSelect::getQueryId() const
 {
     try
@@ -1555,8 +1570,6 @@ bool CegoSelect::nextResultTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		    pAgg = aggList.Next();
 		}		
 
-		// (*pExpr)->setFieldListArray(&gfl);
-
 		ListT<CegoField>* fl[2];
 		fl[0] = &gfl;
 		fl[1] = 0;
@@ -1574,7 +1587,6 @@ bool CegoSelect::nextResultTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		fl[0] = &gfl;
 		fl[1] = 0;
 
-		// (*pExpr)->setFieldListArray(&gfl );
 		f.setValue((*pExpr)->evalFieldValue(fl, _pBlock) );
 		f.setAttrName((*pExpr)->getAlias());
 		jfl.Insert(f);
@@ -1609,17 +1621,13 @@ bool CegoSelect::nextGroupedTuple(ListT<CegoField>& jfl)
 		fla[0]=&jfl;
 		fla[1]=0;
 
-		// _pHavingPred->setFieldListArray(fla);
-
 		_pHavingPred->setAggregationValue(jfl);
 
 		if ( _pHavingPred->eval(0, 0, fla, 0, _pBlock) )
 		{
-		    // _pHavingPred->setFieldListArray(0);
 		    return true;
 		}
 	    }
-	    // _pHavingPred->setFieldListArray(0);
 	    return false;
 	}
 	else
@@ -1710,18 +1718,14 @@ bool CegoSelect::nextGroupedTuple(ListT<CegoField>& jfl)
 		fla[0]=&jfl;
 		fla[1]=0;
 
-		// _pHavingPred->setFieldListArray(fla);
-
 		_pHavingPred->setAggregationValue(jfl);
 		
 		if ( _pHavingPred->eval(0, 0, fla, 0, _pBlock) )
 		{
-		    // _pHavingPred->setFieldListArray(0);
 		    return true;
 		}
 		else
 		{
-		    // _pHavingPred->setFieldListArray(0);
 		    moreTuple = _pGroupCursor->getNext(jfl);
 		}
 	    }
@@ -1761,7 +1765,7 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 
 		    
 		    _pTC[_joinLevel] = 
-			new CegoDistCursor(_pGTM,_joinList[_joinLevel]);
+			new CegoDistCursor(_pGTM, _joinList[_joinLevel], _pBlock);
 		}
 		else
 		{
@@ -1771,15 +1775,21 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		if ( _attrCondFlag[_joinLevel] == true )
 		{
 #ifdef CGDEBUG	    
-		    _pDBMng->log(_modId, Logger::DEBUG, Chain("Setting attrcond =  ") + _attrCond[_joinLevel].toChain() + Chain(" on level ") + Chain(_joinLevel));
+		    _pDBMng->log(_modId, Logger::DEBUG, Chain("Setting attrcond ") + _attrCond[_joinLevel].toChain() + Chain(" on level ") + Chain(_joinLevel));
 #endif
 		    if ( _attrCond[_joinLevel].setup(_pParentJoinBuf, 0, _joinBuf, 0 ) == true )
 		    {
 #ifdef CGDEBUG	    
-			_pDBMng->log(_modId, Logger::DEBUG, Chain("Cursor set up for attrcond =  ") + _attrCond[_joinLevel].toChain());
+			_pDBMng->log(_modId, Logger::DEBUG, Chain("Cursor set up for attrcond ") + _attrCond[_joinLevel].toChain());
 #endif
 
-			_pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _joinBuf);
+			if ( _pParentJoinBuf == 0 )
+			    _pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _joinBuf, _cursorPred[_joinLevel]);
+			else
+			{
+			    mergeBuffer();
+			    _pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _pMergedBuf, _cursorPred[_joinLevel]);
+			}
 		    }	 
 		    else
 		    {
@@ -1792,12 +1802,28 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 			    _attrPred[_joinLevel]->setChecked(false);
 			}
 
-			_pTC[_joinLevel]->distSetup(_joinBuf);
+			// since cursor predicate may contain parent references, we just up, if parent join buf is empty
+			if ( _pParentJoinBuf == 0 )
+			    _pTC[_joinLevel]->distSetup(_joinBuf, _cursorPred[_joinLevel]);
+			else
+			{
+			    mergeBuffer();
+			    _pTC[_joinLevel]->distSetup(_pMergedBuf, _cursorPred[_joinLevel]);
+			}
+
 		    }		    
 		}
 		else
 		{
-		    _pTC[_joinLevel]->distSetup(_joinBuf);
+		    if ( _pParentJoinBuf == 0 )
+		    {
+			_pTC[_joinLevel]->distSetup(_joinBuf,  _cursorPred[_joinLevel]);
+		    }
+		    else
+		    {
+			mergeBuffer();
+			_pTC[_joinLevel]->distSetup(_pMergedBuf, _cursorPred[_joinLevel]);
+		    }
 		}
 
 		/*		
@@ -1874,14 +1900,15 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		}
 	    }
 	}
-
+	
 	bool checkPred = true;
 	CegoPredicate **pPred = _conjunctionList.First();
 
 	while ( pPred && checkPred )
 	{
 	    if ( ! (*pPred)->isChecked() )
-	    {
+	    {		
+		// cout << " For " << toChain(0) << " eval predicate "  <<  (*pPred)->toChain(0) << endl;
 #ifdef CGDEBUG
 		_pDBMng->log(_modId, Logger::DEBUG, Chain("Evaluating predicate ") + (*pPred)->toChain(0));
 #endif
@@ -1890,6 +1917,7 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 					   _joinBuf,
 					   0,
 					   _pBlock);
+
 #ifdef CGDEBUG
 		if ( checkPred )
 		    _pDBMng->log(_modId, Logger::DEBUG, Chain("Predicate matches"));
@@ -1900,6 +1928,9 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 
 	    pPred = _conjunctionList.Next();
 	}
+
+
+
 	
 	if ( checkPred )
 	{	    
@@ -1910,7 +1941,7 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 #endif
 
 	    evalSelection(_exprList, _joinBuf, jfl);
-
+		
 #ifdef CGDEBUG
 	    _pDBMng->log(_modId, Logger::DEBUG, Chain("Evaluating selection done"));
 #endif
@@ -2214,7 +2245,7 @@ void CegoSelect::consolidateConjunctionList()
     pPred = _conjunctionList.First();
     while ( pPred )
     {
-	bool isAppropriate = (*pPred)->getMode() == CegoPredicate::EXPRCOMP || (*pPred)->getMode() == CegoPredicate::CONDITION ;
+	bool isAppropriate = (*pPred)->getMode() == CegoPredicate::EXPRCOMP || (*pPred)->getMode() == CegoPredicate::CONDITION || (*pPred)->getMode() == CegoPredicate::IN ;
 	if ( isAppropriate == false || (*pPred)->getTableRefSet().Size() == 0 )
 	{
 #ifdef CGDEBUG
@@ -2419,7 +2450,7 @@ void CegoSelect::buildJoinTables()
 }
 
 void CegoSelect::buildJoinConditions()
-{
+{    
     if ( _pPred )
 	_pPred->setCheckedRec(false);
 
@@ -2474,8 +2505,7 @@ void CegoSelect::buildJoinConditions()
 		    _pDBMng->log(_modId, Logger::DEBUG, Chain("Getting attribute cond for ") + (*pPred)->toChain(0));
 #endif
 		    CegoQueryHelper::AttrCondMatch m = CegoQueryHelper::checkAttrCond(ac, *pPred, _joinList[i]->getSchema(), &availJoinFields, 1, _pBlock);
-		    
-		    
+		    		    
 		    if ( m != CegoQueryHelper::INAPP )
 		    {
 			bool predChecked = false;
@@ -2492,25 +2522,46 @@ void CegoSelect::buildJoinConditions()
 			}
 			else
 			{
-			    _attrCond[i] = _attrCond[i] + ac;
+			    if ( ac.isAnd() && _attrCond[i].isAnd() )
+			    {
+				_attrCond[i] = _attrCond[i] + ac;
+			    }
+			    else
+			    {
+				predChecked=false;
+			    }
 			}		       
 			
 			// we just set predicated to checked which are not external
-			if ( predChecked == true &&  _viewConjunctionList.Find(*pPred) == 0 )
+			// 06.07.2025, no more need since pPred is fully handled
+			if ( predChecked == true ) // &&  _viewConjunctionList.Find(*pPred) == 0 )
 			{
 			    (*pPred)->setChecked(predChecked);
 			}
 			
 			// if _attrCond.setup fails, the predicate has to be checked on corresponding join level
 			_attrPred[i] = *pPred;
-			    
+
+			if ( m != CegoQueryHelper::COMPLETE )
+			{
+			    // cout << "Attr pred is not complete" << endl;
+			    if ( (*pPred)->isCursorPred() )
+				_cursorPred[i] = *pPred;
+			}
+			
 			pPred = _conjunctionList.Next();		    			
 		    }
 		    else
 		    {
 #ifdef CGDEBUG
 			_pDBMng->log(_modId, Logger::DEBUG, Chain("Inappropriate predicate on level ") + Chain(i));
-#endif 			
+#endif
+
+			if ( (*pPred)->isCursorPred() )
+			    _cursorPred[i] = *pPred;
+
+			// cout << "Cursor Pred = " << (*pPred)->toChain(0) << endl;
+			
 			pPred = _conjunctionList.Next();
 		    }		    
 		}
@@ -2674,18 +2725,7 @@ void CegoSelect::filterRefs(const ListT<CegoField>& inSchema, ListT<CegoField>&
 	{
 
 	    filterPredRef(_pHavingPred, inSchema, tmpSchema[tmpidx]);
-	    tmpidx++;
-	    
-	    /*
-	    ListT<CegoExpr*> exprList = _pHavingPred->getExprList();
-	    
-	    CegoExpr** pExpr = exprList.First();
-	    while ( pExpr )
-	    {
-		filterExprRef(*pExpr, inSchema, tmpSchema[tmpidx]);
-		pExpr = exprList.Next();
-	    }
-	    */
+	    tmpidx++;	    
 	}
 
     }
@@ -2891,6 +2931,8 @@ void CegoSelect::filterPredRef(CegoPredicate *pP, const ListT<CegoField>& inSche
 	     || pP->getMode() == CegoPredicate::EXPRCOMP 
 	     || pP->getMode() == CegoPredicate::ISLIKE
 	     || pP->getMode() == CegoPredicate::ISNOTLIKE
+	     || pP->getMode() == CegoPredicate::ISNCLIKE
+	     || pP->getMode() == CegoPredicate::ISNOTNCLIKE
 	     || pP->getMode() == CegoPredicate::IN
 	     || pP->getMode() == CegoPredicate::NOTIN
 	     || pP->getMode() == CegoPredicate::INSUB
@@ -2978,6 +3020,18 @@ void CegoSelect::getPredObjectList(CegoPredicate *pPred, ListT<CegoContentObject
 		attrRefList += pPred->getExpr2()->getAttrRefList();
 	    }
 
+	    if ( pPred->getExpr3() )
+	    {
+		attrRefList += pPred->getExpr3()->getAttrRefList();
+	    }
+
+	    CegoExpr** pExpr = pPred->getExprList().First();
+	    while ( pExpr )
+	    {
+		attrRefList += (*pExpr)->getAttrRefList();
+		pExpr = pPred->getExprList().Next();
+	    }
+	    
 	    CegoContentObject** pCO = _coList.First();	
 	    while (pCO)
 	    {	
@@ -3104,16 +3158,6 @@ int CegoSelect::evalTableReferences(CegoContentObject *pCO, const ListT<CegoFiel
     if ( _pHavingPred )
     {
 	refCount += _pHavingPred->evalReferences(pCO, fl);
-
-	/*
-	ListT<CegoExpr*> exprList = _pHavingPred->getExprList();
-	CegoExpr** pExpr = exprList.First();
-	while ( pExpr )
-	{
-	    refCount += (*pExpr)->evalReferences(pCO, fl);
-	    pExpr = exprList.Next();
-	}
-	*/
     }
 
     return refCount;
@@ -3124,11 +3168,44 @@ void CegoSelect::evalReferences()
     
     _joinPredList.Empty();
     CegoContentObject** pCO = _coList.First();
+
+    SetT<Chain> aliasSet;
+    
     while (pCO)
     {
+	
 	if ( (*pCO)->getType() == CegoObject::JOIN )
 	{
 	    ((CegoJoinObject*)(*pCO))->getPredList(_joinPredList);
+	    
+	    if ( aliasSet.Insert(((CegoJoinObject*)(*pCO))->getLeftObject()->getTabAlias()) == false )
+	    {
+		Chain msg = Chain("Duplicate alias ")
+		    + ((CegoJoinObject*)(*pCO))->getLeftObject()->getTabAlias()
+		    + Chain(" (")
+		    + ((CegoJoinObject*)(*pCO))->getLeftObject()->getTabName() + Chain(")");
+		throw Exception(EXLOC, msg);	    
+	    }
+	    
+	    if ( aliasSet.Insert(((CegoJoinObject*)(*pCO))->getRightObject()->getTabAlias()) == false )
+	    {
+		Chain msg = Chain("Duplicate alias ")
+		    + ((CegoJoinObject*)(*pCO))->getRightObject()->getTabAlias()
+		    + Chain(" (")
+		    + ((CegoJoinObject*)(*pCO))->getRightObject()->getTabName() + Chain(")");
+		throw Exception(EXLOC, msg);	    
+	    }	    
+	}
+	else
+	{	    
+	    if ( aliasSet.Insert((*pCO)->getTabAlias()) == false )
+	    {
+		Chain msg = Chain("Duplicate alias ")
+		    + (*pCO)->getTabAlias()
+		    + Chain(" (")
+		    + (*pCO)->getTabName() + Chain(")");
+		throw Exception(EXLOC, msg);
+	    }	    
 	}
 	pCO = _coList.Next();
     }
@@ -3179,7 +3256,6 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 	CegoExpr** pExpr = exprList.First();
 	while ( pExpr )
 	{
-	    // (*pExpr)->setFieldListArray( pJoinBuf );	    
 	    (*pExpr)->getFieldList(ol, pJoinBuf);
 	    pExpr = exprList.Next();
 	}
@@ -3647,15 +3723,20 @@ int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
    evaluation of the attribute values, set up as parent join buffer
    If a complete evaluation could be made by the query itself, the method returns true.
    Otherwise false is returned and the attribute condition must be evaluated by the outer instance
+
+   With cego version 2.52.20, master predicate parameter was introduced to support inappropriate conditions ( or-conditions)
+   In this case, the predicate is added to the view conjunction list and so  might be evaluated in a more efficient way.
+   If master predicate is set up, the method returns false ( isCompleted = false ), since it might not be ensured,
+   that the master predicate can be fully evaluated
  */
 
-bool CegoSelect::setViewCond( CegoAttrCond& attrCond, ListT<CegoField> **pFLA)
+bool CegoSelect::setViewCond(const Chain& viewAlias,  CegoAttrCond& attrCond, CegoPredicate* pPred, ListT<CegoField> **pFLA)
 {        
     bool isComplete = true;
     
     CegoPredicate **pP = _viewConjunctionList.First();
     while ( pP )
-    {      
+    {
 	delete (*pP);
 	pP = _viewConjunctionList.Next();
     }
@@ -3663,11 +3744,13 @@ bool CegoSelect::setViewCond( CegoAttrCond& attrCond, ListT<CegoField> **pFLA)
     
     if ( attrCond.numComp() > 0 )
     {
-	isComplete = attrCond.asConjunctionList(_exprList, _viewConjunctionList);
 
 	// we have to setup attrcond before retrievig the id
 	if ( pFLA )
 	    attrCond.setup(**pFLA);
+
+	isComplete = attrCond.asConjunctionList(_exprList, _viewConjunctionList);
+	
 	_viewCondId = attrCond.getId();
     }
     else
@@ -3675,13 +3758,27 @@ bool CegoSelect::setViewCond( CegoAttrCond& attrCond, ListT<CegoField> **pFLA)
 	_viewCondId = Chain();
     }
 
+    if ( pPred )
+    {	
+	CegoPredicate *pMapPred = pPred->map(viewAlias, _exprList);
+
+	if ( pMapPred )
+	{
+	    _viewConjunctionList.Insert(pMapPred);
+	}
+	else
+	{
+	    isComplete = false;
+	}		
+    }
+    
     cleanUp();
 
     setParentJoinBuf(pFLA);
 	
     if ( _pUnionSelect )
     {
-	_pUnionSelect->setViewCond(attrCond, pFLA);
+	_pUnionSelect->setViewCond(viewAlias, attrCond, pPred, pFLA);
     }
 
     return isComplete;
@@ -3889,10 +3986,26 @@ void CegoSelect::initAggregation()
 	    {
 		(*pAgg)->setFieldValue( CegoFieldValue(LONG_TYPE, Chain("0")));
 	    }
-	    else
+	    else if ( (*pAgg)->getType() == CegoAggregation::MIN
+		      || (*pAgg)->getType() == CegoAggregation::MAX )
 	    {
 		CegoFieldValue fv;
-		(*pAgg)->setFieldValue(fv);
+                (*pAgg)->setFieldValue(fv);
+	    }
+	    else // SUM / AVG
+	    {
+		CegoField f = (*pExpr)->evalField(_joinFields, true);
+                // cout << "Type is " << f.getType() << " " << f.getDim() <<  endl;
+                if ( f.getType() == DECIMAL_TYPE )
+                {
+                   BigDecimal d = BigDecimal("0").scaleTo(f.getDim());
+                   // cout << "Setting init value to " << d.toChain() << endl;
+                   (*pAgg)->setFieldValue( CegoFieldValue(f.getType(), d.toChain()));
+                }
+                else
+                {
+		    (*pAgg)->setFieldValue( CegoFieldValue(f.getType(), Chain("0")));
+                }
 	    }
 	    (*pAgg)->setAggregationId(nextAid);
 	    nextAid++;
@@ -4227,3 +4340,38 @@ CegoSelect* CegoSelect::clone(bool isAttrRef)
 	    
     return pClone;
 }
+
+
+void CegoSelect::mergeBuffer()
+{
+    // merge join buf and parent join buf
+
+    if ( _pParentJoinBuf )
+    {		
+	int i=0;
+	while ( _joinBuf[i] )
+	{	    
+	    _mergeBuf[i] = _joinBuf[i];
+	    i++;
+	}
+	
+	// now we take parent join buf we a lower priority
+	
+	int j=0;
+	while ( _pParentJoinBuf[j] )
+	{	    
+	    _mergeBuf[i] = _pParentJoinBuf[j];	    
+	    i++;
+	    j++;
+
+	}
+		
+	// terminate array
+	_mergeBuf[i]=0;
+	_pMergedBuf = _mergeBuf;
+    }
+    else
+    {		    	
+	_pMergedBuf = _joinBuf;
+    }
+}
