@@ -116,6 +116,15 @@ CegoAttrDesc* CegoTerm::checkAttr() const
     return 0;
 }
 
+CegoCondition* CegoTerm::checkCondition() const
+{
+    if ( _pFactor && _termType == FACTOR )
+    {
+	return _pFactor->checkCondition();
+    }
+    return 0;
+}
+
 bool CegoTerm::checkLob(CegoFieldValue& fv, CegoProcBlock *pBlock)
 {
     if ( _pFactor && _termType == FACTOR )
@@ -153,12 +162,7 @@ void CegoTerm::getSelectQueryList(ListT<CegoSelect*>& queryList)
     if ( _pTerm )
 	_pTerm->getSelectQueryList(queryList);
     if ( _pFactor )
-    {
-	if ( _pFactor->getSelect() )
-	{
-	    queryList.Insert(_pFactor->getSelect());
-	}
-    }
+	_pFactor->getSelectQueryList(queryList);
 }
 
 void CegoTerm::getFieldList(ListT<CegoField>& fl, ListT<CegoField> **pFLA) const
@@ -509,3 +513,46 @@ ostream& operator << (ostream& s, const CegoTerm& t)
     }
     return s;
 }
+
+CegoTerm* CegoTerm::map(const Chain& viewAlias, const ListT<CegoExpr*>& exprList) const
+{
+
+    CegoTerm* pMapTerm = 0;
+    CegoFactor* pMapFactor = 0;
+
+    bool doMap = true;
+    
+    if ( _pTerm )
+    {
+	pMapTerm = _pTerm->map(viewAlias, exprList);
+	if ( pMapTerm == 0 )
+	    doMap=false;
+    }
+    if ( _pFactor )
+    {
+	pMapFactor = _pFactor->map(viewAlias, exprList);
+	if ( pMapFactor == 0 )
+	    doMap=false;
+    }
+    
+    if ( doMap == false )
+    {
+	if ( pMapTerm )
+	    delete pMapTerm;
+	if ( pMapFactor )
+	    delete pMapFactor;
+	
+	return 0;
+    }
+	     
+    switch ( _termType )
+    {
+    case MUL:
+    case DIV:
+	return ( new CegoTerm ( pMapTerm, pMapFactor, _termType ) );
+    case FACTOR:
+	return ( new CegoTerm ( pMapFactor ) );
+    default:
+        throw Exception(EXLOC, Chain("Unknown term type"));
+    }   
+}
