@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -22,6 +22,7 @@
 #include <lfcbase/Exception.h>
 
 // cego includes
+#include "CegoDefs.h"
 #include "CegoTypeConverter.h"
 #include "CegoXMLdef.h"
 
@@ -36,7 +37,6 @@ const char *CEGO_TYPE_MAP[] =
     "float",
     "double",
     "decimal",
-    "fixed",
     "smallint",
     "tinyint",
     "blob",
@@ -55,7 +55,6 @@ const int CEGO_JAVATYPE_MAP[] =
     6,
     8,
     3,
-    3,
     5,
     -6,
     2004,
@@ -71,7 +70,7 @@ CegoTypeConverter::~CegoTypeConverter()
 {
 }
 
-Chain CegoTypeConverter::getTypeString(CegoDataType type) const
+Chain CegoTypeConverter::getTypeString(CegoDataType type)
 {
     switch  ( type ) 
     {
@@ -93,8 +92,6 @@ Chain CegoTypeConverter::getTypeString(CegoDataType type) const
 	return Chain(XML_DOUBLE_VALUE);
     case DECIMAL_TYPE:
 	return Chain(XML_DECIMAL_VALUE);
-    case FIXED_TYPE:
-	return Chain(XML_FIXED_VALUE);
     case SMALLINT_TYPE:
 	return Chain(XML_SMALLINT_VALUE);
     case TINYINT_TYPE:
@@ -105,24 +102,27 @@ Chain CegoTypeConverter::getTypeString(CegoDataType type) const
 	return Chain(XML_CLOB_VALUE);
     case NULL_TYPE:
 	return Chain(XML_NULL_VALUE);
+    case PAGEID_TYPE:
+	return Chain(XML_PAGEIDTYPE_VALUE);
+    default:
+        throw Exception(EXLOC, Chain("Unknown data type"));	
     }
 }
 
-int CegoTypeConverter::getTypeLen(CegoDataType type, const Chain& val) const
+int CegoTypeConverter::getTypeLen(CegoDataType type, const Chain& val)
 {
     switch  ( type ) 
     {
     case INT_TYPE:
 	return sizeof(int);
     case LONG_TYPE:
-	return sizeof(long);
+	return sizeof(long long);
     case BOOL_TYPE:
 	return sizeof(char);
     case DATETIME_TYPE:
-	return sizeof(int);
+	return sizeof(unsigned long long);
     case VARCHAR_TYPE:
     case BIGINT_TYPE:
-    case FIXED_TYPE:
     case DECIMAL_TYPE:
 	return val.length();
     case FLOAT_TYPE:
@@ -139,12 +139,16 @@ int CegoTypeConverter::getTypeLen(CegoDataType type, const Chain& val) const
 	return 2 * sizeof(int);
     case NULL_TYPE:
 	return 0;
+    // just internal use
+    case PAGEID_TYPE:
+	return sizeof(PageIdType);
+    default:
+        throw Exception(EXLOC, Chain("Unknown data type"));
     }
 }
 
 CegoDataType CegoTypeConverter::getTypeId(const Chain& typeString)
 {
-
     CegoDataType type;
     
     if ( typeString == Chain(XML_STRING_VALUE) )
@@ -171,10 +175,6 @@ CegoDataType CegoTypeConverter::getTypeId(const Chain& typeString)
     {
 	type = DECIMAL_TYPE;
     }
-    else if ( typeString == Chain(XML_FIXED_VALUE) )
-    {
-	type = FIXED_TYPE;
-    }
     else if ( typeString == Chain(XML_BIGINT_VALUE) )
     {
 	type = BIGINT_TYPE;
@@ -203,10 +203,14 @@ CegoDataType CegoTypeConverter::getTypeId(const Chain& typeString)
     {
 	type = CLOB_TYPE;
     }
+    else
+    {
+	throw Exception(EXLOC, Chain("Unknown type string ") + typeString);
+    }
     return type;
 }
 
-Chain CegoTypeConverter::getObjectTypeString(CegoObject::ObjectType type) const
+Chain CegoTypeConverter::getObjectTypeString(CegoObject::ObjectType type)
 {    
     switch ( type )
     {
@@ -234,14 +238,21 @@ Chain CegoTypeConverter::getObjectTypeString(CegoObject::ObjectType type) const
 	return Chain(XML_FKEYOBJ_VALUE);
     case CegoObject::PROCEDURE:
 	return Chain(XML_PROCOBJ_VALUE);
+    case CegoObject::TRIGGER:
+	return Chain(XML_TRIGGEROBJ_VALUE);
+    case CegoObject::ALIAS:
+	return Chain(XML_ALIASOBJ_VALUE);
+    case CegoObject::CHECK:
+	return Chain(XML_CHECKOBJ_VALUE);
     default:
-	throw Exception(EXLOC, "Unknown type id");
+    // case CegoObject::JOIN:
+    // case CegoObject::UNDEFINED:	
+	throw Exception(EXLOC, "Invalid type id");
     }
 }
 
 CegoObject::ObjectType CegoTypeConverter::getObjectTypeId(const Chain& typeString)
 {
- 
     if ( typeString == Chain(XML_SYSOBJ_VALUE) )
 	return CegoObject::SYSTEM;
     if ( typeString == Chain(XML_TABOBJ_VALUE) )
@@ -266,5 +277,12 @@ CegoObject::ObjectType CegoTypeConverter::getObjectTypeId(const Chain& typeStrin
 	return CegoObject::FKEY;
     if ( typeString == Chain(XML_PROCOBJ_VALUE) )
 	return CegoObject::PROCEDURE;
+    if ( typeString == Chain(XML_TRIGGEROBJ_VALUE) )
+	return CegoObject::TRIGGER;    
+    if ( typeString == Chain(XML_CHECKOBJ_VALUE) )
+	return CegoObject::CHECK;
+    if ( typeString == Chain(XML_ALIASOBJ_VALUE) )
+	return CegoObject::ALIAS;
+
     throw Exception(EXLOC, Chain("Unknown object type"));
 }
