@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -29,45 +29,33 @@
 #include "CegoContentObject.h"
 
 class CegoViewObject : public CegoContentObject {
-
- public:
-
+    
+public:
+    
     CegoViewObject();
-    CegoViewObject(Element *pVO);
     CegoViewObject(const CegoViewObject& vo);
     CegoViewObject(const Chain& viewName, int tabSetId = 0);
-
     CegoViewObject(int tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewStmt);
-	
     ~CegoViewObject();
     
     int getEntrySize() const;
-    void encode(char *buf);
+    void encode(char *buf) const;
     void decode(char *buf);
-
-    void setSchema(const ListT<CegoField>& schema);   
-    
+    void setSchema(const ListT<CegoField>& schema);
     const Chain& getViewStmt() const;
     void setViewStmt(const Chain& viewStmt);
-
     void setEmpty();
-    
-    CegoViewObject& operator = ( const CegoViewObject& vo);
-    bool operator == ( const CegoViewObject& vo);
-
-    Chain getId() const;
-    Chain toChain() const;
+    Chain getId(CegoProcBlock *pBlock) const;
+    Chain toChain(int defTabSetId) const;
     CegoContentObject* clone(bool isAttrRef=false);
-
-    Element* getElement() const;
-    void putElement(Element* pElement);
     Chain getFormatted() const;
 
- private:
+    CegoViewObject& operator = ( const CegoViewObject& vo);
+    bool operator == ( const CegoViewObject& vo);
+    
+private:
 
     Chain fill(const Chain& s, int num) const;
     Chain _viewStmt;
-
 };
-
 #endif
