@@ -25,6 +25,7 @@
 #include <lfcbase/SetT.h>
 #include <lfcbase/Chain.h>
 #include <lfcbase/Logger.h>
+#include <lfcbase/BigDecimal.h>
 
 // xml includes
 #include <lfcxml/Document.h>
@@ -87,6 +88,8 @@ public:
     void setQuoteEscapeMode(bool m);
     bool isQuoteEscapeMode();
     Chain getDateTimeFormat();
+    BigDecimal::RoundMode getRoundMode();
+    
     ListT<Chain> getDateFormatList();
     void setArchRestoreProg(const Chain& progname);
     Chain getArchRestoreProg();
