@@ -525,6 +525,7 @@
 #define XML_QUEUEDELAY_ATTR "QUEUEDELAY"
 #define XML_REFTABLENAME_ATTR "REFTABLENAME"
 #define XML_ROLE_ATTR "ROLE"
+#define XML_ROUNDMODE_ATTR "ROUNDMODE"
 #define XML_RUNSTATE_ATTR "RUNSTATE"
 #define XML_SCANDATETIMEFORMAT_ATTR "SCANDATETIMEFORMAT"
 #define XML_SEGMENT_ATTR "SEGMENT"
@@ -790,4 +791,10 @@
 #define XML_READ_ROLE "read"
 #define XML_DROP_ROLE "drop"
 
+#define XML_ROUND_DOWN "DOWN"
+#define XML_ROUND_UP "UP"
+#define XML_ROUND_HALFDOWN "HALFDOWN"
+#define XML_ROUND_HALFUP "HALFUP"
+
+
 #endif
